-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-B96
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- # File Information: src/tedw_apps_etl/FixPack/ctd/cdw/ddl/ctd_cdw_schema.sql, dbmx_db2_tedw, dbmx_db2_510FP5
-- # Revision: 1.2
-- # Date: 3/5/04 10:34:20
-- ############################################################################

--#iftag fixpack_1

------------------------------------------------
-- Create a view for the current relation rules
-------------------------------------------------
create view CTD.Cur_RelnRul as 
select *
from TWG.RelnRul
where current timestamp - current timezone
between RelnRul_Strt_DtTm and RelnRul_End_DtTm;

------------------------------------------------
-- Create a view for the current attrtyp rules
-------------------------------------------------

create view CTD.Cur_AttrRul as 
select *
from TWG.AttrRul
where current timestamp - current timezone
between AttrRul_Strt_DtTm and AttrRul_End_DtTm;

---------
--- Host 
---------

--VE VIEW
create view CTD.ve_host (max_value) as
select VALUE(max(c.comp_id),-1) 
from twg.cur_comp c
where c.comptyp_cd in ('IP_HOST', 'IP_INTERFACE', 'CTD_HOST')
;

--VD VIEW
create view CTD.vd_host(
 orig_host_id,
 host_name,
 cust_nm,
 centr_nm ) as
select
  c1.comp_id as orig_host_id,
  c1.comp_nm as host_name, 
  cu.cust_nm as cust_nm,
  ce.centr_nm as centr_nm 
 from  
  twg.cur_comp c1, 
  twg.cust cu,
  twg.centr ce
where
  cu.cust_id=c1.cust_id and
  ce.centr_cd=c1.centr_cd and
  c1.comptyp_cd in ('IP_HOST', 'CTD_HOST', 'IP_INTERFACE') 
group by
  c1.comp_id, c1.comp_nm, cu.cust_nm, ce.centr_nm
;  

--------------------
---  INST 
--------------------

create table CTD.STG_INST_MET (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_name	        varchar(254)   not null,
 met_desc        	varchar(254),
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_INST_met (max_value) as
select VALUE(max(metric_id),-1) 
from CTD.stg_INST_met
;

-- VD VIEW
create view CTD.vd_INST_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.STG_INST_MET d
;

-- VE VIEW
create view CTD.ve_INST (max_value) as
select VALUE(max(c.comp_id),-1) 
from twg.cur_comp c
where c.comptyp_cd = 'CTD_INSTANCE' 
;

-- VD VIEW
create view CTD.vd_INST(
 orig_INST_id,
 Inst_Nm  , 
 IsMPP
 ) as
select
 c1.comp_id as orig_INST_id,
 c1.comp_nm as Inst_Nm , 
 value(min(ca2.compattr_val),'UNKNOWN')
from
 twg.cur_comp c1 
 left outer join 
 TWG.cur_compattr ca2
 on c1.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'CTD_ISMPP' 
where
 c1.comptyp_cd='CTD_INSTANCE'  
group by
 c1.comp_id, 
 c1.comp_nm
   ;
 

--VE VIEW
create view CTD.ve_stg_INST_hr (max_value) as
select VALUE(max(m.msmt_id),-1) 
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_INSTANCE'
and    c.comp_id = m.comp_id
;

--------------------
---  DB 
--------------------

create table CTD.STG_DB_MET (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_DB_met (max_value) as
select VALUE(max(metric_id),-1)
from CTD.stg_DB_met
;

-- VD VIEW
create view CTD.vd_DB_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.STG_DB_MET d
;

-- VE VIEW
create view CTD.ve_DB (max_value) as
select VALUE(max(c.comp_id) ,-1)
from twg.cur_comp c
where c.comptyp_cd = 'CTD_DATABASE' 
;

-- VD VIEW
create view CTD.vd_DB(
 orig_DB_id,
 DB_Nm 
 ) as
select
 c1.comp_id as orig_DB_id,
 c1.comp_nm as DB_Nm 
from
 twg.cur_comp c1  
where
 c1.comptyp_cd='CTD_DATABASE'  
group by
 c1.comp_id, 
 c1.comp_nm
   ;
 

--VE VIEW
create view CTD.ve_stg_DB_hr (max_value) as
select VALUE(max(m.msmt_id) ,-1)
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_DATABASE'
and    c.comp_id = m.comp_id
;

--------------------
---  GTWY 
--------------------

create table CTD.STG_GTWY_MET (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_GTWY_met (max_value) as
select VALUE(max(metric_id) ,-1)
from CTD.stg_GTWY_met
;

-- VD VIEW
create view CTD.vd_GTWY_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.STG_GTWY_MET d
;

-- VE VIEW
create view CTD.ve_GTWY (max_value) as
select VALUE(max(c.comp_id),-1) 
from twg.cur_comp c
where c.comptyp_cd = 'CTD_GATEWAY' 
;

-- VD VIEW
create view CTD.vd_GTWY(
 orig_GTWY_id,
 Gtwy_Nm 
 ) as
select
 c1.comp_id as orig_GTWY_id,
 c1.comp_nm as Gtwy_Nm 
from
 twg.cur_comp c1  
where
 c1.comptyp_cd='CTD_GATEWAY'  
group by
 c1.comp_id, 
 c1.comp_nm
   ;
 

--VE VIEW
create view CTD.ve_stg_GTWY_hr (max_value) as
select VALUE(max(m.msmt_id),-1)
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_GATEWAY'
and    c.comp_id = m.comp_id
;

--------------------
---  NODE 
--------------------

create table CTD.stg_NODE_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_NODE_met (max_value) as
select VALUE(max(metric_id),-1)
from CTD.stg_NODE_met
;

-- VD VIEW
create view CTD.vd_NODE_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.stg_NODE_met d
;

-- VE VIEW
create view CTD.ve_NODE (max_value) as
select VALUE(max(c.comp_id),-1)
from twg.cur_comp c
where c.comptyp_cd = 'CTD_NODE' 
;

-- VD VIEW
create view CTD.vd_NODE(
 orig_NODE_id,
 Node_Number,
 Node_Hostname  , 
 Node_Port_Number
 ) as
select
 c1.comp_id as orig_NODE_id,
 c1.comp_nm as Node_Number, 
 value(min(ca2.compattr_val),'UNKNOWN') as Node_Hostname , 
 value(min(ca3.compattr_val),'UNKNOWN') as Node_Port_Number
from
 twg.cur_comp c1 
 left outer join 
 TWG.cur_compattr ca3
 on c1.comp_id = ca3.comp_id and ca3.attrtyp_cd = 'CTD_NODE_PORT_NUM' ,
 twg.cur_comp c2
 left outer join 
 twg.cur_compattr ca2
 on c2.comp_id = ca2.comp_id and ca2.attrtyp_cd = 'CTD_NODE_HOST_NM' 
 where
 c1.comptyp_cd='CTD_NODE' and 
 c1.comp_id = c2.comp_id 
group by
 c1.comp_id, 
 c1.comp_nm,
 ca3.compattr_val,
 ca2.compattr_val
   ;
 

--VE VIEW
create view CTD.ve_stg_NODE_hr (max_value) as
select VALUE(max(m.msmt_id),-1)
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_NODE'
and    c.comp_id = m.comp_id
;

--------------------
---  APPLY 
--------------------

create table CTD.stg_APPLY_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_APPLY_met (max_value) as
select VALUE(max(metric_id),-1)
from CTD.stg_APPLY_met
;

-- VD VIEW
create view CTD.vd_APPLY_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.stg_APPLY_met d
;

-- VE VIEW
create view CTD.ve_APPLY (max_value) as
select VALUE(max(c.comp_id),-1)
from twg.cur_comp c
where c.comptyp_cd = 'CTD_APPLY_ID' 
;

-- VD VIEW
create view CTD.vd_APPLY(
 orig_APPLY_id,
 ApplyID 
 ) as
select
 c1.comp_id as orig_APPLY_id,
 c1.comp_nm as ApplyID 
from
 twg.cur_comp c1  
 where
 c1.comptyp_cd='CTD_APPLY_ID'  
group by
 c1.comp_id, 
 c1.comp_nm
   ;
 

--VE VIEW
create view CTD.ve_stg_APPLY_hr (max_value) as
select VALUE(max(m.msmt_id),-1)
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_APPLY_ID'
and    c.comp_id = m.comp_id
;

--------------------
---  TABLE 
--------------------

create table CTD.stg_TABLE_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_TABLE_met (max_value) as
select VALUE(max(metric_id),-1)
from CTD.stg_TABLE_met
;

-- VD VIEW
create view CTD.vd_TABLE_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.stg_TABLE_met d
;

-- VE VIEW
create view CTD.ve_TABLE (max_value) as
select VALUE(max(c.comp_id),-1)
from twg.cur_comp c
where c.comptyp_cd = 'CTD_TABLE' 
;

-- VD VIEW
create view CTD.vd_TABLE(
 orig_TABLE_id,
 Table_Nm,
 Table_Owner 
 ) as
select
 c1.comp_id as orig_TABLE_id,
 ca1.compattr_val as Table_Nm, 
 ca2.compattr_val as Table_Owner 
from
 twg.cur_comp c1  ,
 twg.cur_compattr ca1,
 twg.cur_compattr ca2
 where
 c1.comptyp_cd='CTD_TABLE' and 
 c1.comp_id = ca1.comp_id and
 ca1.attrtyp_cd ='NAME' and
 c1.comp_id = ca2.comp_id and
 ca2.attrtyp_cd ='OWNER' 
group by
 c1.comp_id, 
 ca1.compattr_val,
 ca2.compattr_val
   ;
 

--VE VIEW
create view CTD.ve_stg_TABLE_hr (max_value) as
select VALUE(max(m.msmt_id),-1)
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_TABLE'
and    c.comp_id = m.comp_id
;

--------------------
---  APPL 
--------------------

create table CTD.stg_APPL_met (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_APPL_met (max_value) as
select VALUE(max(metric_id),-1)
from CTD.stg_APPL_met
;

-- VD VIEW
create view CTD.vd_APPL_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.stg_APPL_met d
;

-- VE VIEW
create view CTD.ve_APPL (max_value) as
select VALUE(max(c.comp_id),-1)
from twg.cur_comp c
where c.comptyp_cd = 'CTD_APPL' 
;

-- VD VIEW
create view CTD.vd_APPL(
 orig_APPL_id,
 Appl_Nm 
 ) as
select
 c1.comp_id as orig_APPL_id,
 value(min(ca1.compattr_val),c1.comp_nm) as Appl_Nm
from
 twg.cur_comp c1 
 left outer join 
 TWG.cur_compattr ca1
 on c1.comp_id = ca1.comp_id and ca1.attrtyp_cd = 'CTD_APPL_NAME' 
where
 c1.comptyp_cd='CTD_APPL' 
group by
 c1.comp_id,
 c1.comp_nm,
 ca1.compattr_val
 ;
 

--VE VIEW
create view CTD.ve_stg_APPL_hr (max_value) as
select VALUE(max(m.msmt_id),-1)
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_APPL'
and    c.comp_id = m.comp_id
;


--------------------
---  TBSP Partition 
--------------------

create table CTD.STG_TBSP_ND_MET (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_TBSP_ND_met (max_value) as
select VALUE(max(metric_id),-1)
from CTD.STG_TBSP_ND_MET
;

-- VD VIEW
create view CTD.vd_TBSP_ND_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.stg_TBSP_ND_met d
;

-- VE VIEW
create view CTD.ve_TBSP_ND (max_value) as
select VALUE(max(c.comp_id),-1)
from twg.cur_comp c
where c.comptyp_cd = 'CTD_TBSP' 
;

-- VD VIEW
create view CTD.vd_TBSP_ND(
 orig_TBSP_ND_id,
 Tbsp_Nd_Nm 
 ) as
select
 c1.comp_id as orig_TBSP_ND_id,
 c1.comp_nm as Tbsp_Nd_Nm 
from
 twg.cur_comp c1  
where
 c1.comptyp_cd='CTD_TBSP'  
group by
 c1.comp_id, 
 c1.comp_nm
   ;
 

--VE VIEW
create view CTD.ve_stg_TBSP_ND_hr (max_value) as
select VALUE(max(m.msmt_id),-1) 
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_TBSP'
and    c.comp_id = m.comp_id
;


--------------------
---  TAPPLY 
--------------------

create table CTD.STG_TAPPLY_MET (
 insert_dttm            timestamp,
 metric_id     	        integer        not null,
 met_category 	        varchar(254),
 met_desc        	varchar(254),
 met_name	        varchar(254)   not null,
 met_units      	varchar(254),
 min_exists		char(1)        not null,
 max_exists		char(1)        not null,
 avg_exists		char(1)        not null,
 total_exists	        char(1)        not null,
 msrc_nm		varchar(254),
      primary key (metric_id));
      
-- VE VIEW
create view CTD.ve_TAPPLY_met (max_value) as
select VALUE(max(metric_id),-1)
from CTD.STG_TAPPLY_MET
;

-- VD VIEW
create view CTD.vd_TAPPLY_met (
  orig_metric_id,
  met_category,
  met_desc,
  met_name,
  met_units,
  min_exists,
  max_exists,
  avg_exists,
  total_exists,
  msrc_nm) as
select 
  d.metric_id as orig_metric_id,
  d.met_category as met_category,
  d.met_desc as met_desc,
  d.met_name as met_name,
  d.met_units as met_units,
  d.min_exists as min_exists,
  d.max_exists as max_exists,
  d.avg_exists as avg_exists,
  d.total_exists as total_exists,
  d.msrc_nm as msrc_nm
from 
 CTD.stg_TAPPLY_met d
;

-- VE VIEW
create view CTD.ve_TAPPLY (max_value) as
select VALUE(max(c.comp_id),-1)
from twg.cur_comp c
where c.comptyp_cd = 'CTD_TABLE_APPLY' 
;

-- VD VIEW
create view CTD.vd_TAPPLY(
 orig_TBAPPLY_id,
 Tapply_Nm,
 Tapply_Owner 
 ) as
select
 c1.comp_id as orig_TBAPPLY_id,
 ca1.compattr_val as Tapply_Nm, 
 ca2.compattr_val as Tapply_Owner 
from
 twg.cur_comp c1  ,
 twg.cur_compattr ca1,
 twg.cur_compattr ca2
where
 c1.comptyp_cd='CTD_TABLE_APPLY' and 
 c1.comp_id = ca1.comp_id and
 ca1.attrtyp_cd ='NAME' and
 c1.comp_id = ca2.comp_id and
 ca2.attrtyp_cd ='OWNER' 
group by
 c1.comp_id, 
 ca1.compattr_val,
 ca2.compattr_val
   ;
 

--VE VIEW
create view CTD.ve_stg_TAPPLY_hr (max_value) as
select VALUE(max(m.msmt_id),-1)
from   twg.cur_comp c, twg.msmt m
where  c.comptyp_cd = 'CTD_TABLE_APPLY'
and    c.comp_id = m.comp_id
;

--#endtag fixpack_1  
