-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-B96
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- # File Information: src/tedw_apps_etl/FixPack/ctd/etl/sql/ctd_m05_s030_mart_load.db2, dbmx_db2_tedw, dbmx_db2_510FP5
-- # Revision: 1.1
-- # Date: 2/13/04 10:21:11
-- ############################################################################
--#VERSION 1.1.0.1.0 

----------------------
--  HOST
---------------------
insert into CTD.T_HOST
select
 orig_host_id,
 host_id,
 cdw_id,
 host_name,
 CUST_NM,
 CENTR_NM
from
 CTD.STG_T_HOST a
where
not exists (
 select 1
 from
  CTD.T_HOST b
 where
  a.orig_host_id=b.orig_host_id and
  a.cdw_id=b.cdw_id
  )
 ;


insert into CTD.D_HOST 
(host_id,
 host_name,
 cust_nm,
 centr_nm) 
select 
 0, 
 host_name,
 cust_nm,
 centr_nm 
from 
 CTD.T_HOST b 
where 
not exists  (
  select 1 
  from 
   CTD.D_HOST a
  where
   a.centr_nm=b.centr_nm and 
   a.cust_nm=b.cust_nm and 
   a.host_name=b.host_name ) 
group by 
 centr_nm,
 cust_nm,
 host_name
;

update CTD.T_HOST s1 set host_id =
(
select
 d1.host_id
from
 CTD.D_HOST d1
where
 s1.host_name = d1.host_name and
 s1.cust_nm = d1.cust_nm and
 s1.centr_nm = d1.centr_nm 
);

-- insert into a slowly changing dimension table from 
-- the fact staging table  
insert into CTD.D_Host_Ip_Ad (Host_Ip_Ad_id, Host_Ip_Ad) 
select 
 0,
 Host_Ip_Ad
from 
 CTD.STG_INST_HR s
where not exists (
select 1 from
 CTD.D_Host_Ip_Ad d
where
 d.Host_Ip_Ad=s.Host_Ip_Ad)
group by
 Host_Ip_Ad
 ;
 
insert into CTD.D_Host_Ip_Ad (Host_Ip_Ad_id, Host_Ip_Ad)
select 
 0,
 Host_Ip_Ad
from 
 CTD.STG_GTWY_HR s
where not exists (
select 1 from
 CTD.D_Host_Ip_Ad d
where
 d.Host_Ip_Ad=s.Host_Ip_Ad)
group by
 Host_Ip_Ad
;

----------------------
-- CTD_INSTANCE
---------------------
insert into CTD.T_INST_METRIC 
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_INST_MET a
where
not exists (
select 1
from
 CTD.T_INST_METRIC b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);


insert into CTD.D_INST_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_INST_METRIC b 
where 
not exists  (
   select 1 from CTD.D_INST_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_INST ( Inst_Nm,IsMPP,orig_INST_id, cdw_id, INST_id) 
select
 a.Inst_Nm,
 a.IsMPP,
 a.orig_INST_id,
 a.cdw_id,
 a.INST_id
from
 CTD.STG_T_INST a
where
not exists (
select 1
from
 CTD.T_INST b
where
 b.orig_INST_id=a.orig_INST_id and
 b.cdw_id=a.cdw_id
)
;

insert into CTD.D_INST 
(
 INST_id, 
 Inst_Nm  , 
 IsMPP
) 
select 
 0, 
 Inst_Nm  , 
 IsMPP
from 
 CTD.T_INST b 
where 
not exists  (
   select 1 from CTD.D_INST a
    where 
    a.Inst_Nm = b.Inst_Nm  and  
     a.IsMPP = b.IsMPP
            ) 
group by 
 Inst_Nm  , 
 IsMPP
 ; 


update CTD.T_INST_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_INST_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_INST s1 set INST_id =
(
select
 d1.INST_id
from
 CTD.D_INST d1
where 
 s1.Inst_Nm = d1.Inst_Nm  and 
 s1.IsMPP = d1.IsMPP
);


-- insert into a slowly changing dimension table from 
-- the fact staging table  
insert into CTD.D_Inst_Vers
(Inst_Vers_id,
 Inst_Vers) 
select 
 0,
 Inst_Vers
from 
 CTD.STG_INST_HR s
where not exists (
select 1 from
 CTD.D_Inst_Vers d
where
 d.Inst_Vers=s.Inst_Vers)
group by
 Inst_Vers; 

-- set ids    
update CTD.STG_INST_HR s set 
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_INST_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_INST_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_INST_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and
  s.INST_id = f.INST_id and s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_INST_HOUR ( metric_id, host_id, host_ip_ad_id, INST_id, INST_Vers_id,  meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_INST_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.meas_hour;

----------------------
-- CTD_DATABASE
---------------------
insert into CTD.T_DB_METRIC 
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_DB_MET a
where
not exists (
select 1
from
 CTD.T_DB_METRIC b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);

insert into CTD.D_DB_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_DB_METRIC b 
where 
not exists  (
   select 1 from CTD.D_DB_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_DB 
select
 a.DB_Nm,
 a.orig_DB_id,
 a.cdw_id,
 a.DB_id
from
 CTD.STG_T_DB a
where
not exists (
select 1
from
 CTD.T_DB b
where
 b.orig_DB_id=a.orig_DB_id and
 b.cdw_id=a.cdw_id
)
;

insert into CTD.D_DB 
(
 DB_id, 
 DB_Nm 
) 
select 
 0, 
 DB_Nm 
from 
 CTD.T_DB b 
where 
not exists  (
   select 1 from CTD.D_DB a
    where 
    a.DB_Nm = b.DB_Nm 
            ) 
group by 
 DB_Nm 
 ; 


update CTD.T_DB_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_DB_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_DB s1 set DB_id =
(
select
 d1.DB_id
from
 CTD.D_DB d1
where 
 s1.DB_Nm = d1.DB_Nm 
);


-- set ids    
update CTD.STG_DB_HR s set 
DB_id = ( select DB_id from CTD.T_DB t
   where t.orig_DB_id = s.orig_DB_id 
   and   t.cdw_id = s.cdw_id),
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_DB_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_DB_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_DB_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and s.DB_id = f.DB_id and s.INST_id = f.INST_id and
  s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_DB_HOUR ( metric_id, host_id, host_ip_ad_id, DB_id, INST_id, INST_Vers_id, meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.DB_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_DB_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.DB_id, s.meas_hour;

----------------------
-- CTD_GATEWAY
---------------------
insert into CTD.T_GTWY_METRIC 
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_GTWY_MET a
where
not exists (
select 1
from
 CTD.T_GTWY_METRIC b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);

insert into CTD.D_GTWY_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_GTWY_METRIC b 
where 
not exists  (
   select 1 from CTD.D_GTWY_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_GTWY 
select
 a.GTWY_Nm,
 a.orig_GTWY_id,
 a.cdw_id,
 a.GTWY_id
from
 CTD.STG_T_GTWY a
where
not exists (
select 1
from
 CTD.T_GTWY b
where
 b.orig_GTWY_id=a.orig_GTWY_id and
 b.cdw_id=a.cdw_id
)
;

insert into CTD.D_GTWY 
(
 GTWY_id, 
 Gtwy_Nm 
) 
select 
 0, 
 Gtwy_Nm 
from 
 CTD.T_GTWY b 
where 
not exists  (
   select 1 from CTD.D_GTWY a
    where 
    a.Gtwy_Nm = b.Gtwy_Nm 
            ) 
group by 
 Gtwy_Nm 
 ; 


update CTD.T_GTWY_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_GTWY_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_GTWY s1 set GTWY_id =
(
select
 d1.GTWY_id
from
 CTD.D_GTWY d1
where 
 s1.Gtwy_Nm = d1.Gtwy_Nm 
);


-- set ids    
update CTD.STG_GTWY_HR s set 
GTWY_id = ( select GTWY_id from CTD.T_GTWY t
   where t.orig_GTWY_id = s.orig_GTWY_id 
   and   t.cdw_id = s.cdw_id),
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_GTWY_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_GTWY_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_GTWY_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and s.GTWY_id = f.GTWY_id and s.INST_id = f.INST_id and
  s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_GTWY_HOUR ( metric_id, host_id, host_ip_ad_id, GTWY_id, INST_id, INST_Vers_id, meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.GTWY_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_GTWY_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.GTWY_id, s.meas_hour;

----------------------
-- CTD_NODE
---------------------
insert into CTD.T_NODE_METRIC 
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_NODE_MET a
where
not exists (
select 1
from
 CTD.T_NODE_METRIC b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);

insert into CTD.D_NODE_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_NODE_METRIC b 
where 
not exists  (
   select 1 from CTD.D_NODE_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_NODE (Node_Number, Node_Hostname  , Node_Port_Number, orig_NODE_id, cdw_id, NODE_id )
select
 a.Node_Number,
 a.Node_Hostname  , 
 a.Node_Port_Number,
 a.orig_NODE_id,
 a.cdw_id,
 a.NODE_id
from
 CTD.STG_T_NODE a
where
not exists (
select 1
from
 CTD.T_NODE b
where
 b.orig_NODE_id=a.orig_NODE_id and
 b.cdw_id=a.cdw_id
)
;

insert into CTD.D_NODE 
(
 NODE_id, 
 Node_Number,
 Node_Hostname  , 
 Node_Port_Number
) 
select 
 0, 
 Node_Number,
 Node_Hostname  , 
 Node_Port_Number
from 
 CTD.T_NODE b 
where 
not exists  (
   select 1 from CTD.D_NODE a
    where 
    a.Node_Number = b.Node_Number and
	a.Node_Hostname = b.Node_Hostname  and  
     a.Node_Port_Number = b.Node_Port_Number
            ) 
group by 
 Node_Number,
 Node_Hostname  , 
 Node_Port_Number
 ; 


update CTD.T_NODE_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_NODE_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_NODE s1 set NODE_id =
(
select
 d1.NODE_id
from
 CTD.D_NODE d1
where 
 s1.Node_Number = d1.Node_Number and
 s1.Node_Hostname = d1.Node_Hostname  and 
 s1.Node_Port_Number = d1.Node_Port_Number
);


-- insert into a slowly changing dimension table from 
-- the fact staging table  
insert into CTD.D_Nd_LGPTH
(Nd_LGPTH_id,
 Nd_LGPTH) 
select 
 0,
 Nd_LGPTH
from 
 CTD.STG_NODE_HR s
where not exists (
select 1 from
 CTD.D_Nd_LGPTH d
where
 d.Nd_LGPTH=s.Nd_LGPTH)
group by
 Nd_LGPTH; 

-- set ids    
update CTD.STG_NODE_HR s set 
NODE_id = ( select NODE_id from CTD.T_NODE t
   where t.orig_NODE_id = s.orig_NODE_id 
   and   t.cdw_id = s.cdw_id),
ND_LGPTH_id = ( select ND_LGPTH_id from CTD.D_ND_LGPTH t
   where t.ND_LGPTH = s.ND_LGPTH),
DB_id = ( select DB_id from CTD.T_DB t
   where t.orig_DB_id = s.orig_DB_id 
   and   t.cdw_id = s.cdw_id),
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_NODE_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_NODE_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_NODE_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and s.NODE_id = f.NODE_id and s.ND_LGPTH_id = f.ND_LGPTH_id and s.INST_id = f.INST_id and s.DB_id = f.DB_id and
  s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_NODE_HOUR ( metric_id, host_id, host_ip_ad_id, NODE_id, ND_LGPTH_id, DB_id, INST_id, INST_Vers_id, meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.NODE_id, s.ND_LGPTH_id, s.DB_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_NODE_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.DB_Id, s.NODE_id, s.ND_LGPTH_id, s.meas_hour;

----------------------
-- CTD_APPLY_ID
---------------------
insert into CTD.T_APPLY_METRIC
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_APPLY_MET a
where
not exists (
select 1
from
 CTD.T_APPLY_METRIC b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);

insert into CTD.D_APPLY_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_APPLY_METRIC b 
where 
not exists  (
   select 1 from CTD.D_APPLY_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_APPLY  (APPLYID, orig_APPLY_id, cdw_id, APPLY_id )
select 
a.APPLYID, 
a.orig_APPLY_id, 
a.cdw_id, 
a.APPLY_id
from
 CTD.STG_T_APPLY a
where
not exists (
select 1
from
 CTD.T_APPLY b
where
 b.orig_APPLY_id=a.orig_APPLY_id and
 b.cdw_id=a.cdw_id
)
;

insert into CTD.D_APPLY 
(
 APPLY_id, 
 ApplyID 
) 
select 
 0, 
 ApplyID 
from 
 CTD.T_APPLY b 
where 
not exists  (
   select 1 from CTD.D_APPLY a
    where 
    a.ApplyID = b.ApplyID 
            ) 
group by 
 ApplyID 
 ; 


update CTD.T_APPLY_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_APPLY_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_APPLY s1 set APPLY_id =
(
select
 d1.APPLY_id
from
 CTD.D_APPLY d1
where 
 s1.ApplyID = d1.ApplyID 
);

-- set ids    
update CTD.STG_APPLY_HR s set 
APPLY_id = ( select APPLY_id from CTD.T_APPLY t
   where t.orig_APPLY_id = s.orig_APPLY_id 
   and   t.cdw_id = s.cdw_id),
DB_id = ( select DB_id from CTD.T_DB t
   where t.orig_DB_id = s.orig_DB_id 
   and   t.cdw_id = s.cdw_id),
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_APPLY_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_APPLY_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_APPLY_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and s.APPLY_id = f.APPLY_id and s.INST_id = f.INST_id and s.DB_id = f.DB_id and
  s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_APPLY_HOUR ( metric_id, host_id, host_ip_ad_id, APPLY_id, DB_id, INST_id, INST_Vers_id, meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.APPLY_id, s.DB_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_APPLY_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.DB_Id, s.APPLY_id, s.meas_hour;

----------------------
-- CTD_TABLE
---------------------
insert into CTD.T_TABLE_METRIC 
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_TABLE_MET  a
where
not exists (
select 1
from
 CTD.T_TABLE_METRIC  b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);

insert into CTD.D_TABLE_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_TABLE_METRIC b 
where 
not exists  (
   select 1 from CTD.D_TABLE_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_TABLE ( TABLE_Nm, Table_Owner, orig_TABLE_id, cdw_id, TABLE_id) 
select
 a.TABLE_Nm,
 a.Table_Owner,
 a.orig_TABLE_id,
 a.cdw_id,
 a.TABLE_id
from
 CTD.STG_T_TABLE a
where
not exists (
select 1
from
 CTD.T_TABLE b
where
 b.orig_TABLE_id=a.orig_TABLE_id and
 b.cdw_id=a.cdw_id
)
;


insert into CTD.D_TABLE 
(
 TABLE_id, 
 Table_Nm,
 Table_Owner 
) 
select 
 0, 
 Table_Nm,
 Table_Owner 
from 
 CTD.T_TABLE b 
where 
not exists  (
   select 1 from CTD.D_TABLE a
    where 
    a.Table_Nm = b.Table_Nm and
	a.Table_Owner = b.Table_Owner 
            ) 
group by 
 Table_Nm,
 Table_Owner 
 ; 


update CTD.T_TABLE_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_TABLE_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_TABLE s1 set TABLE_id =
(
select
 d1.TABLE_id
from
 CTD.D_TABLE d1
where 
 s1.Table_Nm = d1.Table_Nm and
 s1.Table_Owner = d1.Table_Owner 
);

-- set ids    
update CTD.STG_TABLE_HR s set 
TABLE_id = ( select TABLE_id from CTD.T_TABLE t
   where t.orig_TABLE_id = s.orig_TABLE_id 
   and   t.cdw_id = s.cdw_id),
DB_id = ( select DB_id from CTD.T_DB t
   where t.orig_DB_id = s.orig_DB_id 
   and   t.cdw_id = s.cdw_id),
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_TABLE_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_TABLE_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_TABLE_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and s.TABLE_id = f.TABLE_id and s.INST_id = f.INST_id and s.DB_id = f.DB_id and
  s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_TABLE_HOUR ( metric_id, host_id, host_ip_ad_id, TABLE_id, DB_id, INST_id, INST_Vers_id, meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.TABLE_id, s.DB_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_TABLE_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.DB_Id, s.TABLE_id, s.meas_hour;

----------------------
-- CTD_APPL
---------------------
insert into CTD.T_APPL_METRIC
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_APPL_MET  a
where
not exists (
select 1
from
 CTD.T_APPL_METRIC  b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);


insert into CTD.D_APPL_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_APPL_METRIC b 
where 
not exists  (
   select 1 from CTD.D_APPL_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_APPL ( APPL_Nm, orig_APPL_id, cdw_id, APPL_id) 
select
 a.APPL_Nm,
 a.orig_APPL_id,
 a.cdw_id,
 a.APPL_id
from
 CTD.STG_T_APPL a
where
not exists (
select 1
from
 CTD.T_APPL b
where
 b.orig_APPL_id=a.orig_APPL_id and
 b.cdw_id=a.cdw_id
)
;

insert into CTD.D_APPL 
(
 APPL_id, 
 Appl_Nm 
) 
select 
 0, 
 Appl_Nm 
from 
 CTD.T_APPL b 
where 
not exists  (
   select 1 from CTD.D_APPL a
    where 
    a.Appl_Nm = b.Appl_Nm 
            ) 
group by 
 Appl_Nm 
 ; 


update CTD.T_APPL_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_APPL_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_APPL s1 set APPL_id =
(
select
 d1.APPL_id
from
 CTD.D_APPL d1
where 
 s1.Appl_Nm = d1.Appl_Nm 
);


-- set ids    
update CTD.STG_APPL_HR s set 
APPL_id = ( select APPL_id from CTD.T_APPL t
   where t.orig_APPL_id = s.orig_APPL_id 
   and   t.cdw_id = s.cdw_id),
DB_id = ( select DB_id from CTD.T_DB t
   where t.orig_DB_id = s.orig_DB_id 
   and   t.cdw_id = s.cdw_id),
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_APPL_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_APPL_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_APPL_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and s.APPL_id = f.APPL_id and s.INST_id = f.INST_id and s.DB_id = f.DB_id and
  s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_APPL_HOUR ( metric_id, host_id, host_ip_ad_id, APPL_id, DB_id, INST_id, INST_Vers_id, meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.APPL_id, s.DB_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_APPL_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.DB_Id, s.APPL_id, s.meas_hour;

----------------------
-- CTD_TBSP
---------------------
insert into CTD.T_TBSP_ND_METRIC
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_TBSP_ND_MET  a
where
not exists (
select 1
from
 CTD.T_TBSP_ND_METRIC  b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);

insert into CTD.D_TBSP_ND_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_TBSP_ND_METRIC b 
where 
not exists  (
   select 1 from CTD.D_TBSP_ND_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_TBSP_ND ( TBSP_ND_Nm, orig_TBSP_ND_id, cdw_id, TBSP_ND_id )
select
 a.TBSP_ND_Nm,
 a.orig_TBSP_ND_id,
 a.cdw_id,
 a.TBSP_ND_id
from
 CTD.STG_T_TBSP_ND a
where
not exists (
select 1
from
 CTD.T_TBSP_ND b
where
 b.orig_TBSP_ND_id=a.orig_TBSP_ND_id and
 b.cdw_id=a.cdw_id
)
;

insert into CTD.D_TBSP_ND 
(
 TBSP_ND_id, 
 Tbsp_Nd_Nm 
) 
select 
 0, 
 Tbsp_Nd_Nm 
from 
 CTD.T_TBSP_ND b 
where 
not exists  (
   select 1 from CTD.D_TBSP_ND a
    where 
    a.Tbsp_Nd_Nm = b.Tbsp_Nd_Nm 
            ) 
group by 
 Tbsp_Nd_Nm 
 ; 


update CTD.T_TBSP_ND_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_TBSP_ND_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_TBSP_ND s1 set TBSP_ND_id =
(
select
 d1.TBSP_ND_id
from
 CTD.D_TBSP_ND d1
where 
 s1.Tbsp_Nd_Nm = d1.Tbsp_Nd_Nm 
);

-- set ids    
update CTD.STG_TBSP_ND_HR s set 
TBSP_ND_id = ( select TBSP_ND_id from CTD.T_TBSP_ND t
   where t.orig_TBSP_ND_id = s.orig_TBSP_ND_id 
   and   t.cdw_id = s.cdw_id),
NODE_id = ( select NODE_id from CTD.T_NODE t
   where t.orig_NODE_id = s.orig_NODE_id 
   and   t.cdw_id = s.cdw_id),
ND_LGPTH_id = ( select ND_LGPTH_id from CTD.D_ND_LGPTH t
   where t.ND_LGPTH = s.ND_LGPTH),
DB_id = ( select DB_id from CTD.T_DB t
   where t.orig_DB_id = s.orig_DB_id 
   and   t.cdw_id = s.cdw_id),
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_TBSP_ND_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_TBSP_ND_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_TBSP_ND_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and s.TBSP_ND_id = f.TBSP_ND_id and s.INST_id = f.INST_id and s.DB_id = f.DB_id and s.NODE_id = f.NODE_id and s.ND_LGPTH_id = f.ND_LGPTH_id and
  s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_TBSP_ND_HOUR ( metric_id, host_id, host_ip_ad_id, TBSP_ND_id,NODE_id, ND_LGPTH_id, DB_id, INST_id, INST_Vers_id, meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.TBSP_ND_id, s.NODE_Id, s.ND_LGPTH_id, s.DB_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_TBSP_ND_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.DB_Id, s.TBSP_ND_id, s.NODE_id, s.ND_LGPTH_id, s.meas_hour;

----------------------
-- CTD_TABLE_APPLY
---------------------
insert into CTD.T_TAPPLY_METRIC
select
 a.orig_metric_id,
 a.metric_id,
 a.cdw_id,
 a.met_category,
 a.met_desc,
 a.met_name,
 a.met_units,
 a.min_exists,
 a.max_exists,
 a.avg_exists,
 a.total_exists,
 a.msrc_nm
from
 CTD.STG_T_TAPPLY_MET  a
where
not exists (
select 1
from
 CTD.T_TAPPLY_METRIC  b
where
 a.orig_metric_id=b.orig_metric_id and
 a.cdw_id=b.cdw_id
);

insert into CTD.D_TAPPLY_METRIC 
(metric_id,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 max_exists,
 avg_exists,
 total_exists,
 msrc_nm) 
select 
    0, 
    met_category,
    met_desc,
    met_name,
    met_units,
    min_exists,
    max_exists,
    avg_exists,
    total_exists,
    msrc_nm 
from 
CTD.T_TAPPLY_METRIC b 
where 
not exists  (
   select 1 from CTD.D_TAPPLY_METRIC a
    where
    a.avg_exists=b.avg_exists and 
    a.max_exists=b.max_exists and 
    a.met_category=b.met_category and 
    a.met_desc=b.met_desc and 
    a.met_name=b.met_name and 
    a.met_units=b.met_units and 
    a.min_exists=b.min_exists and 
    a.msrc_nm=b.msrc_nm and 
    a.total_exists=b.total_exists) 
group by 
 avg_exists,
 max_exists,
 met_category,
 met_desc,
 met_name,
 met_units,
 min_exists,
 msrc_nm,
 total_exists; 

insert into CTD.T_TAPPLY  ( TAPPLY_Nm, orig_TBAPPLY_id, cdw_id, TBAPPLY_id )
select
 a.TAPPLY_Nm,
 a.orig_TBAPPLY_id,
 a.cdw_id,
 a.TBAPPLY_id
from
 CTD.STG_T_TAPPLY  a
where
not exists (
select 1
from
 CTD.T_TAPPLY  b
where
 b.orig_TBAPPLY_id=a.orig_TBAPPLY_id and
 b.cdw_id=a.cdw_id
)
;

insert into CTD.D_TAPPLY 
(
 TBAPPLY_id, 
 Tapply_Nm,
 Tapply_Owner 
) 
select 
 0, 
 Tapply_Nm,
 Tapply_Owner 
from 
 CTD.T_TAPPLY b 
where 
not exists  (
   select 1 from CTD.D_TAPPLY a
    where 
    a.Tapply_Nm = b.Tapply_Nm and
	a.Tapply_Owner = b.Tapply_Owner 
            ) 
group by 
 Tapply_Nm,
 Tapply_Owner 
 ; 


update CTD.T_TAPPLY_metric s1 set metric_id =
(
select
 d1.metric_id
from
 CTD.D_TAPPLY_METRIC d1
where
 s1.met_name = d1.met_name and
 s1.met_units = d1.met_units and
 s1.msrc_nm = d1.msrc_nm
);

update CTD.T_TAPPLY s1 set TBAPPLY_id =
(
select
 d1.TBAPPLY_id
from
 CTD.D_TAPPLY d1
where 
 s1.Tapply_Nm = d1.Tapply_Nm and
 s1.Tapply_Owner = d1.Tapply_Owner 
);



-- set ids    
update CTD.STG_TAPPLY_HR s set 
TBAPPLY_id = ( select TBAPPLY_id from CTD.T_TAPPLY t
   where t.orig_TBAPPLY_id = s.orig_TBAPPLY_id 
   and   t.cdw_id = s.cdw_id),
APPLY_id = ( select APPLY_id from CTD.T_APPLY t
   where t.orig_APPLY_id = s.orig_APPLY_id 
   and   t.cdw_id = s.cdw_id),
DB_id = ( select DB_id from CTD.T_DB t
   where t.orig_DB_id = s.orig_DB_id 
   and   t.cdw_id = s.cdw_id),
INST_id = ( select INST_id from CTD.T_INST t
   where t.orig_INST_id = s.orig_INST_id 
   and   t.cdw_id = s.cdw_id),
INST_Vers_id = ( select INST_Vers_id from CTD.D_INST_Vers t
   where t.INST_Vers = s.INST_Vers),
host_id = ( select host_id from CTD.T_HOST t
   where t.orig_host_id = s.orig_host_id 
   and   t.cdw_id = s.cdw_id),
metric_id = ( select metric_id from CTD.T_TAPPLY_METRIC t
   where t.orig_metric_id = s.orig_metric_id 
   and   t.cdw_id = s.cdw_id),
host_ip_ad_id = ( select host_ip_ad_id from CTD.D_HOST_IP_AD t
   where t.host_ip_ad = s.host_ip_ad );

-- set row_exists 
update CTD.STG_TAPPLY_HR s set 
row_exists = 'Y' where exists ( select 1 from CTD.F_TAPPLY_HOUR f where
  s.metric_id = f.metric_id and s.host_id = f.host_id and s.host_ip_ad_id = f.host_ip_ad_id and s.TBAPPLY_id = f.TBAPPLY_id and s.INST_id = f.INST_id and s.DB_id = f.DB_id and s.APPLY_id = f.APPLY_id and
  s.meas_hour = f.meas_hour )
;

-- insert into fact table where not exists
insert into CTD.F_TAPPLY_HOUR ( metric_id, host_id, host_ip_ad_id, TBAPPLY_id, APPLY_id, DB_id, INST_id, INST_Vers_id, meas_hour, min_value, max_value, avg_value, total_value, sample_count)
select
 s.metric_id, s.host_id, s.host_ip_ad_id, s.TBAPPLY_id, s.APPLY_Id, s.DB_id, s.INST_id, s.INST_Vers_id, s.meas_hour,
 min(s.min_value), max(s.max_value), avg(s.avg_value), avg(s.total_value), avg(s.sample_count)
from
 CTD.STG_TAPPLY_HR s
where s.row_exists = 'N'
group by s.metric_id, s.host_id, s.host_ip_ad_id, s.INST_id, s.INST_Vers_id, s.DB_Id, s.TBAPPLY_id, s.APPLY_id, s.meas_hour
