-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-B96
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- # File Information: src/tedw_apps_etl/FixPack/ctd/mart/ddl/ctd_mart_schema.sql, dbmx_db2_tedw, dbmx_db2_510FP5
-- # Revision: 1.1
-- # Date: 2/13/04 10:21:15
-- ############################################################################

--#iftag fixpack_1
-------------------------------------------------------
-- Prune tables
-------------------------------------------------------

create table CTD.prune_mart_control (
table_name 	varchar(120) not null,
pmartc_duration	decimal(8,0) not null
);


create table CTD.prune_mart_log (
pmart_run_dttm 	timestamp not null,
table_name	varchar(30),
pmartc_duration	decimal(8,0) not null,
number_pruned	decimal(8,0) not null
);

----------------------------
--- Dimension Table:  Host  
----------------------------

create table CTD.d_host (
 host_id                     integer        not null,
 host_name                   varchar(254)   not null,
 cust_nm                     varchar(120), 
 centr_nm                    varchar(120),
      primary key (host_id)
      );

-- Translation table      

create table CTD.t_host (
 orig_host_id                integer        not null,
 host_id		     integer,
 cdw_id		             integer        not null,		
 host_name                   varchar(254)   not null,
 cust_nm                     varchar(120), 
 centr_nm                    varchar(120),
      primary key (orig_host_id, cdw_id)
      );

--SEQUENCE      

create sequence CTD.host_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--TRIGGER

create trigger CTD.host_i1
no cascade before insert on CTD.d_host  
referencing new as n for each row mode db2sql
set n.host_id = nextval for CTD.host_id_seq;

-----------------------------
-- dimension table:  host_ip_address
-----------------------------

create table CTD.D_Host_ip_ad (
 Host_ip_ad_id    	           integer        not null,
 Host_ip_ad                  varchar(254)   not null,
      primary key (Host_ip_ad_id));

  
--sequence      

create sequence CTD.Host_ip_ad_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.Host_ip_ad_i0
no cascade before insert on CTD.d_Host_ip_ad 
referencing new as n for each row mode db2sql
set n.Host_ip_ad_id = nextval for CTD.Host_ip_ad_id_seq;     
      
--------------------
---  INST 
--------------------

---------------------------------
-- dimension table: INST metric 
---------------------------------

create table CTD.d_INST_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_INST_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.INSTmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.INSTmt_i1
no cascade before insert on CTD.d_INST_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.INSTmt_id_seq;

-----------------------------
-- dimension table: INST 
-----------------------------

create table CTD.D_INST (
 Inst_Nm	varchar(254), 
 INST_id     	integer        not null,  
 IsMPP 		varchar(254),
      primary key (INST_id));

-- translation table

create table CTD.T_INST (
 Inst_Nm	varchar(254), 
 orig_INST_id         integer        not null,  
 IsMPP 		varchar(254),
 cdw_id			 integer        not null, 
 INST_id              integer not null,
      primary key (orig_INST_id,cdw_id)
      );

--sequence      

create sequence CTD.INST_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.INST_i1
no cascade before insert on CTD.d_INST  
referencing new as n for each row mode db2sql
set n.INST_id = nextval for CTD.INST_id_seq;
      

-----------------------------
-- dimension table:Inst_Vers 
-----------------------------

create table CTD.D_Inst_Vers (
 Inst_Vers_id    	           integer        not null,
 Inst_Vers                   varchar(254)   not null,
      primary key (Inst_Vers_ID));

  
--sequence      

create sequence CTD.Inst_Vers_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.Inst_Vers_i1
no cascade before insert on CTD.d_Inst_Vers 
referencing new as n for each row mode db2sql
set n.Inst_Vers_id = nextval for CTD.Inst_Vers_id_seq;     
      
-----------------------------
-- staging hour fact table
------------------------------

create table CTD.STG_INST_HR (
    msmt_id		  integer not null,
    orig_INST_id          integer not null, 
    Inst_Vers             varchar(254) not null,
    orig_host_id          integer not null,
    Host_ip_ad		  varchar(254) not null,	
    orig_metric_id        integer not null,
    cdw_id		  integer not null,
    meas_hour             timestamp not null,
    min_value		  float,
    max_value	          float,
    avg_value       	  float,
    total_value		  float,
    sample_count	  float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: INST 
-----------------------------

create table CTD.F_INST_HOUR (
 INST_id            integer not null, 
 Inst_Vers_id 	integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_hour                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (INST_id, 
       Inst_Vers_id, 
       host_id, host_ip_ad_id, metric_id, 
       meas_hour)
       );

create index CTD.f_INST_hr1 on CTD.F_INST_HOUR (INST_id);
create index CTD.f_INST_hr2 on CTD.F_INST_HOUR (host_id);
create index CTD.f_INST_hr3 on CTD.F_INST_HOUR (metric_id);
create index CTD.f_INST_hr4 on CTD.F_INST_HOUR (meas_hour); 
create index CTD.f_INST_hr5 on CTD.F_INST_HOUR (Inst_Vers_id);
create index CTD.f_INST_hr60 on CTD.F_INST_HOUR (host_ip_ad_id);

alter table CTD.F_INST_HOUR
add constraint K1
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_INST_HOUR
add constraint K2
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_INST_HOUR
add constraint K3
foreign key (metric_id)
references CTD.D_INST_METRIC (metric_id); 

alter table CTD.F_INST_HOUR
add constraint K12
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_INST_HOUR
add constraint K646
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: INST 
-----------------------------

create table CTD.F_INST_DAY (
 INST_id            integer not null, 
 Inst_Vers_id 	integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (INST_id, 
       Inst_Vers_id, 
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_INST_day1 on CTD.F_INST_DAY (INST_id);
create index CTD.f_INST_day2 on CTD.F_INST_DAY (host_id);
create index CTD.f_INST_day3 on CTD.F_INST_DAY (metric_id);
create index CTD.f_INST_day4 on CTD.F_INST_DAY (meas_date); 
create index CTD.f_INST_day55 on CTD.F_INST_DAY (Inst_Vers_id);
create index CTD.f_INST_day60 on CTD.F_INST_DAY (host_ip_ad_id);

alter table CTD.F_INST_DAY
add constraint K4
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_INST_DAY
add constraint K5
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_INST_DAY
add constraint K6
foreign key (metric_id)
references CTD.D_INST_METRIC (metric_id);  

alter table CTD.F_INST_DAY
add constraint K13
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_INST_DAY
add constraint K647
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);


-----------------------------
-- weekly fact table: INST 
-----------------------------

create table CTD.F_INST_WEEK (
 INST_id         integer not null, 
 Inst_Vers_id 	integer not null,
 host_id		integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id		integer not null,
 meas_date		timestamp not null,
 min_value		float,
 max_value		float,
 avg_value		float,
 total_value		float,
 sample_count		float,
       primary key (INST_id, 
       Inst_Vers_id, 
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_INST_wk1 on CTD.F_INST_WEEK (INST_id);
create index CTD.f_INST_wk2 on CTD.F_INST_WEEK (host_id);
create index CTD.f_INST_wk3 on CTD.F_INST_WEEK (metric_id);
create index CTD.f_INST_wk4 on CTD.F_INST_WEEK (meas_date); 
create index CTD.f_INST_wk55 on CTD.F_INST_WEEK (Inst_Vers_id);
create index CTD.f_INST_wk60 on CTD.F_INST_WEEK (host_ip_ad_id);

alter table CTD.F_INST_WEEK
add constraint K7
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_INST_WEEK
add constraint K8
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_INST_WEEK
add constraint K9
foreign key (metric_id)
references CTD.D_INST_METRIC (metric_id); 

alter table CTD.F_INST_WEEK
add constraint K14
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_INST_WEEK
add constraint K648
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: INST 
-----------------------------

create table CTD.F_INST_MONTH (
 INST_id            integer not null, 
 Inst_Vers_id 	integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (INST_id, 
       Inst_Vers_id, 
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_INST_mo1 on CTD.F_INST_MONTH (INST_id);
create index CTD.f_INST_mo2 on CTD.F_INST_MONTH (host_id);
create index CTD.f_INST_mo3 on CTD.F_INST_MONTH (metric_id);
create index CTD.f_INST_mo4 on CTD.F_INST_MONTH (meas_date);  
create index CTD.f_INST_mo55 on CTD.F_INST_MONTH (Inst_Vers_id);
create index CTD.f_INST_mo60 on CTD.F_INST_MONTH (host_ip_ad_id);

alter table CTD.F_INST_MONTH
add constraint K9
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_INST_MONTH
add constraint K10
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_INST_MONTH
add constraint K11
foreign key (metric_id)
references CTD.D_INST_METRIC (metric_id); 

alter table CTD.F_INST_MONTH
add constraint K15
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_INST_MONTH
add constraint K649
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

--------------------
---  DB 
--------------------

---------------------------------
-- dimension table: DB metric 
---------------------------------

create table CTD.d_DB_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_DB_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.DBmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.DBmt_i1
no cascade before insert on CTD.d_DB_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.DBmt_id_seq;

-----------------------------
-- dimension table: DB 
-----------------------------

create table CTD.D_DB (
 DB_Nm	varchar(254), 
 DB_id     	integer        not null, 
      primary key (DB_id));

-- translation table

create table CTD.T_DB (
 DB_Nm	varchar(254), 
 orig_DB_id         integer        not null, 
 cdw_id			 integer        not null, 
 DB_id              integer not null,
      primary key (orig_DB_id,cdw_id)
      );

--sequence      

create sequence CTD.DB_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.DB_i1
no cascade before insert on CTD.d_DB  
referencing new as n for each row mode db2sql
set n.DB_id = nextval for CTD.DB_id_seq;
      

--staging hour fact table
create table CTD.STG_DB_HR (
    msmt_id		   integer	  not null,
    orig_DB_id    integer        not null,
    orig_INST_id	   integer	  not null,
    Inst_Vers    varchar(254) not null,
    orig_host_id           integer        not null,
    Host_ip_ad		  varchar(254) not null,
    orig_metric_id         integer        not null,
    cdw_id		   integer        not null,
    meas_HOUR              timestamp      not null,
    min_value		   float,
    max_value	           float,
    avg_value       	   float,
    total_value		   float,
    sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: DB 
-----------------------------

create table CTD.F_DB_HOUR (
 DB_id            integer       not null, 
 INST_id		   integer 	 not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer       not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer       not null,
 meas_HOUR                 timestamp     not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, meas_HOUR)
       );

create index CTD.f_DB_hr1 on CTD.F_DB_HOUR (DB_id);
create index CTD.f_DB_hr2 on CTD.F_DB_HOUR (host_id);
create index CTD.f_DB_hr3 on CTD.F_DB_HOUR (metric_id);
create index CTD.f_DB_hr4 on CTD.F_DB_HOUR (meas_hour); 
create index CTD.f_DB_hr6 on CTD.F_DB_HOUR (INST_id);  
create index CTD.f_DB_hr7 on CTD.F_DB_HOUR (Inst_Vers_id);
create index CTD.f_DB_hr60 on CTD.F_DB_HOUR (host_ip_ad_id);

alter table CTD.F_DB_HOUR
add constraint K16
foreign key (DB_id)
references CTD.D_DB (DB_id);

alter table CTD.F_DB_HOUR
add constraint K17
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_DB_HOUR
add constraint K18
foreign key (metric_id)
references CTD.D_DB_METRIC (metric_id);  

alter table CTD.F_DB_HOUR
add constraint K38
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_DB_HOUR
add constraint K27
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_DB_HOUR
add constraint K650
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: DB 
-----------------------------

create table CTD.F_DB_DAY (
 DB_id            integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_DB_day1 on CTD.F_DB_DAY (DB_id);
create index CTD.f_DB_day2 on CTD.F_DB_DAY (host_id);
create index CTD.f_DB_day3 on CTD.F_DB_DAY (metric_id);
create index CTD.f_DB_day4 on CTD.F_DB_DAY (meas_date);
create index CTD.f_DB_day6 on CTD.F_DB_DAY (INST_id);  
create index CTD.f_DB_day7 on CTD.F_DB_DAY (Inst_Vers_id);
create index CTD.f_DB_day60 on CTD.F_DB_DAY (host_ip_ad_id);

alter table CTD.F_DB_DAY
add constraint K19
foreign key (DB_id)
references CTD.D_DB (DB_id);

alter table CTD.F_DB_DAY
add constraint K20
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_DB_DAY
add constraint K21
foreign key (metric_id)
references CTD.D_DB_METRIC (metric_id);   

alter table CTD.F_DB_day
add constraint K39
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_DB_day
add constraint K29
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_DB_day
add constraint K651
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- weekly fact table: DB 
-----------------------------

create table CTD.F_DB_WEEK (
 DB_id            integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_DB_wk1 on CTD.F_DB_WEEK (DB_id);
create index CTD.f_DB_wk2 on CTD.F_DB_WEEK (host_id);
create index CTD.f_DB_wk3 on CTD.F_DB_WEEK (metric_id);
create index CTD.f_DB_wk4 on CTD.F_DB_WEEK (meas_date);
create index CTD.f_DB_wk6 on CTD.F_DB_WEEK (INST_id);  
create index CTD.f_DB_wk7 on CTD.F_DB_WEEK (Inst_Vers_id);
create index CTD.f_DB_wk60 on CTD.F_DB_WEEK (host_ip_ad_id);

alter table CTD.F_DB_WEEK
add constraint K22
foreign key (DB_id)
references CTD.D_DB (DB_id);

alter table CTD.F_DB_WEEK
add constraint K23
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_DB_WEEK
add constraint K24
foreign key (metric_id)
references CTD.D_DB_METRIC (metric_id);  

alter table CTD.F_DB_WEEK
add constraint K40
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_DB_WEEK
add constraint K32
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_DB_WEEK
add constraint K652
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: DB 
-----------------------------

create table CTD.F_DB_MONTH (
 DB_id            integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_DB_mo1 on CTD.F_DB_MONTH (DB_id);
create index CTD.f_DB_mo2 on CTD.F_DB_MONTH (host_id);
create index CTD.f_DB_mo3 on CTD.F_DB_MONTH (metric_id);
create index CTD.f_DB_mo4 on CTD.F_DB_MONTH (meas_date);
create index CTD.f_DB_mo6 on CTD.F_DB_MONTH (INST_id);  
create index CTD.f_DB_mo7 on CTD.F_DB_MONTH (Inst_Vers_id);
create index CTD.f_DB_mo60 on CTD.F_DB_MONTH (host_ip_ad_id);

alter table CTD.F_DB_MONTH
add constraint K24
foreign key (DB_id)
references CTD.D_DB (DB_id);

alter table CTD.F_DB_MONTH
add constraint K25
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_DB_MONTH
add constraint K26
foreign key (metric_id)
references CTD.D_DB_METRIC (metric_id);    

alter table CTD.F_DB_MONTH
add constraint K41
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_DB_MONTH
add constraint K35
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_DB_MONTH
add constraint K653
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

--------------------
---  GTWY 
--------------------

---------------------------------
-- dimension table: GTWY metric 
---------------------------------

create table CTD.d_GTWY_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_GTWY_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.GTWYmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.GTWYmt_i1
no cascade before insert on CTD.d_GTWY_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.GTWYmt_id_seq;

-----------------------------
-- dimension table: GTWY 
-----------------------------

create table CTD.D_GTWY (
 Gtwy_Nm	varchar(254), 
 GTWY_id     	integer        not null, 
      primary key (GTWY_id));

-- translation table

create table CTD.T_GTWY (
 Gtwy_Nm	varchar(254), 
 orig_GTWY_id         integer        not null, 
 cdw_id			 integer        not null, 
 GTWY_id              integer not null,
      primary key (orig_GTWY_id,cdw_id)
      );

--sequence      

create sequence CTD.GTWY_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.GTWY_i1
no cascade before insert on CTD.d_GTWY  
referencing new as n for each row mode db2sql
set n.GTWY_id = nextval for CTD.GTWY_id_seq;
      

--staging hour fact table
create table CTD.STG_GTWY_HR (
    msmt_id		   integer	  not null,
    orig_GTWY_id    integer        not null,
    orig_INST_id	   integer	  not null,
    Inst_Vers    varchar(254) not null,
    orig_host_id           integer        not null,
    Host_ip_ad		  varchar(254) not null,
    orig_metric_id         integer        not null,
    cdw_id		   integer        not null,
    meas_HOUR              timestamp      not null,
    min_value		   float,
    max_value	           float,
    avg_value       	   float,
    total_value		   float,
    sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: GTWY 
-----------------------------

create table CTD.F_GTWY_HOUR (
 GTWY_id            integer       not null, 
 INST_id		   integer 	 not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer       not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer       not null,
 meas_HOUR                 timestamp     not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (GTWY_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, meas_HOUR)
       );

create index CTD.f_GTWY_hr1 on CTD.F_GTWY_HOUR (GTWY_id);
create index CTD.f_GTWY_hr2 on CTD.F_GTWY_HOUR (host_id);
create index CTD.f_GTWY_hr3 on CTD.F_GTWY_HOUR (metric_id);
create index CTD.f_GTWY_hr4 on CTD.F_GTWY_HOUR (meas_hour); 
create index CTD.f_GTWY_hr8 on CTD.F_GTWY_HOUR (INST_id);  
create index CTD.f_GTWY_hr9 on CTD.F_GTWY_HOUR (Inst_Vers_id);
create index CTD.f_GTWY_hr60 on CTD.F_GTWY_HOUR (host_ip_ad_id);

alter table CTD.F_GTWY_HOUR
add constraint K42
foreign key (GTWY_id)
references CTD.D_GTWY (GTWY_id);

alter table CTD.F_GTWY_HOUR
add constraint K43
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_GTWY_HOUR
add constraint K44
foreign key (metric_id)
references CTD.D_GTWY_METRIC (metric_id);  

alter table CTD.F_GTWY_HOUR
add constraint K64
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_GTWY_HOUR
add constraint K53
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_GTWY_HOUR
add constraint K654
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: GTWY 
-----------------------------

create table CTD.F_GTWY_DAY (
 GTWY_id            integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (GTWY_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_GTWY_day1 on CTD.F_GTWY_DAY (GTWY_id);
create index CTD.f_GTWY_day2 on CTD.F_GTWY_DAY (host_id);
create index CTD.f_GTWY_day3 on CTD.F_GTWY_DAY (metric_id);
create index CTD.f_GTWY_day4 on CTD.F_GTWY_DAY (meas_date);
create index CTD.f_GTWY_day8 on CTD.F_GTWY_DAY (INST_id);  
create index CTD.f_GTWY_day9 on CTD.F_GTWY_DAY (Inst_Vers_id);
create index CTD.f_GTWY_day60 on CTD.F_GTWY_DAY (host_ip_ad_id);

alter table CTD.F_GTWY_DAY
add constraint K45
foreign key (GTWY_id)
references CTD.D_GTWY (GTWY_id);

alter table CTD.F_GTWY_DAY
add constraint K46
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_GTWY_DAY
add constraint K47
foreign key (metric_id)
references CTD.D_GTWY_METRIC (metric_id);   

alter table CTD.F_GTWY_day
add constraint K65
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_GTWY_day
add constraint K55
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_GTWY_day
add constraint K655
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- weekly fact table: GTWY 
-----------------------------

create table CTD.F_GTWY_WEEK (
 GTWY_id            integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (GTWY_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_GTWY_wk1 on CTD.F_GTWY_WEEK (GTWY_id);
create index CTD.f_GTWY_wk2 on CTD.F_GTWY_WEEK (host_id);
create index CTD.f_GTWY_wk3 on CTD.F_GTWY_WEEK (metric_id);
create index CTD.f_GTWY_wk4 on CTD.F_GTWY_WEEK (meas_date);
create index CTD.f_GTWY_wk8 on CTD.F_GTWY_WEEK (INST_id);  
create index CTD.f_GTWY_wk9 on CTD.F_GTWY_WEEK (Inst_Vers_id);
create index CTD.f_GTWY_wk60 on CTD.F_GTWY_WEEK (host_ip_ad_id);

alter table CTD.F_GTWY_WEEK
add constraint K48
foreign key (GTWY_id)
references CTD.D_GTWY (GTWY_id);

alter table CTD.F_GTWY_WEEK
add constraint K49
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_GTWY_WEEK
add constraint K50
foreign key (metric_id)
references CTD.D_GTWY_METRIC (metric_id);  

alter table CTD.F_GTWY_WEEK
add constraint K66
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_GTWY_WEEK
add constraint K58
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_GTWY_WEEK
add constraint K656
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: GTWY 
-----------------------------

create table CTD.F_GTWY_MONTH (
 GTWY_id            integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (GTWY_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_GTWY_mo1 on CTD.F_GTWY_MONTH (GTWY_id);
create index CTD.f_GTWY_mo2 on CTD.F_GTWY_MONTH (host_id);
create index CTD.f_GTWY_mo3 on CTD.F_GTWY_MONTH (metric_id);
create index CTD.f_GTWY_mo4 on CTD.F_GTWY_MONTH (meas_date);
create index CTD.f_GTWY_mo8 on CTD.F_GTWY_MONTH (INST_id);  
create index CTD.f_GTWY_mo9 on CTD.F_GTWY_MONTH (Inst_Vers_id);
create index CTD.f_GTWY_mo60 on CTD.F_GTWY_MONTH (host_ip_ad_id);

alter table CTD.F_GTWY_MONTH
add constraint K50
foreign key (GTWY_id)
references CTD.D_GTWY (GTWY_id);

alter table CTD.F_GTWY_MONTH
add constraint K51
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_GTWY_MONTH
add constraint K52
foreign key (metric_id)
references CTD.D_GTWY_METRIC (metric_id);    

alter table CTD.F_GTWY_MONTH
add constraint K67
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_GTWY_MONTH
add constraint K61
foreign key (INST_id)
references CTD.D_INST (INST_id);

alter table CTD.F_GTWY_MONTH
add constraint K657
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);
--------------------
---  NODE 
--------------------

---------------------------------
-- dimension table: NODE metric 
---------------------------------

create table CTD.d_NODE_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_NODE_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.NODEmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.NODEmt_i1
no cascade before insert on CTD.d_NODE_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.NODEmt_id_seq;

-----------------------------
-- dimension table: NODE 
-----------------------------

create table CTD.D_NODE (
 Node_Number	varchar(254),
 Node_Hostname	varchar(254), 
 NODE_id     	integer        not null,  
 Node_Port_Number 		varchar(254),
      primary key (NODE_id));

-- translation table

create table CTD.T_NODE (
 Node_Number	varchar(254),
 Node_Hostname	varchar(254), 
 orig_NODE_id         integer        not null,  
 Node_Port_Number 		varchar(254),
 cdw_id			 integer        not null, 
 NODE_id              integer not null,
      primary key (orig_NODE_id,cdw_id)
      );

--sequence      

create sequence CTD.NODE_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.NODE_i1
no cascade before insert on CTD.d_NODE  
referencing new as n for each row mode db2sql
set n.NODE_id = nextval for CTD.NODE_id_seq;
      

-----------------------------
-- dimension table:Nd_LGPTH 
-----------------------------

create table CTD.D_Nd_LGPTH (
 Nd_LGPTH_id    	           integer        not null,
 Nd_LGPTH                   varchar(254)   not null,
      primary key (Nd_LGPTH_ID));

  
--sequence      

create sequence CTD.Nd_LGPTH_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.Nd_LGPTH_i1
no cascade before insert on CTD.d_Nd_LGPTH 
referencing new as n for each row mode db2sql
set n.Nd_LGPTH_id = nextval for CTD.Nd_LGPTH_id_seq;     
      
--staging hour fact table
create table CTD.STG_NODE_HR (
    msmt_id		   integer	  not null,
    orig_NODE_id    integer        not null,
    Nd_LGPTH    varchar(254) not null,
    orig_DB_id	   integer	  not null,
    orig_INST_id	   integer	  not null,
    Inst_Vers    varchar(254) not null,
    orig_host_id           integer        not null,
    Host_ip_ad		  varchar(254) not null,
    orig_metric_id         integer        not null,
    cdw_id		   integer        not null,
    meas_HOUR              timestamp      not null,
    min_value		   float,
    max_value	           float,
    avg_value       	   float,
    total_value		   float,
    sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: NODE 
-----------------------------

create table CTD.F_NODE_HOUR (
 NODE_id            integer       not null, 
 Nd_LGPTH_id 	integer not null,
 DB_id		   integer 	 not null, 
 INST_id		   integer 	 not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer       not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer       not null,
 meas_HOUR                 timestamp     not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (NODE_id, 
       Nd_LGPTH_id, DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, meas_HOUR)
       );

create index CTD.f_NODE_hr1 on CTD.F_NODE_HOUR (NODE_id);
create index CTD.f_NODE_hr2 on CTD.F_NODE_HOUR (host_id);
create index CTD.f_NODE_hr3 on CTD.F_NODE_HOUR (metric_id);
create index CTD.f_NODE_hr4 on CTD.F_NODE_HOUR (meas_hour); 
create index CTD.f_NODE_hr13 on CTD.F_NODE_HOUR (DB_id); 
create index CTD.f_NODE_hr12 on CTD.F_NODE_HOUR (Nd_LGPTH_id); 
create index CTD.f_NODE_hr14 on CTD.F_NODE_HOUR (INST_id); 
create index CTD.f_NODE_hr15 on CTD.F_NODE_HOUR (Inst_Vers_id); 
create index CTD.f_NODE_hr60 on CTD.F_NODE_HOUR (host_ip_ad_id);

alter table CTD.F_NODE_HOUR
add constraint K94
foreign key (NODE_id)
references CTD.D_NODE (NODE_id);

alter table CTD.F_NODE_HOUR
add constraint K95
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_NODE_HOUR
add constraint K96
foreign key (metric_id)
references CTD.D_NODE_METRIC (metric_id); 

alter table CTD.F_NODE_HOUR
add constraint K105
foreign key (Nd_LGPTH_id)
references CTD.D_Nd_LGPTH (Nd_LGPTH_id); 

alter table CTD.F_NODE_HOUR
add constraint K109
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_NODE_HOUR
add constraint K120
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_NODE_HOUR
add constraint K131
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_NODE_HOUR
add constraint K662
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: NODE 
-----------------------------

create table CTD.F_NODE_DAY (
 NODE_id            integer not null, 
 Nd_LGPTH_id 	integer not null,
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (NODE_id, 
       Nd_LGPTH_id, DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_NODE_day1 on CTD.F_NODE_DAY (NODE_id);
create index CTD.f_NODE_day2 on CTD.F_NODE_DAY (host_id);
create index CTD.f_NODE_day3 on CTD.F_NODE_DAY (metric_id);
create index CTD.f_NODE_day4 on CTD.F_NODE_DAY (meas_date);
create index CTD.f_NODE_day13 on CTD.F_NODE_DAY (DB_id); 
create index CTD.f_NODE_day125 on CTD.F_NODE_DAY (Nd_LGPTH_id); 
create index CTD.f_NODE_day14 on CTD.F_NODE_DAY (INST_id); 
create index CTD.f_NODE_day15 on CTD.F_NODE_DAY (Inst_Vers_id);
create index CTD.f_NODE_day60 on CTD.F_NODE_DAY (host_ip_ad_id);

alter table CTD.F_NODE_DAY
add constraint K97
foreign key (NODE_id)
references CTD.D_NODE (NODE_id);

alter table CTD.F_NODE_DAY
add constraint K98
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_NODE_DAY
add constraint K99
foreign key (metric_id)
references CTD.D_NODE_METRIC (metric_id);  

alter table CTD.F_NODE_DAY
add constraint K106
foreign key (Nd_LGPTH_id)
references CTD.D_Nd_LGPTH (Nd_LGPTH_id); 

alter table CTD.F_NODE_day
add constraint K111
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_NODE_day
add constraint K122
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_NODE_day
add constraint K132
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_NODE_DAY
add constraint K663
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- weekly fact table: NODE 
-----------------------------

create table CTD.F_NODE_WEEK (
 NODE_id            integer not null, 
 Nd_LGPTH_id 	integer not null,
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (NODE_id, 
       Nd_LGPTH_id, DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_NODE_wk1 on CTD.F_NODE_WEEK (NODE_id);
create index CTD.f_NODE_wk2 on CTD.F_NODE_WEEK (host_id);
create index CTD.f_NODE_wk3 on CTD.F_NODE_WEEK (metric_id);
create index CTD.f_NODE_wk4 on CTD.F_NODE_WEEK (meas_date);
create index CTD.f_NODE_wk13 on CTD.F_NODE_WEEK (DB_id); 
create index CTD.f_NODE_wk125 on CTD.F_NODE_WEEK (Nd_LGPTH_id); 
create index CTD.f_NODE_wk14 on CTD.F_NODE_WEEK (INST_id); 
create index CTD.f_NODE_wk15 on CTD.F_NODE_WEEK (Inst_Vers_id);
create index CTD.f_NODE_wk60 on CTD.F_NODE_WEEK (host_ip_ad_id);

alter table CTD.F_NODE_WEEK
add constraint K100
foreign key (NODE_id)
references CTD.D_NODE (NODE_id);

alter table CTD.F_NODE_WEEK
add constraint K101
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_NODE_WEEK
add constraint K102
foreign key (metric_id)
references CTD.D_NODE_METRIC (metric_id); 

alter table CTD.F_NODE_WEEK
add constraint K107
foreign key (Nd_LGPTH_id)
references CTD.D_Nd_LGPTH (Nd_LGPTH_id); 

alter table CTD.F_NODE_WEEK
add constraint K114
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_NODE_WEEK
add constraint K125
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_NODE_WEEK
add constraint K133
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_NODE_WEEK
add constraint K664
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: NODE 
-----------------------------

create table CTD.F_NODE_MONTH (
 NODE_id            integer not null, 
 Nd_LGPTH_id 	integer not null,
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (NODE_id, 
       Nd_LGPTH_id, DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_NODE_mo1 on CTD.F_NODE_MONTH (NODE_id);
create index CTD.f_NODE_mo2 on CTD.F_NODE_MONTH (host_id);
create index CTD.f_NODE_mo3 on CTD.F_NODE_MONTH (metric_id);
create index CTD.f_NODE_mo4 on CTD.F_NODE_MONTH (meas_date);
create index CTD.f_NODE_mo13 on CTD.F_NODE_MONTH (DB_id);  
create index CTD.f_NODE_mo125 on CTD.F_NODE_MONTH (Nd_LGPTH_id); 
create index CTD.f_NODE_mo14 on CTD.F_NODE_MONTH (INST_id); 
create index CTD.f_NODE_mo15 on CTD.F_NODE_MONTH (Inst_Vers_id);
create index CTD.f_NODE_mo60 on CTD.F_NODE_MONTH (host_ip_ad_id);

alter table CTD.F_NODE_MONTH
add constraint K102
foreign key (NODE_id)
references CTD.D_NODE (NODE_id);

alter table CTD.F_NODE_MONTH
add constraint K103
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_NODE_MONTH
add constraint K104
foreign key (metric_id)
references CTD.D_NODE_METRIC (metric_id);   

alter table CTD.F_NODE_MONTH
add constraint K108
foreign key (Nd_LGPTH_id)
references CTD.D_Nd_LGPTH (Nd_LGPTH_id); 

alter table CTD.F_NODE_MONTH
add constraint K117
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_NODE_MONTH
add constraint K128
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_NODE_MONTH
add constraint K134
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_NODE_MONTH
add constraint K665
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

--------------------
---  APPLY 
--------------------

---------------------------------
-- dimension table: APPLY metric 
---------------------------------

create table CTD.d_APPLY_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_APPLY_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.APLYmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.APLYmt_i1
no cascade before insert on CTD.d_APPLY_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.APLYmt_id_seq;

-----------------------------
-- dimension table: APPLY 
-----------------------------

create table CTD.D_APPLY (
 ApplyID	varchar(254), 
 APPLY_id     	integer        not null, 
      primary key (APPLY_id));

-- translation table

create table CTD.T_APPLY (
 ApplyID	varchar(254), 
 orig_APPLY_id         integer        not null, 
 cdw_id			 integer        not null, 
 APPLY_id              integer not null,
      primary key (orig_APPLY_id,cdw_id)
      );

--sequence      

create sequence CTD.APLY_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.APLY_i1
no cascade before insert on CTD.d_APPLY  
referencing new as n for each row mode db2sql
set n.APPLY_id = nextval for CTD.APLY_id_seq;
      

--staging hour fact table
create table CTD.STG_APPLY_HR (
    msmt_id		   integer	  not null,
    orig_APPLY_id    integer        not null,
    orig_DB_id	   integer	  not null,
    orig_INST_id	   integer	  not null,
    Inst_Vers    varchar(254) not null,
    orig_host_id           integer        not null,
    Host_ip_ad		  varchar(254) not null,
    orig_metric_id         integer        not null,
    cdw_id		   integer        not null,
    meas_HOUR              timestamp      not null,
    min_value		   float,
    max_value	           float,
    avg_value       	   float,
    total_value		   float,
    sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: APPLY 
-----------------------------

create table CTD.F_APPLY_HOUR (
 APPLY_id            integer       not null, 
 DB_id		   integer 	 not null, 
 INST_id		   integer 	 not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer       not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer       not null,
 meas_HOUR                 timestamp     not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (APPLY_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, meas_HOUR)
       );

create index CTD.f_APLY_hr1 on CTD.F_APPLY_HOUR (APPLY_id);
create index CTD.f_APLY_hr2 on CTD.F_APPLY_HOUR (host_id);
create index CTD.f_APLY_hr3 on CTD.F_APPLY_HOUR (metric_id);
create index CTD.f_APLY_hr4 on CTD.F_APPLY_HOUR (meas_hour); 
create index CTD.f_APLY_hr16 on CTD.F_APPLY_HOUR (DB_id);  
create index CTD.f_APLY_hr17 on CTD.F_APPLY_HOUR (INST_id); 
create index CTD.f_APLY_hr18 on CTD.F_APPLY_HOUR (Inst_Vers_id); 
create index CTD.f_APLY_hr60 on CTD.F_APPLY_HOUR (host_ip_ad_id);

alter table CTD.F_APPLY_HOUR
add constraint K135
foreign key (APPLY_id)
references CTD.D_APPLY (APPLY_id);

alter table CTD.F_APPLY_HOUR
add constraint K136
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_APPLY_HOUR
add constraint K137
foreign key (metric_id)
references CTD.D_APPLY_METRIC (metric_id);  

alter table CTD.F_APPLY_HOUR
add constraint K146
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_APPLY_HOUR
add constraint K157
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_APPLY_HOUR
add constraint K168
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_APPLY_HOUR
add constraint K666
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: APPLY 
-----------------------------

create table CTD.F_APPLY_DAY (
 APPLY_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (APPLY_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_APLY_day1 on CTD.F_APPLY_DAY (APPLY_id);
create index CTD.f_APLY_day2 on CTD.F_APPLY_DAY (host_id);
create index CTD.f_APLY_day3 on CTD.F_APPLY_DAY (metric_id);
create index CTD.f_APLY_day4 on CTD.F_APPLY_DAY (meas_date);
create index CTD.f_APLY_day16 on CTD.F_APPLY_DAY (DB_id);  
create index CTD.f_APLY_day17 on CTD.F_APPLY_DAY (INST_id); 
create index CTD.f_APLY_day18 on CTD.F_APPLY_DAY (Inst_Vers_id);
create index CTD.f_APLY_day60 on CTD.F_APPLY_DAY (host_ip_ad_id);

alter table CTD.F_APPLY_DAY
add constraint K138
foreign key (APPLY_id)
references CTD.D_APPLY (APPLY_id);

alter table CTD.F_APPLY_DAY
add constraint K139
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_APPLY_DAY
add constraint K140
foreign key (metric_id)
references CTD.D_APPLY_METRIC (metric_id);   

alter table CTD.F_APPLY_day
add constraint K148
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_APPLY_day
add constraint K159
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_APPLY_day
add constraint K169
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_APPLY_DAY
add constraint K667
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- weekly fact table: APPLY 
-----------------------------

create table CTD.F_APPLY_WEEK (
 APPLY_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (APPLY_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_APLY_wk1 on CTD.F_APPLY_WEEK (APPLY_id);
create index CTD.f_APLY_wk2 on CTD.F_APPLY_WEEK (host_id);
create index CTD.f_APLY_wk3 on CTD.F_APPLY_WEEK (metric_id);
create index CTD.f_APLY_wk4 on CTD.F_APPLY_WEEK (meas_date);
create index CTD.f_APLY_wk16 on CTD.F_APPLY_WEEK (DB_id);  
create index CTD.f_APLY_wk17 on CTD.F_APPLY_WEEK (INST_id); 
create index CTD.f_APLY_wk18 on CTD.F_APPLY_WEEK (Inst_Vers_id);
create index CTD.f_APLY_wk60 on CTD.F_APPLY_WEEK (host_ip_ad_id);

alter table CTD.F_APPLY_WEEK
add constraint K141
foreign key (APPLY_id)
references CTD.D_APPLY (APPLY_id);

alter table CTD.F_APPLY_WEEK
add constraint K142
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_APPLY_WEEK
add constraint K143
foreign key (metric_id)
references CTD.D_APPLY_METRIC (metric_id);  

alter table CTD.F_APPLY_WEEK
add constraint K151
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_APPLY_WEEK
add constraint K162
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_APPLY_WEEK
add constraint K170
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_APPLY_WEEK
add constraint K668
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: APPLY 
-----------------------------

create table CTD.F_APPLY_MONTH (
 APPLY_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (APPLY_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_APLY_mo1 on CTD.F_APPLY_MONTH (APPLY_id);
create index CTD.f_APLY_mo2 on CTD.F_APPLY_MONTH (host_id);
create index CTD.f_APLY_mo3 on CTD.F_APPLY_MONTH (metric_id);
create index CTD.f_APLY_mo4 on CTD.F_APPLY_MONTH (meas_date);
create index CTD.f_APLY_mo16 on CTD.F_APPLY_MONTH (DB_id);  
create index CTD.f_APLY_mo17 on CTD.F_APPLY_MONTH (INST_id); 
create index CTD.f_APLY_mo18 on CTD.F_APPLY_MONTH (Inst_Vers_id);
create index CTD.f_APLY_mo60 on CTD.F_APPLY_MONTH (host_ip_ad_id);

alter table CTD.F_APPLY_MONTH
add constraint K143
foreign key (APPLY_id)
references CTD.D_APPLY (APPLY_id);

alter table CTD.F_APPLY_MONTH
add constraint K144
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_APPLY_MONTH
add constraint K145
foreign key (metric_id)
references CTD.D_APPLY_METRIC (metric_id);    

alter table CTD.F_APPLY_MONTH
add constraint K154
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_APPLY_MONTH
add constraint K165
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_APPLY_MONTH
add constraint K171
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_APPLY_MONTH
add constraint K669
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

--------------------
---  TABLE 
--------------------

---------------------------------
-- dimension table: TABLE metric 
---------------------------------

create table CTD.d_TABLE_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_TABLE_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.TABLmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.TABLmt_i1
no cascade before insert on CTD.d_TABLE_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.TABLmt_id_seq;

-----------------------------
-- dimension table: TABLE 
-----------------------------

create table CTD.D_TABLE (
 Table_Nm	varchar(254),
	Table_Owner	varchar(254), 
 TABLE_id     	integer        not null, 
      primary key (TABLE_id));

-- translation table

create table CTD.T_TABLE (
 Table_Nm	varchar(254),
	Table_Owner	varchar(254), 
 orig_TABLE_id         integer        not null, 
 cdw_id			 integer        not null, 
 TABLE_id              integer not null,
      primary key (orig_TABLE_id,cdw_id)
      );

--sequence      

create sequence CTD.TABL_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.TABL_i1
no cascade before insert on CTD.d_TABLE  
referencing new as n for each row mode db2sql
set n.TABLE_id = nextval for CTD.TABL_id_seq;
      

--staging hour fact table
create table CTD.STG_TABLE_HR (
    msmt_id		   integer	  not null,
    orig_TABLE_id    integer        not null,
    orig_DB_id	   integer	  not null,
    orig_INST_id	   integer	  not null,
    Inst_Vers    varchar(254) not null,
    orig_host_id           integer        not null,
    Host_ip_ad		  varchar(254) not null,
    orig_metric_id         integer        not null,
    cdw_id		   integer        not null,
    meas_HOUR              timestamp      not null,
    min_value		   float,
    max_value	           float,
    avg_value       	   float,
    total_value		   float,
    sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: TABLE 
-----------------------------

create table CTD.F_TABLE_HOUR (
 TABLE_id            integer       not null, 
 DB_id		   integer 	 not null, 
 INST_id		   integer 	 not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer       not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer       not null,
 meas_HOUR                 timestamp     not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TABLE_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, meas_HOUR)
       );

create index CTD.f_TABL_hr1 on CTD.F_TABLE_HOUR (TABLE_id);
create index CTD.f_TABL_hr2 on CTD.F_TABLE_HOUR (host_id);
create index CTD.f_TABL_hr3 on CTD.F_TABLE_HOUR (metric_id);
create index CTD.f_TABL_hr4 on CTD.F_TABLE_HOUR (meas_hour); 
create index CTD.f_TABL_hr19 on CTD.F_TABLE_HOUR (DB_id);  
create index CTD.f_TABL_hr20 on CTD.F_TABLE_HOUR (INST_id); 
create index CTD.f_TABL_hr21 on CTD.F_TABLE_HOUR (Inst_Vers_id); 
create index CTD.f_TABL_hr60 on CTD.F_TABLE_HOUR (host_ip_ad_id);

alter table CTD.F_TABLE_HOUR
add constraint K172
foreign key (TABLE_id)
references CTD.D_TABLE (TABLE_id);

alter table CTD.F_TABLE_HOUR
add constraint K173
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TABLE_HOUR
add constraint K174
foreign key (metric_id)
references CTD.D_TABLE_METRIC (metric_id);  

alter table CTD.F_TABLE_HOUR
add constraint K183
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TABLE_HOUR
add constraint K194
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TABLE_HOUR
add constraint K205
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TABLE_HOUR
add constraint K670
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: TABLE 
-----------------------------

create table CTD.F_TABLE_DAY (
 TABLE_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TABLE_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TABL_day1 on CTD.F_TABLE_DAY (TABLE_id);
create index CTD.f_TABL_day2 on CTD.F_TABLE_DAY (host_id);
create index CTD.f_TABL_day3 on CTD.F_TABLE_DAY (metric_id);
create index CTD.f_TABL_day4 on CTD.F_TABLE_DAY (meas_date);
create index CTD.f_TABL_day19 on CTD.F_TABLE_DAY (DB_id);  
create index CTD.f_TABL_day20 on CTD.F_TABLE_DAY (INST_id); 
create index CTD.f_TABL_day21 on CTD.F_TABLE_DAY (Inst_Vers_id);
create index CTD.f_TABL_day60 on CTD.F_TABLE_DAY (host_ip_ad_id);

alter table CTD.F_TABLE_DAY
add constraint K175
foreign key (TABLE_id)
references CTD.D_TABLE (TABLE_id);

alter table CTD.F_TABLE_DAY
add constraint K176
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TABLE_DAY
add constraint K177
foreign key (metric_id)
references CTD.D_TABLE_METRIC (metric_id);   

alter table CTD.F_TABLE_day
add constraint K185
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TABLE_day
add constraint K196
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TABLE_day
add constraint K206
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TABLE_DAY
add constraint K671
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- weekly fact table: TABLE 
-----------------------------

create table CTD.F_TABLE_WEEK (
 TABLE_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TABLE_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id,  host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TABL_wk1 on CTD.F_TABLE_WEEK (TABLE_id);
create index CTD.f_TABL_wk2 on CTD.F_TABLE_WEEK (host_id);
create index CTD.f_TABL_wk3 on CTD.F_TABLE_WEEK (metric_id);
create index CTD.f_TABL_wk4 on CTD.F_TABLE_WEEK (meas_date);
create index CTD.f_TABL_wk19 on CTD.F_TABLE_WEEK (DB_id);  
create index CTD.f_TABL_wk20 on CTD.F_TABLE_WEEK (INST_id); 
create index CTD.f_TABL_wk21 on CTD.F_TABLE_WEEK (Inst_Vers_id);
create index CTD.f_TABL_wk60 on CTD.F_TABLE_WEEK (host_ip_ad_id);

alter table CTD.F_TABLE_WEEK
add constraint K178
foreign key (TABLE_id)
references CTD.D_TABLE (TABLE_id);

alter table CTD.F_TABLE_WEEK
add constraint K179
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TABLE_WEEK
add constraint K180
foreign key (metric_id)
references CTD.D_TABLE_METRIC (metric_id);  

alter table CTD.F_TABLE_WEEK
add constraint K188
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TABLE_WEEK
add constraint K199
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TABLE_WEEK
add constraint K207
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TABLE_WEEK
add constraint K672
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: TABLE 
-----------------------------

create table CTD.F_TABLE_MONTH (
 TABLE_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TABLE_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TABL_mo1 on CTD.F_TABLE_MONTH (TABLE_id);
create index CTD.f_TABL_mo2 on CTD.F_TABLE_MONTH (host_id);
create index CTD.f_TABL_mo3 on CTD.F_TABLE_MONTH (metric_id);
create index CTD.f_TABL_mo4 on CTD.F_TABLE_MONTH (meas_date);
create index CTD.f_TABL_mo19 on CTD.F_TABLE_MONTH (DB_id);  
create index CTD.f_TABL_mo20 on CTD.F_TABLE_MONTH (INST_id); 
create index CTD.f_TABL_mo21 on CTD.F_TABLE_MONTH (Inst_Vers_id);
create index CTD.f_TABL_mo60 on CTD.F_TABLE_MONTH (host_ip_ad_id);

alter table CTD.F_TABLE_MONTH
add constraint K180
foreign key (TABLE_id)
references CTD.D_TABLE (TABLE_id);

alter table CTD.F_TABLE_MONTH
add constraint K181
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_TABLE_MONTH
add constraint K182
foreign key (metric_id)
references CTD.D_TABLE_METRIC (metric_id);    

alter table CTD.F_TABLE_MONTH
add constraint K191
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TABLE_MONTH
add constraint K202
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TABLE_MONTH
add constraint K208
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TABLE_MONTH
add constraint K673
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

--------------------
---  APPL 
--------------------

---------------------------------
-- dimension table: APPL metric 
---------------------------------

create table CTD.d_APPL_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_APPL_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.APPLmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.APPLmt_i1
no cascade before insert on CTD.d_APPL_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.APPLmt_id_seq;

-----------------------------
-- dimension table: APPL 
-----------------------------

create table CTD.D_APPL (
 Appl_Nm	varchar(254), 
 APPL_id     	integer        not null, 
      primary key (APPL_id));

-- translation table

create table CTD.T_APPL (
 Appl_Nm	varchar(254), 
 orig_APPL_id         integer        not null, 
 cdw_id			 integer        not null, 
 APPL_id              integer not null,
      primary key (orig_APPL_id,cdw_id)
      );

--sequence      

create sequence CTD.APPL_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.APPL_i1
no cascade before insert on CTD.d_APPL  
referencing new as n for each row mode db2sql
set n.APPL_id = nextval for CTD.APPL_id_seq;
      

--staging hour fact table
create table CTD.STG_APPL_HR (
    msmt_id		   integer	  not null,
    orig_APPL_id    integer        not null,
    orig_DB_id	   integer	  not null,
    orig_INST_id	   integer	  not null,
    Inst_Vers    varchar(254) not null,
    orig_host_id           integer        not null,
    Host_ip_ad		  varchar(254) not null,
    orig_metric_id         integer        not null,
    cdw_id		   integer        not null,
    meas_HOUR              timestamp      not null,
    min_value		   float,
    max_value	           float,
    avg_value       	   float,
    total_value		   float,
    sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: APPL 
-----------------------------

create table CTD.F_APPL_HOUR (
 APPL_id            integer       not null, 
 DB_id		   integer 	 not null, 
 INST_id		   integer 	 not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer       not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer       not null,
 meas_HOUR                 timestamp     not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (APPL_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, meas_HOUR)
       );

create index CTD.f_APPL_hr1 on CTD.F_APPL_HOUR (APPL_id);
create index CTD.f_APPL_hr2 on CTD.F_APPL_HOUR (host_id);
create index CTD.f_APPL_hr3 on CTD.F_APPL_HOUR (metric_id);
create index CTD.f_APPL_hr4 on CTD.F_APPL_HOUR (meas_hour); 
create index CTD.f_APPL_hr22 on CTD.F_APPL_HOUR (DB_id);  
create index CTD.f_APPL_hr23 on CTD.F_APPL_HOUR (INST_id); 
create index CTD.f_APPL_hr24 on CTD.F_APPL_HOUR (Inst_Vers_id); 
create index CTD.f_APPL_hr60 on CTD.F_APPL_HOUR (host_ip_ad_id);

alter table CTD.F_APPL_HOUR
add constraint K209
foreign key (APPL_id)
references CTD.D_APPL (APPL_id);

alter table CTD.F_APPL_HOUR
add constraint K210
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_APPL_HOUR
add constraint K211
foreign key (metric_id)
references CTD.D_APPL_METRIC (metric_id);  

alter table CTD.F_APPL_HOUR
add constraint K220
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_APPL_HOUR
add constraint K231
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_APPL_HOUR
add constraint K242
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_APPL_HOUR
add constraint K674
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: APPL 
-----------------------------

create table CTD.F_APPL_DAY (
 APPL_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (APPL_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_APPL_day1 on CTD.F_APPL_DAY (APPL_id);
create index CTD.f_APPL_day2 on CTD.F_APPL_DAY (host_id);
create index CTD.f_APPL_day3 on CTD.F_APPL_DAY (metric_id);
create index CTD.f_APPL_day4 on CTD.F_APPL_DAY (meas_date);
create index CTD.f_APPL_day22 on CTD.F_APPL_DAY (DB_id);  
create index CTD.f_APPL_day23 on CTD.F_APPL_DAY (INST_id); 
create index CTD.f_APPL_day24 on CTD.F_APPL_DAY (Inst_Vers_id);
create index CTD.f_APPL_day60 on CTD.F_APPL_DAY (host_ip_ad_id);

alter table CTD.F_APPL_DAY
add constraint K212
foreign key (APPL_id)
references CTD.D_APPL (APPL_id);

alter table CTD.F_APPL_DAY
add constraint K213
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_APPL_DAY
add constraint K214
foreign key (metric_id)
references CTD.D_APPL_METRIC (metric_id);   

alter table CTD.F_APPL_day
add constraint K222
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_APPL_day
add constraint K233
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_APPL_day
add constraint K243
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_APPL_DAY
add constraint K675
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- weekly fact table: APPL 
-----------------------------

create table CTD.F_APPL_WEEK (
 APPL_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (APPL_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_APPL_wk1 on CTD.F_APPL_WEEK (APPL_id);
create index CTD.f_APPL_wk2 on CTD.F_APPL_WEEK (host_id);
create index CTD.f_APPL_wk3 on CTD.F_APPL_WEEK (metric_id);
create index CTD.f_APPL_wk4 on CTD.F_APPL_WEEK (meas_date);
create index CTD.f_APPL_wk22 on CTD.F_APPL_WEEK (DB_id);  
create index CTD.f_APPL_wk23 on CTD.F_APPL_WEEK (INST_id); 
create index CTD.f_APPL_wk24 on CTD.F_APPL_WEEK (Inst_Vers_id);
create index CTD.f_APPL_wk60 on CTD.F_APPL_WEEK (host_ip_ad_id);

alter table CTD.F_APPL_WEEK
add constraint K215
foreign key (APPL_id)
references CTD.D_APPL (APPL_id);

alter table CTD.F_APPL_WEEK
add constraint K216
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_APPL_WEEK
add constraint K217
foreign key (metric_id)
references CTD.D_APPL_METRIC (metric_id);  

alter table CTD.F_APPL_WEEK
add constraint K225
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_APPL_WEEK
add constraint K236
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_APPL_WEEK
add constraint K244
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_APPL_WEEK
add constraint K676
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: APPL 
-----------------------------

create table CTD.F_APPL_MONTH (
 APPL_id            integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (APPL_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_APPL_mo1 on CTD.F_APPL_MONTH (APPL_id);
create index CTD.f_APPL_mo2 on CTD.F_APPL_MONTH (host_id);
create index CTD.f_APPL_mo3 on CTD.F_APPL_MONTH (metric_id);
create index CTD.f_APPL_mo4 on CTD.F_APPL_MONTH (meas_date);
create index CTD.f_APPL_mo22 on CTD.F_APPL_MONTH (DB_id);  
create index CTD.f_APPL_mo23 on CTD.F_APPL_MONTH (INST_id); 
create index CTD.f_APPL_mo24 on CTD.F_APPL_MONTH (Inst_Vers_id);
create index CTD.f_APPL_mo60 on CTD.F_APPL_MONTH (host_ip_ad_id);

alter table CTD.F_APPL_MONTH
add constraint K217
foreign key (APPL_id)
references CTD.D_APPL (APPL_id);

alter table CTD.F_APPL_MONTH
add constraint K218
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_APPL_MONTH
add constraint K219
foreign key (metric_id)
references CTD.D_APPL_METRIC (metric_id);    

alter table CTD.F_APPL_MONTH
add constraint K228
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_APPL_MONTH
add constraint K239
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_APPL_MONTH
add constraint K245
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_APPL_MONTH
add constraint K677
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);


--------------------
---  TBSP 
--------------------


---------------------------------
-- dimension table: TBSP_ND metric 
---------------------------------

create table CTD.d_TBSP_ND_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_TBSP_ND_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.TBSNmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.TBSNmt_i1
no cascade before insert on CTD.d_TBSP_ND_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.TBSNmt_id_seq;

-----------------------------
-- dimension table: TBSP_ND 
-----------------------------

create table CTD.D_TBSP_ND (
 Tbsp_Nd_Nm	varchar(254), 
 TBSP_ND_id     	integer        not null, 
      primary key (TBSP_ND_id));

-- translation table

create table CTD.T_TBSP_ND (
 Tbsp_Nd_Nm	varchar(254), 
 orig_TBSP_ND_id         integer        not null, 
 cdw_id			 integer        not null, 
 TBSP_ND_id              integer not null,
      primary key (orig_TBSP_ND_id,cdw_id)
      );

--sequence      

create sequence CTD.TBSN_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.TBSN_i1
no cascade before insert on CTD.d_TBSP_ND  
referencing new as n for each row mode db2sql
set n.TBSP_ND_id = nextval for CTD.TBSN_id_seq;
      

--staging hour fact table
create table CTD.STG_TBSP_ND_HR (
    msmt_id		   integer	  not null,
    orig_TBSP_ND_id    integer        not null,
    orig_NODE_id	   integer	  not null,
    Nd_LGPTH    varchar(254) not null,
    orig_DB_id	   integer	  not null,
    orig_INST_id	   integer	  not null,
    Inst_Vers    varchar(254) not null,
    orig_host_id           integer        not null,
    Host_ip_ad		  varchar(254) not null,
    orig_metric_id         integer        not null,
    cdw_id		   integer        not null,
    meas_HOUR              timestamp      not null,
    min_value		   float,
    max_value	           float,
    avg_value       	   float,
    total_value		   float,
    sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: TBSP_ND 
-----------------------------

create table CTD.F_TBSP_ND_HOUR (
 TBSP_ND_id            integer       not null, 
 NODE_id		   integer 	 not null, 
 Nd_LGPTH_id		integer not null,
 DB_id		   integer 	 not null, 
 INST_id		   integer 	 not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer       not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer       not null,
 meas_HOUR                 timestamp     not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TBSP_ND_id,  NODE_id, 
       Nd_LGPTH_id, DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, meas_HOUR)
       );

create index CTD.f_TBSN_hr1 on CTD.F_TBSP_ND_HOUR (TBSP_ND_id);
create index CTD.f_TBSN_hr2 on CTD.F_TBSP_ND_HOUR (host_id);
create index CTD.f_TBSN_hr3 on CTD.F_TBSP_ND_HOUR (metric_id);
create index CTD.f_TBSN_hr4 on CTD.F_TBSP_ND_HOUR (meas_hour); 
create index CTD.f_TBSN_hr40 on CTD.F_TBSP_ND_HOUR (NODE_id);  
create index CTD.f_TBSN_hr41 on CTD.F_TBSP_ND_HOUR (Nd_LGPTH_id);
create index CTD.f_TBSN_hr42 on CTD.F_TBSP_ND_HOUR (DB_id);  
create index CTD.f_TBSN_hr43 on CTD.F_TBSP_ND_HOUR (INST_id); 
create index CTD.f_TBSN_hr44 on CTD.F_TBSP_ND_HOUR (Inst_Vers_id);
create index CTD.f_TBSN_hr60 on CTD.F_TBSP_ND_HOUR (host_ip_ad_id);

alter table CTD.F_TBSP_ND_HOUR
add constraint K431
foreign key (TBSP_ND_id)
references CTD.D_TBSP_ND (TBSP_ND_id);

alter table CTD.F_TBSP_ND_HOUR
add constraint K432
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TBSP_ND_HOUR
add constraint K433
foreign key (metric_id)
references CTD.D_TBSP_ND_METRIC (metric_id);  

alter table CTD.F_TBSP_ND_HOUR
add constraint K442
foreign key (NODE_id)
references CTD.D_NODE (NODE_id); 

alter table CTD.F_TBSP_ND_HOUR
add constraint K453
foreign key (Nd_LGPTH_id)
references CTD.D_Nd_LGPTH (Nd_LGPTH_id);

alter table CTD.F_TBSP_ND_HOUR
add constraint K457
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TBSP_ND_HOUR
add constraint K468
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TBSP_ND_HOUR
add constraint K479
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TBSP_ND_HOUR
add constraint K698
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: TBSP_ND 
-----------------------------

create table CTD.F_TBSP_ND_DAY (
 TBSP_ND_id            integer not null, 
 NODE_id		   integer not null, 
 Nd_LGPTH_id		integer not null,
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TBSP_ND_id,  NODE_id, 
       Nd_LGPTH_id, DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TBSN_day1 on CTD.F_TBSP_ND_DAY (TBSP_ND_id);
create index CTD.f_TBSN_day2 on CTD.F_TBSP_ND_DAY (host_id);
create index CTD.f_TBSN_day3 on CTD.F_TBSP_ND_DAY (metric_id);
create index CTD.f_TBSN_day4 on CTD.F_TBSP_ND_DAY (meas_date);
create index CTD.f_TBSN_day40 on CTD.F_TBSP_ND_DAY (NODE_id);  
create index CTD.f_TBSN_day41 on CTD.F_TBSP_ND_DAY (Nd_LGPTH_id);
create index CTD.f_TBSN_day42 on CTD.F_TBSP_ND_DAY (DB_id); 
create index CTD.f_TBSN_day43 on CTD.F_TBSP_ND_DAY (INST_id); 
create index CTD.f_TBSN_day44 on CTD.F_TBSP_ND_DAY (Inst_Vers_id);
create index CTD.f_TBSN_day60 on CTD.F_TBSP_ND_DAY (host_ip_ad_id);

alter table CTD.F_TBSP_ND_DAY
add constraint K434
foreign key (TBSP_ND_id)
references CTD.D_TBSP_ND (TBSP_ND_id);

alter table CTD.F_TBSP_ND_DAY
add constraint K435
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TBSP_ND_DAY
add constraint K436
foreign key (metric_id)
references CTD.D_TBSP_ND_METRIC (metric_id);   

alter table CTD.F_TBSP_ND_day
add constraint K444
foreign key (NODE_id)
references CTD.D_NODE (NODE_id); 

alter table CTD.F_TBSP_ND_day
add constraint K454
foreign key (Nd_LGPTH_id)
references CTD.D_Nd_LGPTH (Nd_LGPTH_id);

alter table CTD.F_TBSP_ND_day
add constraint K459
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TBSP_ND_day
add constraint K470
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TBSP_ND_day
add constraint K480
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TBSP_ND_DAY
add constraint K699
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- weekly fact table: TBSP_ND 
-----------------------------

create table CTD.F_TBSP_ND_WEEK (
 TBSP_ND_id            integer not null, 
 NODE_id		   integer not null, 
 Nd_LGPTH_id		integer not null,
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TBSP_ND_id,  NODE_id, 
       Nd_LGPTH_id, DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TBSN_wk1 on CTD.F_TBSP_ND_WEEK (TBSP_ND_id);
create index CTD.f_TBSN_wk2 on CTD.F_TBSP_ND_WEEK (host_id);
create index CTD.f_TBSN_wk3 on CTD.F_TBSP_ND_WEEK (metric_id);
create index CTD.f_TBSN_wk4 on CTD.F_TBSP_ND_WEEK (meas_date);
create index CTD.f_TBSN_wk40 on CTD.F_TBSP_ND_WEEK (NODE_id);  
create index CTD.f_TBSN_wk41 on CTD.F_TBSP_ND_WEEK (Nd_LGPTH_id);
create index CTD.f_TBSN_wk42 on CTD.F_TBSP_ND_WEEK (DB_id); 
create index CTD.f_TBSN_wk43 on CTD.F_TBSP_ND_WEEK (INST_id); 
create index CTD.f_TBSN_wk44 on CTD.F_TBSP_ND_WEEK (Inst_Vers_id);
create index CTD.f_TBSN_wk60 on CTD.F_TBSP_ND_WEEK (host_ip_ad_id);

alter table CTD.F_TBSP_ND_WEEK
add constraint K437
foreign key (TBSP_ND_id)
references CTD.D_TBSP_ND (TBSP_ND_id);

alter table CTD.F_TBSP_ND_WEEK
add constraint K438
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TBSP_ND_WEEK
add constraint K439
foreign key (metric_id)
references CTD.D_TBSP_ND_METRIC (metric_id);  

alter table CTD.F_TBSP_ND_WEEK
add constraint K447
foreign key (NODE_id)
references CTD.D_NODE (NODE_id); 

alter table CTD.F_TBSP_ND_WEEK
add constraint K455
foreign key (Nd_LGPTH_id)
references CTD.D_Nd_LGPTH (Nd_LGPTH_id);

alter table CTD.F_TBSP_ND_WEEK
add constraint K462
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TBSP_ND_WEEK
add constraint K473
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TBSP_ND_WEEK
add constraint K481
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TBSP_ND_WEEK
add constraint K700
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: TBSP_ND 
-----------------------------

create table CTD.F_TBSP_ND_MONTH (
 TBSP_ND_id            integer not null, 
 NODE_id		   integer not null, 
 Nd_LGPTH_id		integer not null,
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TBSP_ND_id,  NODE_id, 
       Nd_LGPTH_id, DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TBSN_mo1 on CTD.F_TBSP_ND_MONTH (TBSP_ND_id);
create index CTD.f_TBSN_mo2 on CTD.F_TBSP_ND_MONTH (host_id);
create index CTD.f_TBSN_mo3 on CTD.F_TBSP_ND_MONTH (metric_id);
create index CTD.f_TBSN_mo4 on CTD.F_TBSP_ND_MONTH (meas_date);
create index CTD.f_TBSN_mo40 on CTD.F_TBSP_ND_MONTH (NODE_id);  
create index CTD.f_TBSN_mo41 on CTD.F_TBSP_ND_MONTH (Nd_LGPTH_id);
create index CTD.f_TBSN_mo42 on CTD.F_TBSP_ND_MONTH (DB_id); 
create index CTD.f_TBSN_mo43 on CTD.F_TBSP_ND_MONTH (INST_id); 
create index CTD.f_TBSN_mo44 on CTD.F_TBSP_ND_MONTH (Inst_Vers_id);
create index CTD.f_TBSN_mo60 on CTD.F_TBSP_ND_MONTH (host_ip_ad_id);

alter table CTD.F_TBSP_ND_MONTH
add constraint K439
foreign key (TBSP_ND_id)
references CTD.D_TBSP_ND (TBSP_ND_id);

alter table CTD.F_TBSP_ND_MONTH
add constraint K440
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_TBSP_ND_MONTH
add constraint K441
foreign key (metric_id)
references CTD.D_TBSP_ND_METRIC (metric_id);    

alter table CTD.F_TBSP_ND_MONTH
add constraint K450
foreign key (NODE_id)
references CTD.D_NODE (NODE_id); 

alter table CTD.F_TBSP_ND_MONTH
add constraint K456
foreign key (Nd_LGPTH_id)
references CTD.D_Nd_LGPTH (Nd_LGPTH_id);

alter table CTD.F_TBSP_ND_MONTH
add constraint K465
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TBSP_ND_MONTH
add constraint K476
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TBSP_ND_MONTH
add constraint K482
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TBSP_ND_MONTH
add constraint K701
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

--------------------
---  TAPPLY 
--------------------

---------------------------------
-- dimension table: TAPPLY metric 
---------------------------------

create table CTD.d_TAPPLY_metric (
 metric_id     	           integer        not null,
 met_category 	           varchar(254),
 met_desc        	   varchar(254),
 met_name	           varchar(254)   not null,
 met_units      	   varchar(254),
 min_exists		   char(1)        not null,
 max_exists		   char(1)        not null,
 avg_exists		   char(1)        not null,
 total_exists	           char(1)        not null,
 msrc_nm		   varchar(254),
      primary key (metric_id));


-- translation table

create table CTD.t_TAPPLY_metric (
  orig_metric_id 		integer not null,
  metric_id 	  		integer not null,
  cdw_id 			integer not null,
  met_category 	                varchar(254),
  met_desc            		varchar(254),
  met_name 			varchar(254) not null,
  met_units 			varchar(254),
  min_exists		   	char(1)        not null,
  max_exists		   	char(1)        not null,
  avg_exists		   	char(1)        not null,
  total_exists	           	char(1)        not null,
  msrc_nm		   	varchar(254),
    primary key (orig_metric_id, cdw_id)
)
;

--sequence      

create sequence CTD.TBAPmt_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.TBAPmt_i1
no cascade before insert on CTD.d_TAPPLY_metric  
referencing new as n for each row mode db2sql
set n.metric_id = nextval for CTD.TBAPmt_id_seq;

-----------------------------
-- dimension table: TAPPLY 
-----------------------------

create table CTD.D_TAPPLY (
 Tapply_Nm	varchar(254),
	Tapply_Owner	varchar(254), 
 TBAPPLY_id     	integer        not null, 
      primary key (TBAPPLY_id));

-- translation table

create table CTD.T_TAPPLY (
 Tapply_Nm	varchar(254),
	Tapply_Owner	varchar(254), 
 orig_TBAPPLY_id         integer        not null, 
 cdw_id			 integer        not null, 
 TBAPPLY_id              integer not null,
      primary key (orig_TBAPPLY_id,cdw_id)
      );

--sequence      

create sequence CTD.TBAP_id_seq
start with 0 increment by 1 no maxvalue no cycle cache 24;

--trigger

create trigger CTD.TBAP_i1
no cascade before insert on CTD.d_TAPPLY  
referencing new as n for each row mode db2sql
set n.TBAPPLY_id = nextval for CTD.TBAP_id_seq;
      

--staging hour fact table
create table CTD.STG_TAPPLY_HR (
    msmt_id		   integer	  not null,
    orig_TBAPPLY_id    integer        not null,
    orig_APPLY_id	   integer	  not null,
    orig_DB_id	   integer	  not null,
    orig_INST_id	   integer	  not null,
    Inst_Vers    varchar(254) not null,
    orig_host_id           integer        not null,
    Host_ip_ad		  varchar(254) not null,
    orig_metric_id         integer        not null,
    cdw_id		   integer        not null,
    meas_HOUR              timestamp      not null,
    min_value		   float,
    max_value	           float,
    avg_value       	   float,
    total_value		   float,
    sample_count	           float,
       primary key (msmt_id,cdw_id)
       );

----------------------------
-- hourly fact table: TBAPPLY 
-----------------------------

create table CTD.F_TAPPLY_HOUR (
 TBAPPLY_id            integer       not null, 
 APPLY_id		   integer 	 not null, 
 DB_id		   integer 	 not null, 
 INST_id		   integer 	 not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer       not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer       not null,
 meas_HOUR                 timestamp     not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TBAPPLY_id,  APPLY_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, meas_HOUR)
       );

create index CTD.f_TBAP_hr1 on CTD.F_TAPPLY_HOUR (TBAPPLY_id);
create index CTD.f_TBAP_hr2 on CTD.F_TAPPLY_HOUR (host_id);
create index CTD.f_TBAP_hr3 on CTD.F_TAPPLY_HOUR (metric_id);
create index CTD.f_TBAP_hr4 on CTD.F_TAPPLY_HOUR (meas_hour); 
create index CTD.f_TBAP_hr50 on CTD.F_TAPPLY_HOUR (APPLY_id);  
create index CTD.f_TBAP_hr51 on CTD.F_TAPPLY_HOUR (DB_id);  
create index CTD.f_TBAP_hr52 on CTD.F_TAPPLY_HOUR (INST_id); 
create index CTD.f_TBAP_hr53 on CTD.F_TAPPLY_HOUR (Inst_Vers_id); 
create index CTD.f_TBAP_hr60 on CTD.F_TAPPLY_HOUR (host_ip_ad_id);

alter table CTD.F_TAPPLY_HOUR
add constraint K535
foreign key (TBAPPLY_id)
references CTD.D_TAPPLY (TBAPPLY_id);

alter table CTD.F_TAPPLY_HOUR
add constraint K536
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TAPPLY_HOUR
add constraint K537
foreign key (metric_id)
references CTD.D_TAPPLY_METRIC (metric_id);  

alter table CTD.F_TAPPLY_HOUR
add constraint K546
foreign key (APPLY_id)
references CTD.D_APPLY (APPLY_id); 

alter table CTD.F_TAPPLY_HOUR
add constraint K557
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TAPPLY_HOUR
add constraint K568
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TAPPLY_HOUR
add constraint K579
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TAPPLY_HOUR
add constraint K706
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- daily fact table: TAPPLY 
-----------------------------

create table CTD.F_TAPPLY_DAY (
 TBAPPLY_id            integer not null, 
 APPLY_id		   integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TBAPPLY_id,  APPLY_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TBAP_day1 on CTD.F_TAPPLY_DAY (TBAPPLY_id);
create index CTD.f_TBAP_day2 on CTD.F_TAPPLY_DAY (host_id);
create index CTD.f_TBAP_day3 on CTD.F_TAPPLY_DAY (metric_id);
create index CTD.f_TBAP_day4 on CTD.F_TAPPLY_DAY (meas_date);
create index CTD.f_TBAP_day50 on CTD.F_TAPPLY_DAY (APPLY_id);  
create index CTD.f_TBAP_day51 on CTD.F_TAPPLY_DAY (DB_id); 
create index CTD.f_TBAP_day52 on CTD.F_TAPPLY_DAY (INST_id); 
create index CTD.f_TBAP_day53 on CTD.F_TAPPLY_DAY (Inst_Vers_id);
create index CTD.f_TBAP_day60 on CTD.F_TAPPLY_DAY (host_ip_ad_id);

alter table CTD.F_TAPPLY_DAY
add constraint K538
foreign key (TBAPPLY_id)
references CTD.D_TAPPLY (TBAPPLY_id);

alter table CTD.F_TAPPLY_DAY
add constraint K539
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TAPPLY_DAY
add constraint K540
foreign key (metric_id)
references CTD.D_TAPPLY_METRIC (metric_id);   

alter table CTD.F_TAPPLY_day
add constraint K548
foreign key (APPLY_id)
references CTD.D_APPLY (APPLY_id); 

alter table CTD.F_TAPPLY_day
add constraint K559
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TAPPLY_day
add constraint K570
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TAPPLY_day
add constraint K580
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TAPPLY_DAY
add constraint K707
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- weekly fact table: TAPPLY 
-----------------------------

create table CTD.F_TAPPLY_WEEK (
 TBAPPLY_id            integer not null, 
 APPLY_id		   integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TBAPPLY_id,  APPLY_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TBAP_wk1 on CTD.F_TAPPLY_WEEK (TBAPPLY_id);
create index CTD.f_TBAP_wk2 on CTD.F_TAPPLY_WEEK (host_id);
create index CTD.f_TBAP_wk3 on CTD.F_TAPPLY_WEEK (metric_id);
create index CTD.f_TBAP_wk4 on CTD.F_TAPPLY_WEEK (meas_date);
create index CTD.f_TBAP_wk50 on CTD.F_TAPPLY_WEEK (APPLY_id);  
create index CTD.f_TBAP_wk51 on CTD.F_TAPPLY_WEEK (DB_id); 
create index CTD.f_TBAP_wk52 on CTD.F_TAPPLY_WEEK (INST_id); 
create index CTD.f_TBAP_wk53 on CTD.F_TAPPLY_WEEK (Inst_Vers_id);
create index CTD.f_TBAP_wk60 on CTD.F_TAPPLY_WEEK (host_ip_ad_id);

alter table CTD.F_TAPPLY_WEEK
add constraint K541
foreign key (TBAPPLY_id)
references CTD.D_TAPPLY (TBAPPLY_id);

alter table CTD.F_TAPPLY_WEEK
add constraint K542
foreign key (host_id)
references CTD.D_HOST (host_id);

alter table CTD.F_TAPPLY_WEEK
add constraint K543
foreign key (metric_id)
references CTD.D_TAPPLY_METRIC (metric_id);  

alter table CTD.F_TAPPLY_WEEK
add constraint K551
foreign key (APPLY_id)
references CTD.D_APPLY (APPLY_id); 

alter table CTD.F_TAPPLY_WEEK
add constraint K562
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TAPPLY_WEEK
add constraint K573
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TAPPLY_WEEK
add constraint K581
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TAPPLY_WEEK
add constraint K708
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

-----------------------------
-- monthly fact table: TAPPLY 
-----------------------------

create table CTD.F_TAPPLY_MONTH (
 TBAPPLY_id            integer not null, 
 APPLY_id		   integer not null, 
 DB_id		   integer not null, 
 INST_id		   integer not null, 
 Inst_Vers_id		integer not null,
 host_id                   integer not null,
 Host_ip_ad_id		  integer not null,
 metric_id                 integer not null,
 meas_date                 timestamp not null,
 min_value		   float,
 max_value	           float,
 avg_value       	   float,
 total_value		   float,
 sample_count	           float,
       primary key (TBAPPLY_id,  APPLY_id,  DB_id,  INST_id, 
       Inst_Vers_id,
       host_id, host_ip_ad_id, metric_id, 
       meas_date)
       );

create index CTD.f_TBAP_mo1 on CTD.F_TAPPLY_MONTH (TBAPPLY_id);
create index CTD.f_TBAP_mo2 on CTD.F_TAPPLY_MONTH (host_id);
create index CTD.f_TBAP_mo3 on CTD.F_TAPPLY_MONTH (metric_id);
create index CTD.f_TBAP_mo4 on CTD.F_TAPPLY_MONTH (meas_date);
create index CTD.f_TBAP_mo50 on CTD.F_TAPPLY_MONTH (APPLY_id);  
create index CTD.f_TBAP_mo51 on CTD.F_TAPPLY_MONTH (DB_id); 
create index CTD.f_TBAP_mo52 on CTD.F_TAPPLY_MONTH (INST_id); 
create index CTD.f_TBAP_mo53 on CTD.F_TAPPLY_MONTH (Inst_Vers_id);
create index CTD.f_TBAP_mo60 on CTD.F_TAPPLY_MONTH (host_ip_ad_id);

alter table CTD.F_TAPPLY_MONTH
add constraint K543
foreign key (TBAPPLY_id)
references CTD.D_TAPPLY (TBAPPLY_id);

alter table CTD.F_TAPPLY_MONTH
add constraint K544
foreign key (host_id)
references CTD.D_HOST (host_id); 

alter table CTD.F_TAPPLY_MONTH
add constraint K545
foreign key (metric_id)
references CTD.D_TAPPLY_METRIC (metric_id);    

alter table CTD.F_TAPPLY_MONTH
add constraint K554
foreign key (APPLY_id)
references CTD.D_APPLY (APPLY_id); 

alter table CTD.F_TAPPLY_MONTH
add constraint K565
foreign key (DB_id)
references CTD.D_DB (DB_id); 

alter table CTD.F_TAPPLY_MONTH
add constraint K576
foreign key (INST_id)
references CTD.D_INST (INST_id); 

alter table CTD.F_TAPPLY_MONTH
add constraint K582
foreign key (Inst_Vers_id)
references CTD.D_Inst_Vers (Inst_Vers_id);

alter table CTD.F_TAPPLY_MONTH
add constraint K709
foreign key (host_ip_ad_id)
references CTD.D_Host_Ip_Ad (host_ip_ad_id);

--#endtag fixpack_1
