-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-B96
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- # File Information: src/tedw_apps_etl/FixPack/ctd/mart/dml/ctd_mart_data.sql, dbmx_db2_tedw, dbmx_db2_510FP5
-- # Revision: 1.1
-- # Date: 2/13/04 10:21:16
-- ############################################################################

--#iftag fixpack_1
---------------------------------------------
-- Rollup table
--------------------------------------------

-- create a temporary table for measurement source cd 

declare global temporary table Rollup_Tables  (
  Msrc_Cd		char(3) not null,
  Hourly_Fact_Table	varchar(25) not null,
  Stage_Fact_Table	varchar(25) not null
) 
with replace on commit preserve rows not logged
;

insert into session.Rollup_Tables values ('CTD','F_INST_HOUR','STG_INST_HR');
insert into session.Rollup_Tables values ('CTD','F_DB_HOUR','STG_DB_HR');
insert into session.Rollup_Tables values ('CTD','F_GTWY_HOUR','STG_GTWY_HR');
insert into session.Rollup_Tables values ('CTD','F_NODE_HOUR','STG_NODE_HR');
insert into session.Rollup_Tables values ('CTD','F_APPLY_HOUR','STG_APPLY_HR');
insert into session.Rollup_Tables values ('CTD','F_TABLE_HOUR','STG_TABLE_HR');
insert into session.Rollup_Tables values ('CTD','F_APPL_HOUR','STG_APPL_HR');
insert into session.Rollup_Tables values ('CTD','F_TBSP_ND_HOUR','STG_TBSP_ND_HR');
insert into session.Rollup_Tables values ('CTD','F_TAPPLY_HOUR','STG_TAPPLY_HR');

insert into AMX.Rollup_tables 
select 
 r.Msrc_Cd,
 r.Hourly_Fact_Table,
 r.Stage_Fact_Table
from  
 session.Rollup_Tables r
where not exists
( select 1 from
  AMX.Rollup_tables t
  where
  r.Msrc_Cd=t.Msrc_Cd and
  r.Hourly_Fact_Table=t.Hourly_Fact_Table and
  r.Stage_Fact_Table=t.Stage_Fact_Table 
  )
  ; 

-- Insert data into control table for pruning data from all fact tables.
-- A date duration is decimal(8,0) and has the format yyyymmdd.

Declare global temporary table Prune_Mart_Control(
 Table_Name		varchar(120) not null,
 PMartC_Duration	decimal(8,0) not null)
 with replace on commit preserve rows not logged
 ;
insert into session.Prune_Mart_Control values ('CTD.F_INST_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_INST_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_INST_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_INST_MONTH',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_DB_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_DB_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_DB_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_DB_MONTH',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_GTWY_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_GTWY_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_GTWY_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_GTWY_MONTH',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_NODE_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_NODE_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_NODE_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_NODE_MONTH',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_APPLY_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_APPLY_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_APPLY_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_APPLY_MONTH',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_TABLE_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_TABLE_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_TABLE_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_TABLE_MONTH',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_APPL_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_APPL_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_APPL_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_APPL_MONTH',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_TBSP_ND_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_TBSP_ND_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_TBSP_ND_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_TBSP_ND_MONTH',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_TAPPLY_HOUR',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_TAPPLY_DAY',00000300);
insert into session.Prune_Mart_Control values ('CTD.F_TAPPLY_WEEK',00010000);
insert into session.Prune_Mart_Control values ('CTD.F_TAPPLY_MONTH',00010000);
insert into CTD.Prune_Mart_Control
select
  s.Table_Name as Table_Name,
  s.PMartC_Duration as PMartC_Duration
from
  session.Prune_Mart_Control s
where
 not exists (
   select 1
   from
    CTD.Prune_Mart_Control t
   where
    t.Table_Name = s.Table_Name
    )
;
--#endtag fixpack_1
