#!/bin/sh
######################################################################
#
# Tivoli Enterprise Data Warehouse, v 1.1.0
# (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#
# File Information: src/tedw_apps_etl/FixPack/ctd/misc/ctd_before.sh, dbmx_db2_tedw, dbmx_db2_510FP5
# Revision: 1.1
# Date: 2/13/04 10:21:18
#
############################################################################
# Command Line Args:
#	1 = the path and name of the TWH Application config file
#	2 = Application working directory or install base directory
#		$TWH_TOPDIR/apps/ava_code_for_app/vapp_version (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this script called amx_after.sh.log
#
# Required Env Vars:
#       None.
#
# Return Codes:
#	0 = Success
#	255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#       6 - TWH Core tools and application components must be
#	      successfully installed
#
# What is accomplished:
#  * Copy the AMX_Create_Comp_Msmt.sh into $TWH_TOPDIR/tools/bin
#
# Note - Caution needs to be taken for NT paths that have a space.  This
#        is a limitation that requires double quoting around all 
#	   variables that contain a path.  Testing should be done to ensure
#	   this script runs with a space in any of the paths that are used.
#########################################################################
#


###
echo "        ** Before Script Log **          "
echo ""
echo "****************************************"
echo "* Application Before Script Start point *"
echo "****************************************"
echo ""

# Pulls in the generic shared routines

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for beforescript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

#####################################################
######## Add application code below here ONLY #######
#####################################################

#
set_ctd_program_vars()
{
CTD_MISC_DIR="$APP_WORK_DIR/misc"    
tmp_sql_file="ctd_tmp_sql.sql"        # name of the temporary sql file

return 0;
}


###
remove_old_tag_files()
{

	echo "==> Removing the old tag files"
	if [ -f "$APP_WORK_DIR"/etl/CTD_1_ETL2_Process_dwc_data.tag ]
	then
		blah=`rm "$APP_WORK_DIR"/etl/CTD_1_ETL2_Process_dwc_data.tag` 
	fi

	if [ -f "$APP_WORK_DIR"/etl/CTD_2_Hourly_WH_dwc_data.tag ]
	then
		blah=`rm "$APP_WORK_DIR"/etl/CTD_2_Hourly_WH_dwc_data.tag`
	fi
	
	if [ -f "$APP_WORK_DIR"/etl/CTD_3_Daily_WH_dwc_data.tag ]
	then
		blah=`rm "$APP_WORK_DIR"/etl/CTD_3_Daily_WH_dwc_data.tag` 
	fi

	if [ -f "$APP_WORK_DIR"/etl/CTD_4_Weekly_WH_dwc_data.tag ]
	then
		blah=`rm "$APP_WORK_DIR"/etl/CTD_4_Weekly_WH_dwc_data.tag` 
	fi

	if [ -f "$APP_WORK_DIR"/etl/CTD_5_Monthly_WH_dwc_data.tag  ]
	then
		blah=`rm "$APP_WORK_DIR"/etl/CTD_5_Monthly_WH_dwc_data.tag`
	fi
	echo "      (I) Old tag files removed. Program will continue."
return 0;
}

# Remove invalid star schemas
remove_invalid_star_schemas()
{

  # Test a connection
  echo "      (I) Testing the DB connection"
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CTRL_DB" user "$COPT_CTRL_DB2USER" using "$COPT_CTRL_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CTRL_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  echo "==> Removing the invalid the DB2 star schemas"
  
  echo "connect to $TWH_CTRL_DB user $COPT_CTRL_DB2USER using $COPT_CTRL_DB2PASS;" > "$TMPDIR/$tmp_sql_file";
  cat "$CTD_MISC_DIR/RPI_ctd_data_delete.sql" >> "$TMPDIR/$tmp_sql_file"
  err_txt=`$DB2EXEC -xtf"\"$TMPDIR\""/$tmp_sql_file` 

  ret=$?
  if [ $ret -gt 2 ] ; then
	echo "      (F) Unable to remove the invalid DB2 star schemas"
	echo "      Error is : $err_txt"
        echo "      Errors detected but instructed to continue..."
  else
        rm -f "$TMPDIR/$tmp_sql_file"
        echo "      (I) Invalid Db2 star schemas deleted. Program will continue."
  fi
return 0;
}

#
# Remove the etl2 scripts with the old names
#
remove_old_etl2_scripts()
{
  echo "==> Removing old etl2 scripts"
  if [ -f "$APP_WORK_DIR"/etl/sql/CTD_m05_s010_Init_Attr.db2 ]
  then
    blah=`rm "$APP_WORK_DIR"/etl/sql/CTD_m05_s010_Init_Attr.db2`
  fi
  if [ -f "$APP_WORK_DIR"/etl/sql/CTD_m05_s020_Dimension.db2 ]
  then
    blah=`rm "$APP_WORK_DIR"/etl/sql/CTD_m05_s020_Dimension.db2`
  fi
  if [ -f "$APP_WORK_DIR"/etl/sql/CTD_m05_s030_Fact.db2 ]
  then
    blah=`rm "$APP_WORK_DIR"/etl/sql/CTD_m05_s030_Fact.db2`
  fi
  if [ -f "$APP_WORK_DIR"/etl/sql/CTD_m05_s050_Prune.db2 ]
  then
    blah=`rm "$APP_WORK_DIR"/etl/sql/CTD_m05_s050_Prune.db2`
  fi
  echo "      (I) Old etl2 scripts removed. Program will continue."
  return 0;
}

#
# Remove old i18n resource bundles
#
remove_old_i18n_bundles()
{
  echo "==> Removing old i18n bundles"
  if [ -f "$APP_WORK_DIR"/i18n/com.ibm.twh.ctd.nls@1.1.0.jar ]
  then
    blah=`rm "$APP_WORK_DIR"/i18n/com.ibm.twh.ctd.nls@1.1.0.jar`
  fi
  if [ -f "$APP_WORK_DIR"/i18n/com.ibm.twh.ctd.nls_intl@1.1.0.jar ]
  then
    blah=`rm "$APP_WORK_DIR"/i18n/com.ibm.twh.ctd.nls_intl@1.1.0.jar`
  fi
  echo "      (I) Old i18n bundles removed. Program will continue."
  return 0;
}

############
### Main ###
############

echo "==> Processing main WPack routines"
echo ""

  set_ctd_program_vars;
  remove_invalid_star_schemas;
  remove_old_etl2_scripts;
  remove_old_i18n_bundles;

if [ "$TWH_RPI_HOST" <> "RPI_NULL_HOST" ]
  then	 
    echo "TWH_RPI_HOST: $TWH_RPI_HOST"
    remove_invalid_rpi_data;
  else
     echo " TDW 1.2 detected, RPI tables not deleted"	  
  fi 
 
  remove_old_tag_files;

echo ""
echo "      (I) Done processing main WPack routines"           


echo ""
echo "==> Completed executing application before script"
exit 0
