-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-B96
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- # File Information: src/tedw_apps_etl/FixPack/ctd/misc/tools/ctd_verify_etl.db2, dbmx_db2_tedw, dbmx_db2_510FP5
-- # Revision: 1.1
-- # Date: 2/13/04 10:21:23
-- ############################################################################

-- This script checks that all the data in the TWH_CDW get inserted in the
-- TWH_MART 

--#VERSION 1.1.0.1.0

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop table ctd.verify_etl;

--#EXECUTE_AT_TARGET
create table ctd.verify_etl (
   comptyp_cd   varchar(17) not null,
   rows_in_cdw  integer not null,
   rows_in_mart integer not null
);

----------------------- INSTANCE -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_inst;

create view ctd.cdw_inst as 
select 
   substr(c.comp_nm,1,25) as comp_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.msmttyp t
where
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_INSTANCE' 
group by
   comp_nm,
   msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
; 

--#INSERT_INTO_TARGET
insert into ctd.verify_etl (
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_INSTANCE',
   count(*),
   -1
from
   ctd.cdw_inst
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_inst;

--#EXECUTE_AT_TARGET
create view ctd.mart_inst as 
select 
   substr(d1.inst_nm,1,15) as inst_nm,
   substr(d1.ismpp,1,15) as ismpp,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_vers,1,15) as inst_vers,
   f.meas_hour 
from
   ctd.f_inst_hour f,
   ctd.d_inst d1,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_inst_metric d4,
   ctd.d_inst_vers d5
where
   f.inst_id = d1.inst_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id and 
   f.inst_vers_id = d5.inst_vers_id
;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_inst;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_inst )
where comptyp_cd='CTD_INSTANCE'
;

----------------------- DB -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_db;

create view ctd.cdw_db as 
select 
   substr(c.comp_nm,1,25) as comp_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.msmttyp t
where
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_DATABASE' 
group by
   comp_nm,
   msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
; 

--#INSERT_INTO_TARGET
insert into ctd.verify_etl (
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_DATABASE',
   count(*),
   -1
from
   ctd.cdw_db
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_db;

--#EXECUTE_AT_TARGET
create view ctd.mart_db as 
select 
   substr(d1.db_nm,1,15) as db_nm,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_nm, 1,15) as inst_nm,
   substr(d6.inst_vers,1,15) as inst_vers,
   f.meas_hour 
from
   ctd.f_db_hour f,
   ctd.d_db d1,
   ctd.d_inst d5,
   ctd.d_inst_vers d6,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_db_metric d4
where
   f.db_id = d1.db_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id and
   f.inst_id = d5.inst_id and
   f.inst_vers_id = d6.inst_vers_id
;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_db;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_db )
where comptyp_cd='CTD_DATABASE'
;

----------------------- GTWY -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_gtwy;

create view ctd.cdw_gtwy as 
select 
   substr(c.comp_nm,1,25) as comp_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.msmttyp t
where
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_GATEWAY' 
group by
   comp_nm,
   msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
; 

--#INSERT_INTO_TARGET
insert into ctd.verify_etl (
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_GATEWAY',
   count(*),
   -1
from
   ctd.cdw_gtwy
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_gtwy;

--#EXECUTE_AT_TARGET
create view ctd.mart_gtwy as 
select 
   substr(d1.gtwy_nm,1,15) as gtwy_nm,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_nm, 1,15) as inst_nm,
   substr(d6.inst_vers,1,15) as inst_vers,
   f.meas_hour 
from
   ctd.f_gtwy_hour f,
   ctd.d_gtwy d1,
   ctd.d_inst d5,
   ctd.d_inst_vers d6,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_gtwy_metric d4
where
   f.gtwy_id = d1.gtwy_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id and
   f.inst_id = d5.inst_id and
   f.inst_vers_id = d6.inst_vers_id
  ;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_gtwy;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_gtwy )
where comptyp_cd='CTD_GATEWAY'
;

----------------------- NODE -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_nd;

create view ctd.cdw_nd as 
select 
   substr(c.comp_nm,1,25) as comp_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.msmttyp t
where
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_NODE' 
group by
   comp_nm,
   msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
;


--#INSERT_INTO_TARGET
insert into ctd.verify_etl (
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_NODE',
   count(*),
   -1
from
   ctd.cdw_nd
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_nd;

--#EXECUTE_AT_TARGET
create view ctd.mart_nd as 
select 
   substr(d1.node_number,1,15) as node_number,
   substr(d1.node_port_number,1,15) as node_port_number,
   substr(d1.node_hostname,1,15) as node_hostname,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_nm, 1,15) as inst_nm,
   substr(d6.inst_vers,1,15) as inst_vers,
   substr(d7.db_nm,1,15) as db_nm,
   substr(d8.nd_lgpth,1,15) as nd_lgpth,
   f.meas_hour 
from
   ctd.f_node_hour f,
   ctd.d_node d1,
   ctd.d_nd_lgpth d8,
   ctd.d_db d7,
   ctd.d_inst d5,
   ctd.d_inst_vers d6,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_node_metric d4
where
   f.node_id = d1.node_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id  and
   f.inst_id = d5.inst_id and
   f.inst_vers_id = d6.inst_vers_id and
   f.db_id=d7.db_id and
   f.nd_lgpth_id=d8.nd_lgpth_id
;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_nd;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_nd )
where comptyp_cd='CTD_NODE'
;

----------------------- APPLY_ID -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_apply;

create view ctd.cdw_apply as 
select 
   substr(c.comp_nm,1,25) as comp_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.msmttyp t
where
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_APPLY_ID' 
group by
   comp_nm,
   msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
; 

--#INSERT_INTO_TARGET
insert into ctd.verify_etl (
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_APPLY_ID',
   count(*),
   -1
from
   ctd.cdw_apply
; 

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_apply;

--#EXECUTE_AT_TARGET
create view ctd.mart_apply as 
select 
   substr(d1.applyid,1,15) as applyid,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_nm, 1,15) as inst_nm,
   substr(d6.inst_vers,1,15) as inst_vers,
   substr(d7.db_nm,1,15) as db_nm,
   f.meas_hour 
from
   ctd.f_apply_hour f,
   ctd.d_apply d1,
   ctd.d_db d7,
   ctd.d_inst d5,
   ctd.d_inst_vers d6,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_apply_metric d4
where
   f.apply_id = d1.apply_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id and 
   f.inst_id = d5.inst_id and
   f.inst_vers_id = d6.inst_vers_id and
   f.db_id=d7.db_id
;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_apply;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_apply )
where comptyp_cd='CTD_APPLY_ID'
;

----------------------- TABLE -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_table;

create view ctd.cdw_table as 
select 
   substr(c.comp_nm,1,25) as comp_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.msmttyp t
where
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_TABLE' 
group by
   comp_nm,
   msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
; 

--#INSERT_INTO_TARGET
insert into ctd.verify_etl (
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_TABLE',
   count(*),
   -1
from
   ctd.cdw_table
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_table;

--#EXECUTE_AT_TARGET
create view ctd.mart_table as 
select 
   substr(d1.table_nm,1,15) as table_nm,
   substr(d1.table_owner,1,15) as table_owner,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_nm, 1,15) as inst_nm,
   substr(d6.inst_vers,1,15) as inst_vers,
   substr(d7.db_nm,1,15) as db_nm,
   f.meas_hour 
from
   ctd.f_table_hour f,
   ctd.d_table d1,
   ctd.d_db d7,
   ctd.d_inst d5,
   ctd.d_inst_vers d6,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_table_metric d4
where
   f.table_id = d1.table_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id and
   f.inst_id = d5.inst_id and
   f.inst_vers_id = d6.inst_vers_id and
   f.db_id=d7.db_id
;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_table;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_table )
where comptyp_cd='CTD_TABLE'
;

----------------------- APPL -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_appl;

create view ctd.cdw_appl as 
select 
   substr(ca.compattr_val,1,25) as appl_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.compattr ca,
   twg.msmttyp t
where
   ca.comp_id =c.comp_id and
   ca.attrtyp_cd='CTD_APPL_NAME' and
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_APPL'  
group by
   t.msmttyp_nm,
   c.comp_corr_id,
   ca.compattr_val,
   m.msmt_strt_dt,
   m.msmt_strt_tm
; 

--#INSERT_INTO_TARGET
insert into ctd.verify_etl ( 
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_APPL',
   count(*),
   -1
from
   ctd.cdw_appl
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_appl;

--#EXECUTE_AT_TARGET
create view ctd.mart_appl as 
select 
   substr(d1.appl_nm,1,15) as appl_nm,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_nm, 1,15) as inst_nm,
   substr(d6.inst_vers,1,15) as inst_vers,
   substr(d7.db_nm,1,15) as db_nm,
   f.meas_hour 
from
   ctd.f_appl_hour f,
   ctd.d_appl d1,
   ctd.d_db d7,
   ctd.d_inst d5,
   ctd.d_inst_vers d6,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_appl_metric d4
where
   f.appl_id = d1.appl_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id and
   f.inst_id = d5.inst_id and
   f.inst_vers_id = d6.inst_vers_id and
   f.db_id=d7.db_id
;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_appl;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_appl )
where comptyp_cd='CTD_APPL'
;

----------------------- TBSP -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_tbsp_nd;

create view ctd.cdw_tbsp_nd as 
select 
   substr(c.comp_nm,1,25) as comp_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.msmttyp t
where
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_TBSP' 
group by
   comp_nm,
   msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
; 

--#INSERT_INTO_TARGET
insert into ctd.verify_etl (
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_TBSP',
   count(*),
   -1
from
   ctd.cdw_tbsp_nd
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_tbsp_nd;

--#EXECUTE_AT_TARGET
create view ctd.mart_tbsp_nd as 
select 
   substr(d1.tbsp_nd_nm,1,15) as tbsp_nd_nm,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_nm, 1,15) as inst_nm,
   substr(d6.inst_vers,1,15) as inst_vers,
   substr(d7.db_nm,1,15) as db_nm,
   substr(d8.nd_lgpth,1,15) as nd_lgpth,
   substr(d9.node_number,1,15) as node_number,
   substr(d9.node_port_number,1,15) as node_port_number,
   substr(d9.node_hostname,1,15) as node_hostname,
   f.meas_hour 
from
   ctd.f_tbsp_nd_hour f,
   ctd.d_tbsp_nd d1,
   ctd.d_node d9,
   ctd.d_nd_lgpth d8,
   ctd.d_db d7,
   ctd.d_inst d5,
   ctd.d_inst_vers d6,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_tbsp_nd_metric d4
where
   f.tbsp_nd_id = d1.tbsp_nd_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id  and
   f.inst_id = d5.inst_id and
   f.inst_vers_id = d6.inst_vers_id and
   f.db_id=d7.db_id and
   f.nd_lgpth_id=d8.nd_lgpth_id and
   f.node_id=d9.node_id
;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_tbsp_nd;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_tbsp_nd )
where comptyp_cd='CTD_TBSP'
;

----------------------- TAPPLY -------------------------------------------

--#IGNORE_ERROR
drop view ctd.cdw_tbapply;

create view ctd.cdw_tbapply as 
select 
   substr(c.comp_nm,1,25) as comp_nm,
   substr(t.msmttyp_nm,1,25) as msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
from 
   twg.msmt m, 
   twg.comp c,
   twg.msmttyp t
where
   m.comp_id=c.comp_id and
   m.msmttyp_id=t.msmttyp_id and
   c.comptyp_cd='CTD_TABLE_APPLY' 
group by
   comp_nm,
   msmttyp_nm,
   comp_corr_id,
   m.msmt_strt_dt,
   m.msmt_strt_tm
; 

--#INSERT_INTO_TARGET
insert into ctd.verify_etl (
   comptyp_cd, rows_in_cdw, rows_in_mart )
select
   'CTD_TABLE_APPLY',
   count(*),
   -1
from
   ctd.cdw_tbapply
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
drop view ctd.mart_tbapply;

--#EXECUTE_AT_TARGET
create view ctd.mart_tbapply as 
select 
   substr(d1.tapply_nm,1,15) as tapply_nm,
   substr(d1.tapply_owner,1,15) as tapply_owner,
   substr(d8.applyid,1,15) as applyid,
   substr(d2.host_name,1,15) as hostname,
   substr(d3.host_ip_ad,1,15) as host_ip_ad,
   substr(d4.met_name,1,15) as metric,
   substr(d5.inst_nm, 1,15) as inst_nm,
   substr(d6.inst_vers,1,15) as inst_vers,
   substr(d7.db_nm,1,15) as db_nm,
   f.meas_hour 
from
   ctd.f_tapply_hour f,
   ctd.d_tapply d1,
   ctd.d_apply d8,
   ctd.d_db d7,
   ctd.d_inst d5,
   ctd.d_inst_vers d6,
   ctd.d_host d2,
   ctd.d_host_ip_ad d3,
   ctd.d_tapply_metric d4
where
   f.tbapply_id = d1.tbapply_id and
   f.host_id = d2.host_id and
   f.host_ip_ad_id = d3.host_ip_ad_id and
   f.metric_id = d4.metric_id  and
   f.inst_id = d5.inst_id and
   f.inst_vers_id = d6.inst_vers_id and
   f.db_id=d7.db_id and
   f.apply_id=d8.apply_id
;

--#EXECUTE_AT_TARGET
-- select * from ctd.mart_tbapply;

--#EXECUTE_AT_TARGET
update ctd.verify_etl
set rows_in_mart = ( select count(*) from ctd.mart_tbapply )
where comptyp_cd='CTD_TABLE_APPLY'
;

-- SUMMARY OF ALL -------------------------------------------

--#EXECUTE_AT_TARGET
select * from ctd.verify_etl;


