-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  5724-B96
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- # File Information: src/tedw_apps_etl/FixPack/ctd/cdw/dml/ctd_cdw_data.sql, dbmx_db2_tedw, dbmx_db2_510FP5
-- # Revision: 1.2
-- # Date: 3/26/04 08:53:18
-- ############################################################################

--#iftag fixpack_1


-------------------------------------------------
-- Static data for ITM for DB2 v5.1.1
------------------------------------------------

-- create a temporary table for measurement source cd 

declare global temporary table MSrc (
       MSrc_Cd              CHAR(6) NOT NULL,
       MSrc_Parent_Cd       CHAR(6) NOT NULL,
       MSrc_Nm              VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.MSrc values ('CTD', 'AMX', 'IBM Tivoli Monitoring for Databases, Version 5.1.1: DB2, Version 1.1.0.1'); 

insert into TWG.MSrc 
select 
 m.MSrc_Cd,
 m.MSrc_Parent_Cd,
 m.MSrc_Nm
from 
 session.MSrc m
where not exists
( select 1 from
  TWG.MSrc t
  where
  t.MSrc_Cd=m.MSrc_Cd )
  ; 

  ;


--------------------------------------------------------------
-- Component Types description that have changed in v1.1.0.1
--------------------------------------------------------------

update TWG.Comptyp set Comptyp_nm='DB2 Distributed Instance' where comptyp_cd='CTD_INSTANCE';
update TWG.Comptyp set Comptyp_nm='DB2 Distributed Database' where comptyp_cd='CTD_DATABASE';
update TWG.Comptyp set Comptyp_nm='DB2 DCS Database' where comptyp_cd='CTD_GATEWAY';
update TWG.Comptyp set Comptyp_nm='DB2 Database Partition' where comptyp_cd='CTD_NODE';
update TWG.Comptyp set Comptyp_nm='DB2 Apply Program Identifier' where comptyp_cd='CTD_APPLY_ID';
update TWG.Comptyp set Comptyp_nm='DB2 Table' where comptyp_cd='CTD_TABLE';
update TWG.Comptyp set Comptyp_nm='DB2 Application' where comptyp_cd='CTD_APPL';
update TWG.Comptyp set Comptyp_nm='DB2 Table Space Partition' where comptyp_cd='CTD_TBSP';

-- create a temporary table for DB2 component types
-- and the server generic type

declare global temporary table CTD_CompTyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.CTD_CompTyp values ('IP_HOST', null, 'IP Host', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_HOST',null, 'DB2 Host', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_INSTANCE',null, 'DB2 Distributed Instance', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_DATABASE',null, 'DB2 Distributed Database', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_GATEWAY',null, 'DB2 DCS Database', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_NODE',null, 'DB2 Database Partition', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_APPLY_ID',null, 'DB2 Apply Program Identifier', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_TABLE',null, 'DB2 Table', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_TBSP',null, 'DB2 Table Space Partition', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_TABLE_APPLY',null, 'DB2 Table Level Apply', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_CompTyp values ('CTD_APPL',null, 'DB2 Application', current timestamp - current timezone, '9999-01-01-00.00.00.000000');



-- insert the DB2 component types into the generic schema 
-- if not exist already

insert into TWG.CompTyp 
select 
 c.CompTyp_Cd,
 c.CompTyp_Parent_Cd,
 c.CompTyp_Nm,
 c.CompTyp_Strt_DtTm,
 c.CompTyp_End_DtTm   
from 
 session.CTD_CompTyp c
where not exists
( select 1 from
  TWG.Cur_CompTyp t
  where
  t.CompTyp_cd=c.CompTyp_cd)
  ;


------------------------------------------------------
--Update the msmttyp from version 5.1.0
update TWG.MsmtTyp set  Munit_cd='PRC' where msmttyp_nm='PctPrivateMemUsed' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  Munit_cd='PRC' where msmttyp_nm='PctPackageCacheHits' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  Munit_cd='MSec' where msmttyp_nm='AppLockWaitTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  Munit_Cd='PRC', MsmtTyp_Ds='The percentage of the number of agents created from a pool to the number of agents assigned from a pool.' where msmttyp_nm='AgentCreationRatio' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='4KPgs' where msmttyp_nm='ApplControlHeapSize' and MSrc_Cd='CTD';
-- does not seem correct
--update TWG.MsmtTyp set MsmtTyp_Ds='The maximum allowed number of application control heap pages.' where msmttyp_nm='ApplsInLockWait' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  Munit_Cd='Min' , MsmtTyp_Ds='The amount of time for lagging subscriptions for the Apply program. A negative number indicates that the subscription is due in that number of minutes.'  where msmttyp_nm='ApplySubscriptionLagTime'and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The number of currently connected applications.' where msmttyp_nm='AppsCurConnected' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set MsmtTyp_Ds='The number of currently connected applications for which the database manager is currently processing a request.' where msmttyp_nm='AppsReqInProcess' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The number of data pages read asynchronously into the buffer pool.' where msmttyp_nm='AsyncDataReads' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The number of times that a buffer pool data page was written asynchronously to disk.'  where msmttyp_nm='AsyncDataWrites' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The number of index pages that are read asynchronously into the buffer pool by a prefetcher.' where msmttyp_nm='AsyncIndexReads' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The number of times that a buffer pool index page was written asynchronously to disk.' where msmttyp_nm='AsyncIndexWrites' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='Number of asynchronous read requests during the monitoring interval.' where msmttyp_nm='AsyncReadRequests' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The total time (in milliseconds) that the database manager prefetchers spent reading data or index pages into the buffer pool.' where msmttyp_nm='AsyncReadTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The total time (in milliseconds) that the database manager page cleaners spent writing data or index pages from the buffer pool to disk.' where msmttyp_nm='AsyncWriteTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The ratio of buffer pool asynchronous data reads to the total number of pool reads.' where msmttyp_nm='AvgAsyncReadsPerPoolRead' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The ratio of buffer pool asynchronous writes (data and index) to the total number of pool writes.' where msmttyp_nm='AvgAsyncWritesPerPoolWrite' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The average time (in milliseconds) used to perform a direct read.' where msmttyp_nm='AvgDirectReadTime' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The average time (in milliseconds) used to perform a direct write.' where msmttyp_nm='AvgDirectWriteTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The average number of locks held by each connected application.' where msmttyp_nm='AvgLocksHeld' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The ratio of asyncronous pages written to page cleans.' where msmttyp_nm='AvgPagesPerCleaner' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The average time (in milliseconds) needed to perform a buffer pool input or output operation.' where msmttyp_nm='AvgPoolIOTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec' , MsmtTyp_Ds='The average time (in milliseconds) for processing a database read request that caused data or index pages to be physically read from the disk to the buffer pool.' where msmttyp_nm='AvgPoolReadTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The average time (in milliseconds) to process a write request that caused data or index pages to be physically written from buffer pool to disk.' where msmttyp_nm='AvgPoolWriteTime'  and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='The ratio of pool writes to pool reads.' where msmttyp_nm='AvgPoolWritesPerPoolRead' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The average time (in milliseconds) to perform a sort.' where msmttyp_nm='AvgSortTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The average time (in milliseconds) needed to perform a synchronous input or output operation.' where msmttyp_nm='AvgSyncIOTime'  and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='Average time (in milliseconds) for synchronous data reads to be performed.' where msmttyp_nm='AvgSyncReadTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of attempted binds and precompiles.' where msmttyp_nm='BindPrecompileAttempts' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='4KPgs', MsmtTyp_Ds='The default number of buffer pool pages.'  where msmttyp_nm='BufferPoolDefaultSize' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='4KPgs' , MsmtTyp_Ds='The number of catalog cache pages.'  where msmttyp_nm='CatalogCacheSize' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='PRC' , MsmtTyp_Ds='The threshold for changed pages.'  where msmttyp_nm='ChangedPagesThreshold' and MSrc_Cd='CTD';  
update TWG.MsmtTyp set Munit_Cd='B' , MsmtTyp_Ds='The current size (in bytes) of the client input and output block.'  where msmttyp_nm='ClientIOBlockSize' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The unit-of-work commit attempt rate per second. Unit-of-work commits include SQL COMMIT statements that are issued from applications as well as internal commits that are initiated by the database manager.' where msmttyp_nm='CommitRate' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The current number of connections.' where msmttyp_nm='CurrentConnections' and MSrc_Cd='CTD';  
update TWG.MsmtTyp set  MsmtTyp_Ds='The total number of executed SQL DDL statements.' where msmttyp_nm='DDLSqlStatements' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of buffer pool data pages copied from extended storage.' where msmttyp_nm='PagesCopiedFromExtStorage' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of buffer pool data pages copied to extended storage.' where msmttyp_nm='PagesCopiedToExtStorage' and MSrc_Cd='CTD'; 

update TWG.MsmtTyp set  MsmtTyp_Ds='Number of deadlocks detected during the last monitoring interval'  where msmttyp_nm='DeadlocksDelta' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of direct reads that have not used the buffer pool.'  where msmttyp_nm='DirectReads' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The average number of sectors that are read in a direct read request.'  where msmttyp_nm='DirectReadAvgSectorsPer' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of requests to perform a direct read from disk of one or more sectors of data.'  where msmttyp_nm='DirectReadRequests' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The amount of time (in milliseconds) used for performing direct reads.'  where msmttyp_nm='DirectReadTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='Average number of sectors that are written by a direct write.'  where msmttyp_nm='DirectWriteAvgSectorsPer' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of requests to perform a direct write of one or more sectors of data.' where msmttyp_nm='DirectWriteRequests' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The time (in milliseconds) used for performing direct writes.' where msmttyp_nm='DirectWriteTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of write operations that have not used the buffer pool.' where msmttyp_nm='DirectWrites' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The total number of attempted dynamic SQL statements.'  where msmttyp_nm='DynamicSqlStatements' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The total number of failed attempted SQL statements.' where msmttyp_nm='FailedSqlStatements' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The total number of files that have been closed.' where msmttyp_nm='FilesClosed' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec' , MsmtTyp_Ds='The cumulative host response time divided by the number of statements attempted.' where msmttyp_nm='HostTimePerStatement' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of buffer pool index pages copied from extended storage.' where msmttyp_nm='IndexCopiedFromExtStorage' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of buffer pool index pages copied to extended storage.' where msmttyp_nm='IndexCopiedToExtStorage' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of physical read requests used to get index pages into the buffer pool.'  where msmttyp_nm='PhysicalIndexReads' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of times that a buffer pool index page was physically written to disk.'  where msmttyp_nm='PhysicalIndexWrites' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='Qps', MsmtTyp_Ds='The buffer pool input and output operation rate per second. This includes all physical data and index pages that go through the buffer pool when read or written.' where msmttyp_nm='InputOutputRate' and
MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The total number of rows deleted as a result of internal activity.' where msmttyp_nm='InternalRowDeletes' and MSrc_Cd='CTD';  
update TWG.MsmtTyp set  MsmtTyp_Ds='The total number of rows inserted as a result of internal activity.' where msmttyp_nm='InternalRowInserts' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The total number of rows updated as a result of internal activity.' where msmttyp_nm='InternalRowUpdates' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The total number of times that an object lock request timed out and was not granted.' where msmttyp_nm='LockTimeouts' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of times that a request to lock an object timed out instead of being granted during the monitoring interval'  where msmttyp_nm='LockTimeoutsDelta' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='B' , MsmtTyp_Ds='The total number of bytes of lock list memory that is in use.' where msmttyp_nm='LocklistMemInUse' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='4KPgs', msmttyp_ds='The number of log buffer pages.' where msmttyp_nm='LogBufferSize' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of times a page cleaner was invoked because the used logging space reached a predefined criterion.' where msmttyp_nm='LogSpaceCleanersInvoked' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of logical data page read requests that went through the buffer pool.'  where msmttyp_nm='LogicalDataReads' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of logical index page read requests  that went through the buffer pool.' where msmttyp_nm='LogicalIndexReads' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='4KPgs', MsmtTyp_Ds='The maximum allowed number of lock list pages' where msmttyp_nm='MaxLocklistStorage' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The percentage of the lock list held by an application that must be filled before the database manager performs an escalation.' where msmttyp_nm='MaxPctLocklist' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='B', MsmtTyp_Ds='The maximum number of bytes used by the primary log.' where msmttyp_nm='MaxPrimaryLogSpaceUsed' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='4KPgs', MsmtTyp_Ds='The maximum amount of memory that can be allocated for the query heap.' where msmttyp_nm='MaxQueryHeapSize' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='B', MsmtTyp_Ds='The maximum number of bytes used by the secondary log.' where msmttyp_nm='MaxSecondaryLogUsed' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='B', MsmtTyp_Ds='The maximum number of bytes of total log space used.' where msmttyp_nm='MaxTotalLogSpaceUsed' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='4KPgs', MsmtTyp_Ds='The number of database system monitor heap pages.' where msmttyp_nm='MonHeapSize' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='The cumulative host response time, minus cumulative statement execution time, divided by the number of statements attempted.' where msmttyp_nm='NetworkTimePerStatement' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of sorts that have a sort heap allocated.' where msmttyp_nm='NumActiveSorts' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of System Managed Space (SMS) tablespaces.' where msmttyp_nm='NumSMSTablespaces' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of times that agents have been stolen.' where msmttyp_nm='NumStolenAgents' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='4KPgs', MsmtTyp_Ds='The number of package cache size pages.' where msmttyp_nm='PackageCacheSize' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The data pages read per prefetch request ratio.' where msmttyp_nm='PagesPerPrefetch' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The percentage of currently connected applications that are waiting on a lock.' where msmttyp_nm='PctApplsInLockWait' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The percentage of successful asynchronous read requests.' where msmttyp_nm='PctAsyncReadReqSatisfied' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  Munit_Cd='PRC', MsmtTyp_Ds='The percentage of successful index and data page buffer pool hits.' where msmttyp_nm='PctBufferPoolHits' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The percentage of the maximum number of applications allowed that are connected to a database and are processing a unit of work.' where msmttyp_nm='PctConnectionsExecuting' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The percentage of total SQL statements that were Data Definition Language (DDL) statements.' where msmttyp_nm='PctDDLSqlStatements' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The percentage of the locklist used.' where msmttyp_nm='PctLockListUsed' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The percentage of log space used by the secondary log.' where msmttyp_nm='PctLogSpaceUsedBySecondary' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='PRC', MsmtTyp_Ds='The percentage of the allocated sort heap used.'  where msmttyp_nm='PctSortHeapUsed' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of times that a buffer pool data page was physically written to disk.' where msmttyp_nm='PhysicalDataWrites' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='The number of read requests that required physical input and output to get data pages into the buffer pool.' where msmttyp_nm='PhysicalDataReads' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of row deletions attempted.'  where msmttyp_nm='RowDeleteAttempts' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of row insertions attempted.'  where msmttyp_nm='RowInsertAttempts' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of row updates attempted.'  where msmttyp_nm='RowUpdateAttempts' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of rows that were selected and returned'  where msmttyp_nm='RowsSelected' and MSrc_Cd='CTD';
update TWG.MsmtTyp set  Munit_Cd='4KPgs' where msmttyp_nm='SortHeapThreshold' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  Munit_Cd='B' where msmttyp_nm='SpaceUsedSMS' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of SQL SELECT statements that were executed.'  where msmttyp_nm='SqlSelectsExecuted' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec' where msmttyp_nm='StatementElapsedTime' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of times physical data pages were read synchronously into the buffer pool.' where msmttyp_nm='SyncDataReads' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of times that data pages were written synchronously from the buffer pool to disk.'  where msmttyp_nm='SyncDataWrites' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of physical index page read requests that were performed synchronously.'  where msmttyp_nm='SyncIndexReads' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of physical index page write requests that were performed synchronously.'  where msmttyp_nm='SyncIndexWrites' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='Time (in milliseconds) applied to synchronous reads.'  where msmttyp_nm='SyncReadTime' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='Time (in milliseconds) applied in synchronous writes to disk.'  where msmttyp_nm='SyncWriteTime' and MSrc_Cd='CTD';
update TWG.MsmtTyp set Munit_Cd='MSec' where msmttyp_nm='TimePerStatement' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Number of automatic rebinds or recompiles that were attempted'  where msmttyp_nm='TotAutoRebindAttempts' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Total number of locks currently held' where msmttyp_nm='TotCurLocksHeld' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set  MsmtTyp_Ds='Total number of deadlocks'  where msmttyp_nm='TotDeadLocks' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='MSec', MsmtTyp_Ds='total time (in milliseconds) applied to direct reads and writes.' where msmttyp_nm='TotDirectIOTime' and msrc_cd='CTD'; 
update twg.msmttyp set  msmttyp_ds='total number of fcm buffers received by the database node where this monitoring source executes.'  where msmttyp_nm='TotFcmBuffsReceived' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='total number of fcm buffers sent from the database node' where msmttyp_nm='TotFcmBuffsSent' and msrc_cd='CTD'; 
update twg.msmttyp set  msmttyp_ds='total number of commits initiated internally.' where msmttyp_nm='TotInternalCommits' and msrc_cd='CTD'; 
update twg.msmttyp set  msmttyp_ds='total number of rollbacks initiated internally.'  where msmttyp_nm='TotInternalRollbacks' and msrc_cd='CTD';
update twg.msmttyp set munit_cd='Sec', msmttyp_ds='total elapsed time (in seconds) waiting for a lock to be granted.' where msmttyp_nm='TotLockWaitTime' and msrc_cd='CTD'; 
update twg.msmttyp set munit_cd='QTY', msmttyp_ds='total number of times that applications had to wait for locks.'  where msmttyp_nm='TotLockWaits' and msrc_cd='CTD';
update twg.msmttyp set munit_cd='4KPgs'  where msmttyp_nm='TotLogInputOutput' and msrc_cd='CTD'; 
update twg.msmttyp set munit_cd='MSec', msmttyp_ds='total time (in milliseconds) applied to processing read requests that caused data or index pages to be physically read from disk to the buffer pool.' where msmttyp_nm='TotPhysicalIOTime' and msrc_cd='CTD';  
update twg.msmttyp set munit_cd='MSec' where msmttyp_nm='TotPhysicalWriteTime' and msrc_cd='CTD';  
update twg.msmttyp set  msmttyp_ds='total number of physical read requests to get data or index pages into the buffer pool.' where msmttyp_nm='TotPoolReads' and msrc_cd='CTD';  
update twg.msmttyp set  msmttyp_ds='total number of times that buffer pool data or index pages were physically written to disk' where msmttyp_nm='TotPoolWrites' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='total number of secondary log files that are currently being used.' where msmttyp_nm='TotSecondaryLogsInUse' and msrc_cd='CTD'; 
update twg.msmttyp set munit_cd='MSec', msmttyp_ds='total sorting time during the monitoring interval' where msmttyp_nm='TotSortTime' and msrc_cd='CTD'; 
update twg.msmttyp set  msmttyp_ds='total number of sorts performed during the monitoring interval'  where msmttyp_nm='TotSorts' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='total number of sql rollback statements that were attempted.' where msmttyp_nm='TotSqlRollbackAttempts' and msrc_cd='CTD'; 
update twg.msmttyp set  msmttyp_ds='number of sql update insert and delete statements that were executed.' where msmttyp_nm='UIDSqlExecuted' and msrc_cd='CTD';  
update twg.msmttyp set  msmttyp_ds='total user cpu time. user cpu time represents time spent executing database manager code.'  where msmttyp_nm='TotUserCpuTime' and msrc_cd='CTD';  
update twg.msmttyp set munit_cd='MSec', msmttyp_nm='The time (in milliseconds) applied to all applications spent waiting for an input and output server (prefetcher) to finish loading pages into the buffer pool.' where msmttyp_nm='PrefetchWaitTime' and msrc_cd='CTD'; 
update twg.msmttyp set  msmttyp_ds='total number of sql commit statements. this value includes sql commit statements that are issued from the application(s) and internal commits that are initiated by the database manager for the application(s)' where msmttyp_nm='commits' and msrc_cd='CTD'; 
update twg.msmttyp set  msmttyp_ds='total number of cursors (local and remote) that are currently open.' where msmttyp_nm='OpenCursors' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='total number of blocking cursors (local and remote) that are currently open' where msmttyp_nm='OpenBlockingCursors' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='total number of rollbacks. this value includes sql rollback statements that are issued from the application(s) and internal rollbacks that are initiated by the database manager for the application(s)' where msmttyp_nm='Rollbacks' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='total number of row deletions attempted.'  where msmttyp_nm='RowsDeleted' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='total number of row inserts attempted.'  where msmttyp_nm='RowsInserted' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='total number of row updates attempted.this value includes the number of rows updated in the database as a result of internal database activity performed for the application' where msmttyp_nm='RowsUpdated' and msrc_cd='CTD';
update twg.msmttyp set  msmttyp_ds='number of sql requests that were submitted since the last commit' where msmttyp_nm='SqlReqSinceLastCommit' and msrc_cd='CTD';
update twg.msmttyp set munit_cd='MSec', msmttyp_ds='average time (in milliseconds) to perform synchronous data writes.'  where msmttyp_nm='AvgSyncWriteTime' and msrc_cd='CTD'; 
update twg.msmttyp set munit_cd='MSec' where msmttyp_nm='MostRecentConnectResponseTime' and msrc_cd='CTD'; 
update twg.msmttyp set munit_cd='QTY' where msmttyp_nm='LockTimeoutsDelta' and msrc_cd='CTD'; 
update twg.msmttyp set munit_cd='QTY', msmttyp_ds='number of times that applications had to wait for locks during the monitoring interval'  where msmttyp_nm='LockWaitsDelta' and msrc_cd='CTD';
update twg.msmttyp set munit_cd='Sec' where msmttyp_nm='UOWLockWaitTime' and msrc_cd='CTD';
update twg.msmttyp set munit_cd='MSec' where msmttyp_nm='MostRecentConnectElapsedTime' and msrc_cd='CTD';
update twg.msmttyp set munit_cd='4KPgs' where msmttyp_nm='ApplHeapAvailSize' and msrc_cd='CTD'; 
update twg.msmttyp set msmttyp_ds='percentage of sorts that overflowed during the monitoring interval' where msmttyp_nm='PctSortOverflowed' and msrc_cd='CTD';
update twg.msmttyp set msmttyp_ds='number of times a page cleaner was invoked (for any reason) during the monitoring interval' where msmttyp_nm='PageCleans' and msrc_cd='CTD'; 
update twg.msmttyp set msmttyp_ds='number of fcm message anchors during the monitoring interval' where msmttyp_nm='NumFcmAnchors' and msrc_cd='CTD'; 
update twg.msmttyp set msmttyp_ds='number of fcm connection entries during the monitoring interval' where msmttyp_nm='NumFcmConnections' and msrc_cd='CTD'; 
update twg.msmttyp set msmttyp_ds='number of fcm request blocks during the monitoring interval' where msmttyp_nm='NumFcmReqBlocks' and msrc_cd='CTD'; 
update twg.msmttyp set munit_cd='PRC', msmttyp_ds='percentage of piped sort requests that were rejected during the monitoring interval'  where msmttyp_nm='PctPipedSortReqRejected' and msrc_cd='CTD'; 
update twg.msmttyp set munit_cd='PRC', msmttyp_ds='catalog cache hit ratio (as a percentage) during the monitoring interval' where msmttyp_nm='PctCatCacheHits' and msrc_cd='CTD'; 
update twg.msmttyp set msmttyp_ds='number of lock escalations during the monitoring interval. exclusive lock escalations are included in this number' where msmttyp_nm='LockEscalations' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set MsmtTyp_Ds='Percentage of total SQL statements that were SQL UPDATE,INSERT, and DELETE statements executed during the monitoring interval' where msmttyp_nm='PctUidSqlStatements' and MSrc_Cd='CTD';
update TWG.MsmtTyp set MsmtTyp_Ds='Total number of rollbacks explicitly attempted. This value includes only the number of SQL ROLLBACK statements issued from the application(s)' where msmttyp_nm='RollbackSqlStatements' and MSrc_Cd='CTD'; 
update TWG.MsmtTyp set Munit_Cd='4KPgs', MsmtTyp_Ds='Total amount (in pages) of sort heap currently allocated for sorts' where msmttyp_nm='SortHeapAllocated' and MSrc_Cd='CTD';

-------------------------------------------------------------------------
-- Remove the Measurement Unit PGS that was added by the DB2 WEP v1.1.0
-------------------------------------------------------------------------
delete from twg.Munit where Munit_cd='PGS';

delete from twg.Munit where Munit_cd='MSEC';

-- create a temporary table for DB2 measurement types and insert the metric if they do not exist already.

declare global temporary table CTD_MsmtTyp (
   MUnit_Cd         CHAR(6) NOT NULL,
   MSrc_Cd      CHAR(6) NOT NULL,
   MsmtTyp_Nm       VARCHAR(120) NOT NULL,
   MsmtTyp_Ds VARCHAR(254)
)
with replace on commit preserve rows not logged
;
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps', 'CTD', 'SqlStatementsRate', 'Rate (statements per second) at which SQL statements were executed during the monitoring interval');

insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'AgentCreationRatio','The percentage of the number of agents created from a pool to the number of agents assigned from a pool.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'ApplControlHeapSize','The maximum number of allowed application control heap pages.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'ApplHeapAvailSize','The number of application heap pages that are available for each individual agent.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'ApplsInLockWait','The number of applications that are waiting for locks.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'ApplyRequiresRefresh','The number of subscriptions that the Apply program has failed to replicate.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Min', 'CTD', 'ApplySubscriptionLagTime','The amount of time for lagging subscriptions for the Apply program. A negative number indicates that the subscription is due in that number of minutes.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AppsCurConnected','The number of currently connected applications.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AppsReqInProcess','The number of currently connected applications for which the database manager is currently processing a request.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AsyncDataReads','The number of data pages read asynchronously into the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AsyncDataWrites','The number of times that a buffer pool data page was written asynchronously to disk.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AsyncIndexReads','The number of index pages that are read asynchronously into the buffer pool by a prefetcher.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AsyncIndexWrites','The number of times that a buffer pool index page was written asynchronously to disk.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AsyncReadTime','The total time (in milliseconds) that the database manager prefetchers spent reading data or index pages into the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AsyncWriteTime','The total time (in milliseconds) that the database manager page cleaners spent writing data or index pages from the buffer pool to disk.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AttemptedConnections','The number of connections attempted since the last db2start command or the last reset.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AvgAsyncReadsPerPoolRead','The ratio of buffer pool asynchronous data reads to the total number of pool reads.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AvgAsyncWritesPerPoolWrite','The ratio of buffer pool asynchronous writes (data and index) to the total number of pool writes.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgDirectReadTime','The average time (in milliseconds) used to perform a direct read.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgDirectWriteTime','The average time (in milliseconds) used to perform a direct write. ');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AvgLockEscalationConn','The average number of lock escalations per connection.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AvgLocksHeld','The average number of locks held by each connected application.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AvgPagesPerCleaner','The ratio of asyncronous pages written to page cleans.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgPoolIOTime','The average time (in milliseconds) needed to perform a buffer pool input or output operation.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgPoolReadTime','The average time (in milliseconds) for processing a database read request that caused data or index pages to be physically read from the disk to the buffer pool.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'AvgPoolWritesPerPoolRead','The ratio of pool writes to pool reads.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgPoolWriteTime','The average time (in milliseconds) to process a write request that caused data or index pages to be physically written from buffer pool to disk.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgSortTime','The average time (in milliseconds) to perform a sort.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgSyncIOTime','The average time (in milliseconds) needed to perform a synchronous input or output operation.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgSyncReadTime','The average time (in milliseconds) to perform a synchronous data read.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'AvgSyncWriteTime','The average time (in milliseconds) to perform a synchronous data write. ');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'BindPrecompileAttempts','The number of attempted binds and precompiles.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'BufferPoolDefaultSize','The default number of buffer pool pages.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Min', 'CTD', 'CaptureLag','The number of minutes since the Capture programrecorded the last log marker. This is known as the Capture Lag.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CapturePruning','The number of rows in the unit-of-work (UOW) table.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'CatalogCacheSize','The number of catalog cache pages.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CatCacheHeapFull','The number of times that an insert into the catalog cache failed because of a heap-full condition in the database heap.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CatCacheInsertAttempts','The number of times that the system tried to insert table descriptor information into the catalog cache.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CatCacheOverflows','The number of times that  an insert into the catalog cache failed because the catalog cache was full.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CatCacheTableLookups','The number of times that the catalog cache was referenced to obtain table descriptor information.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'ChangedPagesThreshold','The threshold for changed pages.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('B', 'CTD', 'ClientIOBlockSize','The current size (in bytes) of the client input and output block.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps', 'CTD', 'CommitRate','The unit-of-work commit attempt rate per second. Unit-of-work commits include SQL COMMIT statements that are issued from applications as well as internal commits that are initiated by the database manager.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'Commits','The total number of commits that have been executed, including SQL COMMIT statements and internal commits.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'ConnectionErrors','The number of times that a communication error occurred while a DCS application was attempting to connect to a host database, or while it was processing an SQL statement.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'ConnWaitingForClientCurrent','The number of connections to the host databases that are waiting for the client to send a request.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'ConnWaitingForHostCurrent','The number of connections to the host databases that are waiting for the client to send a request.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CurAgentsPriority','The current priority of agents.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CurAgentsWaiting','The number of agents that are waiting for a token so that they can execute a transaction.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CurMaxAgents','The maximum number of allowed agents.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'CurrentConnections','The current number of connections.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'DB2Down','The percentage of time that the instance is Down.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'DB2Up','The percentage of time that the instance is Up.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'DDLSqlStatements','The total number of executed SQL DDL statements.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'DirectReadAvgSectorsPer','The average number of sectors that are read in a direct read request.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'DirectReadRequests','The number of requests to perform a direct read from disk of one or more sectors of data.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'DirectReads','The number of direct reads that have not used the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'DirectReadTime','The amount of time (in milliseconds) used for performing direct reads.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'DirectWriteAvgSectorsPer','The average number of sectors that are written by a direct write.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'DirectWriteRequests','The number of requests to perform a direct write of one or more sectors of data.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'DirectWrites','The number of write operations that have not used the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'DirectWriteTime','The time (in milliseconds) used for performing direct writes.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'DynamicSqlStatements','The total number of attempted dynamic SQL statements.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'FailedSqlStatements','The total number of failed attempted SQL statements.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'FailedSubscriptions','The number of subscriptions the Apply program failed to replicate.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'FilesClosed','The total number of files that have been closed.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'FreeFcmBuffers','The number of free FCM buffers.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'FreeFcmConnections','The number of free FCM connection entries.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'FreeFcmRequestBlocks','The number of free FCM request blocks.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Bps', 'CTD', 'HostThroughput','The number of bytes sent, plus the number of bytes received, divided by the cumulative host response time.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'HostTimePerStatement','The cumulative host response time divided by the number of statements attempted.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'IndexCopiedFromExtStorage','The number of buffer pool index pages copied from extended storage.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'IndexCopiedToExtStorage','The number of buffer pool index pages copied to extended storage.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'InputOutputCleaners','The number of asynchronous page cleaners.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps', 'CTD', 'InputOutputRate','The buffer pool input and output operation rate per second. This includes all physical data and index pages that go through the buffer pool when read or written.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'InputOutputServers','The number of input and output servers.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'InternalRowDeletes','The total number of rows deleted as a result of internal activity.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'InternalRowInserts','The total number of rows inserted as a result of internal activity.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'InternalRowUpdates','The total number of rows updated as a result of internal activity.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'LaggingSubscriptions','The number of lagging subscriptions for the Apply program.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('B', 'CTD', 'LocklistMemInUse','The total number of bytes of lock list memory that is in use.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'LockTimeouts','The total number of times that an object lock request timed out and was not granted.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'LogBufferSize','The number of log buffer pages.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'LogicalDataReads','The number of logical data page read requests that went through the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'LogicalIndexReads','The number of logical index page read requests  that went through the buffer pool.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'LogPageReads','The number of pages that the DB2 logging system has read from disk.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'LogPageWrites','The number of pages that the DB2 logging system has written to disk.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'LogSpaceCleanersInvoked','The number of times a page cleaner was invoked because the used logging space reached a predefined criterion.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MaxAgentsRegistered','The largest amount of agents registered since the database manager has started.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MaxAgentsWaiting','The largest amount of agents that have waited for a token at the same time since the database manager started.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MaxAssociatedAgents','The maximum number of agents that have been connected at one time.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MaxConcurrentAgents','The maximum number of database manager coordinator agents that can concurrently execute a database manager transaction.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MaxCoordAgents','The maximum number of coordinating agents that have been connected at one time.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MaxCurrentConnections','The highest number of simultaneous connections (both local and remote) made to a database since the first application connected to the database.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MB', 'CTD', 'MaxHeapAllocated','The largest amount of database heap allocated and used by the database since the first application connected to the database.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'MaxLocklistStorage','The maximum allowed number of lock list pages.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'MaxPctLocklist','The percentage of the lock list held by an application that must be filled before the database manager performs an escalation.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MaxPoolAgents','The maximum number of idle agents in the agent pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('B', 'CTD', 'MaxPrimaryLogSpaceUsed','The maximum number of bytes used by the primary log.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'MaxQueryHeapSize','The maximum amount of memory that can be allocated for the query heap.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('B', 'CTD', 'MaxSecondaryLogUsed','The maximum number of bytes used by the secondary log.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('B', 'CTD', 'MaxTotalLogSpaceUsed','The maximum number of bytes of total log space used.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MinCommits','The minimum required number of commits allowed to group together.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MinFreeFcmBuffers','The lowest number of free buffers reached during processing.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MinFreeFcmConnections','The lowest number of free connection entries reached during processing.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MinFreeFcmMsgAnchors','The lowest number of free message anchors reached during processing.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'MinFreeFcmReqBlocks','The lowest number of free request blocks reached during processing.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'MonHeapSize','The number of database system monitor heap pages.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'MostRecentConnectElapsedTime','The elapsed connection time of the most recently disconnected DCS application. ');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'MostRecentConnectResponseTime','The elapsed time between the start of connection processing and actual establishment of a connection for the most recent DCS application connection.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'NetworkTimePerStatement','The cumulative host response time, minus cumulative statement execution time, divided by the number of statements attempted.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumActiveSorts','The number of sorts that have a sort heap allocated.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumAgentsRegistered','The number of agents registered.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumConnectionsToLocalDBases','The number of local databases that have applications connected.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumDMSTablespaces','The number of Database Managed Space (DMS) tablespaces.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumEventMonitors','The number of defined event monitors.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumFcmAnchors','The number of FCM message anchors.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumFcmBuffers','The number of buffers that are used for internal communications (messages) among the nodes and within the nodes.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumFcmConnections','The number of FCM connection entries.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumFcmNodes','The number of nodes in the current DB2 partitioned configuration.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumFcmReqBlocks','The number of FCM request blocks.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumIdleAgents','The number of idle agents in the agent pool that are unassigned to an application.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumInactiveNodes','The number of inactive nodes.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumInvalidPkgsALL','The number of packages that are marked invalid.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumInvalidPkgsSYSTEM','The number of SYSTEM packages that are marked invalid.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumInvalidPkgsUSER','The number of USER packages that are marked invalid.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumInvalidTriggers','The number of triggers that are marked invalid.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumLocalConnections','The number of local applications currently connected to a local database within the DB2 instance.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumLocalConnectionsExecuting','The number of local applications currently connected to a local database within the DB2 instance and that are currently processing a unit of work.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumPipedSortsAccepted','The number of piped sorts that have been accepted.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumPipedSortsRequested','The number of piped sorts that have been requested.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumPrimaryLogs','The number of primary log files.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumRemoteConnections','The number of current application connections that remote clients have initiated to the DB2 instance.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumRemoteConnectionsExecuting','The number of remote applications currently connected to a local database within the DB2 instance and that are currently processing a unit of work.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumRows','The total number of rows.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumSMSTablespaces','The number of System Managed Space (SMS) tablespaces.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumStolenAgents','The number of times that agents have been stolen. ');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumTables','The number of tables.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumTablespaces','The number of tablespaces.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumTablespacesWithLONG','The number of tablespaces that store LONG data.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumTriggers','The number of defined triggers.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumUnassignedAgents','The number of agents in the agent pool that are currently unassigned to an application.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumUserIndexes','The number of indexes created by users. Indexes created by SYSIBM are not counted.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'NumViews','The number of views.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'OpenBlockingCursors','The total number of blocking cursors (local and remote) that are currently open.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'OpenCursors','The total number of cursors (local and remote) that are currently open.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'OutboundBytesReceived','The number of bytes received from the host excluding communication protocol overhead.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'OutboundBytesSent','The number of bytes sent to the host excluding communication protocol overhead.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'OverflowAccesses','The number of accesses (reads and writes) made to overflowed rows.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PackageCacheInserts','The number of times that a section had to be loaded into the package cache because an application found that the section it wanted was not yet in the package cache.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PackageCacheLookups','The number of times that an application looked for a section in the package cache.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'PackageCacheSize','The number of package cache size pages.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PageCleanersDueToDirtyThreshold','The total number of page cleaner invocations due to a dirty page threshold.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PagesCopiedFromExtStorage','The number of buffer pool data pages copied from extended storage.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PagesCopiedToExtStorage','The number of buffer pool data pages copied to extended storage.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PagesPerPrefetch','The data pages read per prefetch request ratio.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctAgentsWaiting','The percentage of registered agents that are waiting to execute a transaction. This value is defined as agents waiting for a token, divided by maximum agents registered, times 100.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctApplsInLockWait','The percentage of currently connected applications that are waiting on a lock.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctAsyncReadReqSatisfied','The percentage of successful asynchronous read requests.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctBufferPoolHits','The percentage of successful index and data page buffer pool hits.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctCatCacheHits','The percentage of successful catalog cache hits.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctConnectionsExecuting','The percentage of the maximum number of applications allowed that are connected to a database and are processing a unit of work.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctConnectionsUsed','The percentage of the allowed number of connections that are concurrent connections.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctDDLSqlStatements','The percentage of total SQL statements that were Data Definition Language (DDL) statements.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctDeadlockRollbacks','The percentage of rollbacks due to deadlocks compared to total rollbacks.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctExtStorageReadWrite','The percentage of data and index pages copied from extended storage to pages copied to extended storage.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctFailedSqlStatements','The percentage of total SQL statements that failed.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctFcmBuffsInUse','The percentage of FCM buffers that are used.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctFcmConnInUse','The percentage of FCM connection entries that are used.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctFcmReqBlocksUsed','The percentage of FCM request blocks used during processing.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctIndexHits','The percentage of successful index pages hits.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctIntDeadlockedRollbacks','The percentage of rollbacks due to deadlocks compared to internal rollbacks.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctLockListUsed','The percentage of the locklist used.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctLogSpaceUsedByPrimary','The percentage of log space used by the primary log.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctLogSpaceUsedBySecondary','The percentage of log space used by the secondary log.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctMaxFcmConnUsed','The high water mark of percentage of FCM connection entries used during processing.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctMaxFcmMsgAnchorUsed','The high water mark of percentage of FCM message anchors used during processing.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctPackageCacheHits','The package cache hit ratio percentage. This is (package_cache_lookups - package_cache_inserts) / all_package_cache_lookups.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctPipedSortHits','The piped sort hit ratio (accepted / requested) given as a percentage.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctPipedSortReqRejected','The piped sort miss ratio (rejected / requested) given as a percentage.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctPrivateMemUsed','The percentage of private memory used. This value is not valid for UNIX systems.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctSelectSqlStatements','The percentage of total SQL statements that were SELECT statements.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctSortHeapUsed','The percentage of the allocated sort heap used.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctSortOverflowed','The percentage of sort requests that overflowed.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctSpaceUsedDMS','The percentage of space used in a Database Managed Space (DMS) tablespace.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'PctUidSqlStatements','The percentage of total SQL statements that were SQL UPDATE, INSERT, and DELETE statements.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PhysicalDataReads','The number of read requests that required physical input and output to get data pages into the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PhysicalDataWrites','The number of times that a buffer pool data page was physically written to disk.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PhysicalIndexReads','The number of physical read requests used to get index pages into the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PhysicalIndexWrites','The number of times that a buffer pool index page was physically written to disk.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'PipedSortReqRejected','The total number of rejected piped sorts.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'PreFetchWaitTime','The time (in milliseconds) applied to all applications spent waiting for an input and output server (prefetcher) to finish loading pages into the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('B', 'CTD', 'PrimaryLogSpaceAllocated','The number of bytes allocated to the primary log.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps', 'CTD', 'RollbackRate','The unit-of-work rollback attempt rate per second. Unit-of-work rollbacks include SQL ROLLBACK statements that are issued from applications as well as internal rollbacks that are initiated by the database manager.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'Rollbacks','The total number of rollbacks attempted including SQL ROLLBACK statements and internal rollbacks.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'RollbackSqlStatements','The number of attempted SQL ROLLBACK statements.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'RowDeleteAttempts','The number of attempted row deletions.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'RowInsertAttempts','The number of attempted row insertions.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'RowsDeleted','The total number of row attempted deletions, including SQL DELETE statements and internal deletions.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'RowsInserted','The total number of row attempted inserts, including SQL INSERT statements and internal inserts.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps', 'CTD', 'RowsReadRate','The average number of rows read per second.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'RowsSelected','The number of rows that have been selected and returned.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'RowsUpdated','The total number of attempted row updates, including SQL UPDATE statements and internal updates.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Qps', 'CTD', 'RowsWrittenRate','The average number of changes (inserts, deletes, updates) per second.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'RowUpdateAttempts','The number of attempted row updates.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SectionInserts','The number of inserts of SQL sections from the SQL work area.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SectionLookups','The number of lookups of SQL sections from the SQL work area.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SortHeapAllocated','The total number of pages of sort heap currently allocated for all sorts.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'SortHeapThreshold','The number of sort heap threshold pages.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('B', 'CTD', 'SpaceUsedSMS','The number of bytes allocated to a System Managed Space (SMS) tablespace.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SqlReqSinceLastCommit','The number of submitted SQL requests since the last commit.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SqlSelectsExecuted','The number of executed SQL SELECT statements.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('B', 'CTD', 'SqlStatementSize','The SQL statement size.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'StatementElapsedTime','The sum of the elapsed time for all executed statements.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'StatementSorts','The total number of times that a set of data was sorted to process the OPEN operation of the current SQL statement.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'StaticSqlAttempts','The number of static SQL statements that have been attempted.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SyncDataReads','The number of times physical data pages were read synchronously into the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SyncDataWrites','The number of times that data pages were written synchronously from the buffer pool to disk.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SyncIndexReads','The number of physical index pages that were read synchronously.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'SyncIndexWrites','The number of physical index page write requests that were performed synchronously.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'SyncReadTime','The time (in milliseconds) applied to synchronous reads.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'SyncWriteTime','The time (in milliseconds) applied in synchronous writes to disk.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TableDataReorgNeeded','The percentage of time that at least one table needs to be reorganized.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TableDataReorgNotNeeded','The percentage of time that no table needs to be reorganized.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TableIndexReorgNeeded','The percentage of time that at least one index needs to be reorganized.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TableIndexReorgNotNeeded','The percentage of time that no index needs to be reorganized.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspBackupPending','The percentage of time that the table space state is Backup Pending.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspBackupProgress','The percentage of time that the state of the table space is Backup in Progress.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspDeletePending','The percentage of time that the state of the table space is Delete Pending.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspDisablePending','The percentage of time that the state of the table space is Disable Pending.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspDMSRebalance','The percentage of time that the state of the table space is DMS Rebalancer in Progress.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspDropPending','The percentage of time that the state of the table space is Drop Pending.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspLoadPending','The percentage of time that the state of the table space is Load Pending.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspNormal','The percentage of time that the state of the table space is Normal.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspOffline','The percentage of time that the state of the table space is Offline.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspQuiescedEx','The percentage of time that the state of the table space is Quiesce: EXCLUSIVE.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspQuiescedSh','The percentage of time that the state of the table space is Quiesce: SHARE.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspQuiescedUp','The percentage of time that the state of the table space is Quiesce: UPDATE.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspReorgProgress','The percentage of time that the state of the table space is Reorganization in Progress.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspRestorePending','The percentage of time that the state of the table space is Restore Pending.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspRestoreProgress','The percentage of time that the state of the table space is in Progress.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspRFpending','The percentage of time that the state of the table space is Rollback Forward Pending.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspRFprogress','The percentage of time that the state of the table space is Rollback Forward in Progress.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspStorageUndefined','The percentage of time that the state of the table space is Storage Undefined.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspStorDef','The percentage of time that the state of the table space is Storage may be Defined.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspStorDefChanged','The percentage of time that the state of the table space is Storage Definition was Changed.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspStorDefFinal','The percentage of time that the state of the table space is Storage Definition in Final State.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspTBScreate','The percentage of time that the state of the table space is Create in Progress.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('PRC', 'CTD', 'TbspTBSdelete','The percentage of time that the state of the table space is Delete in Progress.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'TimePerStatement','The cumulative statement execution time divided by the number of statements attempted.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotalConnections','The number of connections made to a database since the first database connection.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotAutoRebindAttempts','The number of attempted automatic rebinds or recompiles.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotCurLocksHeld','The total number of locks held by all applications.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotDeadlockIntRollbacks','The total number of forced rollbacks initiated by the database manager because of a deadlock.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotDeadLocks','The total number of deadlocks that have occurred.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'TotDirectIOTime','The total time (in milliseconds) used for direct reads and writes.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotFcmBuffsReceived','The total number of FCM buffers received by a given database partition.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotFcmBuffsSent','The total number of FCM buffers sent from a given database partition.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotInternalCommits','The total number of internally initiated commits.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotInternalRollbacks','The total number of internally initiated rollbacks.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotLockWaits','The total number of times that an application requested a lock but had to wait because another connection was already holding a lock on the data.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Sec', 'CTD', 'TotLockWaitTime','The total elapsed time (in seconds) that all applications waited for a lock.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('4KPgs', 'CTD', 'TotLogInputOutput','The total amount of log input and output. This is the sum of the number of log pages read plus the number of log pages written.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'TotPhysicalIOTime','The total time (in milliseconds) applied to physical buffer pool input and output operations (including both synchronous and asynchronous reads and writes).');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'TotPhysicalReadTime','The total time (in milliseconds) applied to processing read requests that caused data or index pages to be physically read from disk into the buffer pool. ');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'TotPhysicalWriteTime','The total time (in milliseconds) for buffer pool physical writes (including asynchronous writes).');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotPoolReads','The total number of physical read requests to get data or index pages into the buffer pool.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotPoolWrites','The total number of times that buffer pool data or index pages were physically written to disk.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotSecondaryLogsInUse','The number of allocated secondary log files.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotSorts','The total number of executed sorts.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('MSec', 'CTD', 'TotSortTime','The total elapsed time (in milliseconds) for all the sorts that have been executed. ');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotSqlCommitAttempts','The total number of attempted SQL COMMIT statements.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotSqlRollbackAttempts','The total number of attempted SQL ROLLBACK statements.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'TotSyncInputOutput','The total number of synchronous reads and writes for both data and index pages.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Sec', 'CTD', 'TotSystemCpuTime','The number of seconds spent in system calls.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Sec', 'CTD', 'TotUserCpuTime','The number of seconds spent executing database manager code.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'UIDSqlExecuted','The total number of attempted SQL UPDATE, INSERT, and DELETE statements.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('Sec', 'CTD', 'UOWLockWaitTime','The total  amount of elapsed time (in seconds) that the unit of work (UOW) waited for locks.');
----# insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'VictimPageCleanersInvoked','The number of times a page cleaner was invoked because a synchronous write was needed to make space for new pages in the buffer pool.');
insert into session.CTD_MsmtTyp (Munit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ('QTY', 'CTD', 'WorkLoad','The ratio of the maximum number of subagents associated with an application, to the number of agents that are stolen from the application by DB2 to work on a different application.');

-- insert the DB2 measurement types into the generic schema
-- if not exist already

insert into TWG.MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds)
select
  m.MUnit_Cd,
  m.MSrc_Cd,
  m.MsmtTyp_Nm,
  m.MsmtTyp_Ds
from
  session.CTD_MsmtTyp m
where Not exists (
  select 1 from
      TWG.MsmtTyp t
  where
      t.MsmtTyp_Nm=m.MsmtTyp_Nm)
  order by m.msmttyp_nm
;


-- create a temporary table for DB2 measurement types

declare global temporary table CTD_MsmtRul (
  CompTyp_Cd           CHAR(17) NOT NULL,
  MsmtTyp_ID           INTEGER NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.CTD_MsmtRul select
'CTD_APPL',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----Bufferpool Activity
------------------------
----# 'LogicalDataReads',
'PctBufferPoolHits',
'PctIndexHits',
----# 'PhysicalDataReads',
----# 'PhysicalIndexReads',
----# 'PhysicalIndexWrites',
----# 'PreFetchWaitTime',
----# 'TotPhysicalIOTime',
----# 'TotPhysicalReadTime',
----# 'TotPhysicalWriteTime',

----Connections 
------------------------

----CPU Utilization
------------------------
'TotSystemCpuTime',
'TotUserCpuTime',

----DB2 Agents
------------------------
----# 'MaxAssociatedAgents',
----# 'NumStolenAgents',
'WorkLoad',

----Direct IO
------------------------
----# 'DirectReads',
----# 'DirectWrites',
'DirectReadAvgSectorsPer',
----# 'DirectWriteAvgSectorsPer',

----Lock Waits
------------------------
----# 'TotLockWaits',
----# 'UOWLockWaitTime',

----Locks / DeadLocks
------------------------
----# 'TotCurLocksHeld',

----Locks / DeadLocks
------------------------
'PctLockListUsed',

----Sorts
------------------------
----# 'StatementSorts',
----# 'TotSorts',

----SQL Statement Activity
------------------------
----# 'BindPrecompileAttempts',
----# 'Commits',
'DDLSqlStatements',
----# 'DynamicSqlStatements',
----# 'FailedSqlStatements',
'OpenBlockingCursors',
'OpenCursors',
----# 'PctDDLSqlStatements',
----# 'PctUidSqlStatements',
----# 'Rollbacks',
----# 'RollbackSqlStatements',
----# 'RowsDeleted',
----# 'RowsInserted',
----# 'RowsSelected',
----# 'RowsUpdated',
----# 'SectionInserts',
----# 'SectionLookups',
----# 'SqlReqSinceLastCommit',
'SqlSelectsExecuted',
----# 'StaticSqlAttempts',
'UIDSqlExecuted'
);

insert into session.CTD_MsmtRul select
'CTD_APPLY_ID',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----Replication
------------------------
'FailedSubscriptions',
'LaggingSubscriptions'
----# ,

----Status
------------------------
);


insert into session.CTD_MsmtRul select
'CTD_DATABASE',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----Application Activity
------------------------
----# 'AppsCurConnected',
----# 'AppsReqInProcess',
----# 'MaxCurrentConnections',
----# 'PctConnectionsUsed',
----# 'TotalConnections',

----BufferPool - External Storage
------------------------
'PctExtStorageReadWrite',
----# 'PagesCopiedFromExtStorage',
----# 'PagesCopiedToExtStorage',
----# 'IndexCopiedFromExtStorage',
----# 'IndexCopiedToExtStorage',

----Bufferpool Activity
------------------------
----# 'AsyncDataReads',
----# 'AsyncDataWrites',
----# 'AsyncIndexReads',
----# 'AsyncIndexWrites',

----Bufferpool Activity
------------------------
----# 'AsyncReadTime',
----# 'AsyncWriteTime',
'AvgAsyncReadsPerPoolRead',
'AvgAsyncWritesPerPoolWrite',
----# 'AvgPagesPerCleaner',
'AvgPoolIOTime',
'AvgPoolReadTime',
'AvgPoolWritesPerPoolRead',
'AvgPoolWriteTime',
'AvgSyncIOTime',
'AvgSyncReadTime',
'AvgSyncWriteTime',
----# 'FilesClosed',
----# 'InputOutputRate',
----# 'LogicalDataReads',
----# 'LogicalIndexReads',
----# 'LogSpaceCleanersInvoked',
----# 'PageCleanersDueToDirtyThreshold',

----Bufferpool Activity
------------------------
----# 'PagesPerPrefetch',
'PctBufferPoolHits',
'PctIndexHits',
----# 'PhysicalDataReads',
----# 'PhysicalDataWrites',
----# 'PhysicalIndexReads',
----# 'PhysicalIndexWrites',
----# 'PreFetchWaitTime',
----# 'SyncDataReads',
----# 'SyncDataWrites',
----# 'SyncIndexReads',
----# 'SyncIndexWrites',
----# 'SyncReadTime',
----# 'SyncWriteTime',
----# 'TotPhysicalIOTime',
----# 'TotPhysicalReadTime',
----# 'TotPhysicalWriteTime',
----# 'TotPoolReads',
----# 'TotPoolWrites',
----# 'TotSyncInputOutput',
----# 'VictimPageCleanersInvoked',

----Catalog Cache
------------------------
----# 'CatCacheHeapFull',
----# 'CatCacheInsertAttempts',
----# 'CatCacheOverflows',
----# 'CatCacheTableLookups',
'PctCatCacheHits',

----Configuration
------------------------
----# 'NumDMSTablespaces',
----# 'NumEventMonitors',
----# 'NumInvalidPkgsALL',
----# 'NumInvalidPkgsSYSTEM',
----# 'NumInvalidPkgsUSER',
----# 'NumInvalidTriggers',
----# 'NumSMSTablespaces',
----# 'NumTables',
----# 'NumTablespaces',
----# 'NumTablespacesWithLONG',
----# 'NumTriggers',
----# 'NumUserIndexes',
----# 'NumViews',

----Configuration
------------------------
'ApplControlHeapSize',
'ApplHeapAvailSize',
'BufferPoolDefaultSize',
----# 'CatalogCacheSize',
'ChangedPagesThreshold',
'InputOutputCleaners',
'InputOutputServers',
'LogBufferSize',
----# 'MaxActiveApplications',
'MaxLocklistStorage',
'MaxPctLocklist',
'MinCommits',

----Configuration
------------------------
'NumPrimaryLogs',
'PackageCacheSize',

----Configuration
------------------------

----DB2 Agents
------------------------
----# 'MaxAssociatedAgents',
----# 'MaxCoordAgents',

----Direct IO
------------------------
'AvgDirectReadTime',
'AvgDirectWriteTime',
'DirectReadAvgSectorsPer',
----# 'DirectReadRequests',
----# 'DirectReads',
----# 'DirectReadTime',
----# 'DirectWriteAvgSectorsPer',
----# 'DirectWriteRequests',
----# 'DirectWrites',
----# 'DirectWriteTime',
----# 'TotDirectIOTime',

----# 'TotLockWaits',
----# 'TotLockWaitTime',

----Lock Waits
------------------------
'PctApplsInLockWait',
----# 'ApplsInLockWait',

----Logging
------------------------
'LogPageReads',
'LogPageWrites',
----# 'MaxPrimaryLogSpaceUsed',
----# 'MaxSecondaryLogUsed',
----# 'MaxTotalLogSpaceUsed',
'PctLogSpaceUsedByPrimary',
'PctLogSpaceUsedBySecondary',
----# 'PrimaryLogSpaceAllocated',
'TotLogInputOutput',
'TotSecondaryLogsInUse',

----Locks / DeadLocks
------------------------
'AvgLockEscalationConn',
'AvgLocksHeld',

----Locks / DeadLocks
------------------------

----Locks / DeadLocks
------------------------
----# 'LocklistMemInUse',
----# 'LockTimeouts',

----Locks / DeadLocks
------------------------
'PctDeadlockRollbacks',
'PctIntDeadlockedRollbacks',
'PctLockListUsed',
----# 'TotCurLocksHeld',

----Locks / DeadLocks
------------------------
----# 'TotDeadLocks',

----Locks / DeadLocks
------------------------

----Logging
------------------------

----Memory
------------------------
----# 'MaxHeapAllocated',

----Package Cache
------------------------
'PackageCacheInserts',
'PackageCacheLookups',
'PctPackageCacheHits',

----Replication
------------------------
'CaptureLag',
----# 'CapturePruning',

----Sorts
------------------------
----# 'AvgSortTime',
----# 'NumActiveSorts',
'PctSortOverflowed',
----# 'SortHeapAllocated',
----# 'TotSorts',
----# 'TotSortTime',

----SQL Statement Activity
------------------------
----# 'BindPrecompileAttempts',
'CommitRate',
----# 'DDLSqlStatements',
----# 'DynamicSqlStatements',
'FailedSqlStatements',
----# 'InternalRowDeletes',
----# 'InternalRowInserts',
----# 'InternalRowUpdates',
----# 'PctDDLSqlStatements',
'PctFailedSqlStatements',
'PctSelectSqlStatements',
'RollbackRate',
----# 'RowDeleteAttempts',
----# 'RowInsertAttempts',
----# 'RowsSelected',
----# 'RowUpdateAttempts ',
'SqlSelectsExecuted',
'SqlStatementsRate',
----# 'StaticSqlAttempts',
----# 'TotAutoRebindAttempts',
----# 'TotInternalCommits',
----# 'TotInternalRollbacks',
----# 'TotSqlCommitAttempts',
----# 'TotSqlRollbackAttempts',
'UIDSqlExecuted'
----#,

----Status
------------------------
);

insert into session.CTD_MsmtRul select
'CTD_NODE',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----Application Activity
------------------------
----# 'AppsCurConnected',
----# 'AppsReqInProcess',
----# 'MaxCurrentConnections',
'PctConnectionsUsed',
----# 'TotalConnections',

----BufferPool - External Storage
------------------------
'PctExtStorageReadWrite',
----# 'PagesCopiedFromExtStorage',
----# 'PagesCopiedToExtStorage',
----# 'IndexCopiedFromExtStorage',
----# 'IndexCopiedToExtStorage',

----Bufferpool Activity
------------------------
----# 'AsyncDataReads',
----# 'AsyncDataWrites',
----# 'AsyncIndexReads',
----# 'AsyncIndexWrites',

----Bufferpool Activity
------------------------
----# 'AsyncReadTime',
----# 'AsyncWriteTime',
'AvgAsyncReadsPerPoolRead',
'AvgAsyncWritesPerPoolWrite',
----# 'AvgPagesPerCleaner',
'AvgPoolIOTime',
'AvgPoolReadTime',
'AvgPoolWritesPerPoolRead',
'AvgPoolWriteTime',
'AvgSyncIOTime',
'AvgSyncReadTime',
'AvgSyncWriteTime',
----# 'FilesClosed',
----# 'InputOutputRate',
----# 'LogicalDataReads',
----# 'LogicalIndexReads',
----# 'LogSpaceCleanersInvoked',
----# 'PageCleanersDueToDirtyThreshold',

----Bufferpool Activity
------------------------
----# 'PagesPerPrefetch',
'PctBufferPoolHits',
'PctIndexHits',
----# 'PhysicalDataReads',
----# 'PhysicalDataWrites',
----# 'PhysicalIndexReads',
----# 'PhysicalIndexWrites',
----# 'PreFetchWaitTime',
----# 'SyncDataReads',
----# 'SyncDataWrites',
----# 'SyncIndexReads',
----# 'SyncIndexWrites',
----# 'SyncReadTime',
----# 'SyncWriteTime',
----# 'TotPhysicalIOTime',
----# 'TotPhysicalReadTime',
----# 'TotPhysicalWriteTime',
----# 'TotPoolReads',
----# 'TotPoolWrites',
----# 'TotSyncInputOutput',
----# 'VictimPageCleanersInvoked',

----Catalog Cache
------------------------
----# 'CatCacheHeapFull',
----# 'CatCacheInsertAttempts',
----# 'CatCacheOverflows',
----# 'CatCacheTableLookups',
'PctCatCacheHits',

----DB2 Agents
------------------------
----# 'MaxAssociatedAgents',
----# 'MaxCoordAgents',

----Direct IO
------------------------
'AvgDirectReadTime',
'AvgDirectWriteTime',
'DirectReadAvgSectorsPer',
----# 'DirectReadRequests',
----# 'DirectReads',
----# 'DirectReadTime',
----# 'DirectWriteAvgSectorsPer',
----# 'DirectWriteRequests',
----# 'DirectWrites',
----# 'DirectWriteTime',
----# 'TotDirectIOTime',

----FCM Activity
------------------------
----# 'FreeFcmBuffers',
----# 'FreeFcmConnections',
----# 'FreeFcmRequestBlocks',
----# 'MinFreeFcmBuffers',
----# 'MinFreeFcmConnections',
----# 'MinFreeFcmMsgAnchors',
----# 'MinFreeFcmReqBlocks',
----# 'NumFcmNodes',
'PctFcmBuffsInUse',
'PctFcmConnInUse',
----# 'PctFcmReqBlocksUsed',
'PctMaxFcmConnUsed',
'PctMaxFcmMsgAnchorUsed',
----# 'TotFcmBuffsReceived',
----# 'TotFcmBuffsSent',


----Lock Waits
------------------------
----# 'TotLockWaits',
----# 'TotLockWaitTime',

----Lock Waits
------------------------
'PctApplsInLockWait',
----# 'ApplsInLockWait',

----Logging
------------------------
'LogPageReads',
'LogPageWrites',
----# 'MaxPrimaryLogSpaceUsed',
----# 'MaxSecondaryLogUsed',
----# 'MaxTotalLogSpaceUsed',
'PctLogSpaceUsedByPrimary',
'PctLogSpaceUsedBySecondary',
----# 'PrimaryLogSpaceAllocated',
'TotLogInputOutput',
'TotSecondaryLogsInUse',

----Locks / DeadLocks
------------------------
'AvgLockEscalationConn',
'AvgLocksHeld',

----Locks / DeadLocks
------------------------

----Locks / DeadLocks
------------------------
----# 'LocklistMemInUse',

----Locks / DeadLocks
------------------------
----# 'LockTimeouts',

----Locks / DeadLocks
------------------------
'PctDeadlockRollbacks',
'PctIntDeadlockedRollbacks',
----# 'TotCurLocksHeld',
----# 'TotDeadlockIntRollbacks',
----# 'TotDeadLocks',

----Logging
------------------------

----Memory
------------------------

----Package Cache
------------------------
'PackageCacheInserts',
'PackageCacheLookups',
'PctPackageCacheHits',

----Sorts
------------------------
----# 'AvgSortTime',
----# 'NumActiveSorts',
'PctSortOverflowed',
----# 'SortHeapAllocated',
----# 'TotSorts',
----# 'TotSortTime',

----SQL Statement Activity
------------------------
----# 'BindPrecompileAttempts',
'CommitRate',
----# 'DDLSqlStatements',
----# 'DynamicSqlStatements',
'FailedSqlStatements',
----# 'InternalRowDeletes',
----# 'InternalRowInserts',
----# 'InternalRowUpdates',
----# 'PctDDLSqlStatements',
'PctFailedSqlStatements',
'PctSelectSqlStatements',
'RollbackRate',
----# 'RowDeleteAttempts',
----# 'RowInsertAttempts',
----# 'RowsSelected',
----# 'RowUpdateAttempts ',
'SqlSelectsExecuted',
'SqlStatementsRate',
----# 'StaticSqlAttempts',
----# 'TotAutoRebindAttempts',
----# 'TotInternalCommits',
----# 'TotInternalRollbacks',
----# 'TotSqlCommitAttempts',
----# 'TotSqlRollbackAttempts',
'UIDSqlExecuted'

);


insert into session.CTD_MsmtRul select
'CTD_GATEWAY',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----Connections
------------------------
----# 'AttemptedConnections',
'ConnectionErrors',
----# 'ConnWaitingForClientCurrent',
'ConnWaitingForHostCurrent',
'CurrentConnections',
----# 'MostRecentConnectElapsedTime',
'MostRecentConnectResponseTime',
----# 'StatementElapsedTime',

----Host Throughput
------------------------
'HostThroughput',
'HostTimePerStatement',
'NetworkTimePerStatement',
----# 'OutboundBytesReceived',
----# 'OutboundBytesSent',
'TimePerStatement'
);

insert into session.CTD_MsmtRul select
'CTD_INSTANCE',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----Connections
------------------------
----# 'NumConnectionsToLocalDBases',
----# 'NumLocalConnections',
----# 'NumLocalConnectionsExecuting',
----# 'NumRemoteConnections',
----# 'NumRemoteConnectionsExecuting',
'PctConnectionsExecuting',

----DB2 Agents
------------------------
'AgentCreationRatio',
----# 'CurAgentsWaiting',
----# 'MaxAgentsRegistered',
----# 'MaxAgentsWaiting',
----# 'NumAgentsRegistered',
----# 'NumIdleAgents',
----# 'NumStolenAgents',
----# 'NumUnassignedAgents',
'PctAgentsWaiting',

----Configuration 
------------------------
----# 'ClientIOBlockSize',
----# 'CurAgentsPriority',
----# 'CurMaxAgents',
----# 'MaxConcurrentAgents',
----# 'MaxPoolAgents',
----# 'MaxQueryHeapSize',
----# 'MonHeapSize',
----# 'NumFcmAnchors',
----# 'NumFcmBuffers',
----# 'NumFcmConnections',
----# 'NumFcmReqBlocks',
'PctPrivateMemUsed',
----# 'SortHeapThreshold',
----# 'SqlStatementSize',

----Memory
------------------------

----Sorts
------------------------
----# 'NumPipedSortsAccepted',
----# 'NumPipedSortsRequested',
'PctPipedSortHits',
'PctPipedSortReqRejected',
----# 'PctSortHeapUsed',
'PipedSortReqRejected',

----Sorts
------------------------
----# 'SortHeapAllocated',

----Status
------------------------
'DB2Up',
'DB2Down'
);

----# insert into session.CTD_MsmtRul select
----# 'CTD_RM_DB',
----# mt.MsmtTyp_ID
----# from
----# TWG.MsmtTyp mt
----# where
----# MsmtTyp_Nm in (

----Connections
------------------------
----# 'CurrentConnections',

----Lock Waits
------------------------

----Pass Through
------------------------

----SQL Statement Activity
------------------------
----#'PctUidSqlStatements'
----#);

insert into session.CTD_MsmtRul select
'CTD_TABLE',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----Table Activity
------------------------
----# 'OverflowAccesses',
'RowsReadRate',
'RowsWrittenRate'
----# ,
----# 'NumRows',

----Status
------------------------
----# 'TableDataReorgNeeded',
----# 'TableDataReorgNotNeeded',
----# 'TableIndexReorgNeeded',
----#'TableIndexReorgNotNeeded'
);

insert into session.CTD_MsmtRul select
'CTD_TABLE_APPLY',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----Replication
------------------------
'ApplyRequiresRefresh',

----Replication
------------------------
'ApplySubscriptionLagTime'
----#,

----Status
------------------------
);

insert into session.CTD_MsmtRul select
'CTD_TBSP',
mt.MsmtTyp_ID
from
TWG.MsmtTyp mt
where
MsmtTyp_Nm in (

----BufferPool - External Storage
------------------------
'PctExtStorageReadWrite',
----# 'PagesCopiedFromExtStorage',
----# 'PagesCopiedToExtStorage',
----# 'IndexCopiedFromExtStorage',
----# 'IndexCopiedToExtStorage',

----Bufferpool Activity
------------------------
----# 'AsyncDataReads',
----# 'AsyncDataWrites',
----# 'AsyncIndexReads',
----# 'AsyncIndexWrites',
----# 'AsyncReadTime',
----# 'AsyncWriteTime',
'AvgPoolIOTime',
'AvgPoolReadTime',
'AvgPoolWriteTime',
----# 'AvgSyncIOTime',
----# 'AvgSyncReadTime',
----# 'AvgSyncWriteTime',
----# 'FilesClosed',
'InputOutputRate',
----# 'LogicalDataReads',
----# 'LogicalIndexReads',
----# 'PctAsyncReadReqSatisfied',
'PctBufferPoolHits',
----# 'PctIndexHits',
----# 'PhysicalDataReads',
----# 'PhysicalDataWrites',
----# 'PhysicalIndexReads',
----# 'PhysicalIndexWrites',
----# 'SyncDataReads',
----# 'SyncDataWrites',
----# 'SyncIndexReads',
----# 'SyncIndexWrites',
----# 'SyncReadTime',
----# 'SyncWriteTime',
----# 'TotPhysicalIOTime',
----# 'TotPhysicalReadTime',
----# 'TotPhysicalWriteTime',
----# 'TotPoolReads',
----# 'TotPoolWrites',
----# 'TotSyncInputOutput',

----Direct IO
------------------------
'AvgDirectReadTime',
'AvgDirectWriteTime',
'DirectReadAvgSectorsPer'
----# ,
----# 'DirectReadRequests',
----# 'DirectReads',
----# 'DirectReadTime',
----# 'DirectWriteAvgSectorsPer',
----# 'DirectWriteRequests',
----# 'DirectWrites',
----# 'DirectWriteTime',
----# 'TotDirectIOTime',

----Storage
------------------------
);


-- insert the measurement rule into the generic schema 
-- if not exist already

insert into TWG.MsmtRul 
select 
 m.CompTyp_Cd,
 m.MsmtTyp_ID
from 
 session.CTD_MsmtRul m
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.CompTyp_Cd=m.CompTyp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
;
--------------------------------------------------
-- DB2 Attribute Types
---------------------------------------------------
declare global temporary table CTD_AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
;


insert into session.CTD_AttrTyp values ('AMX_EID', 'ITM Endpoint ID');
insert into session.CTD_AttrTyp values ('AMX_GMT_OFFSET', 'ITM Endpoint GMT Offset');
insert into session.CTD_AttrTyp values ('CTD_ISMPP', 'DB2 Parallel System Indicator');
insert into session.CTD_AttrTyp values ('CTD_LOGPATH', 'DB2 Database Partition Log Path');
insert into session.CTD_AttrTyp values ('CTD_NODE_PORT_NUM', 'DB2 Database Partition Port Number');
insert into session.CTD_AttrTyp values ('CTD_NODE_HOST_NM', 'DB2 Database Partition Host Name');
insert into session.CTD_AttrTyp values ('CTD_NODE_NUM', 'DB2 Database Partition Number');
insert into session.CTD_AttrTyp values ('CTD_HOST', 'DB2 Instance Host Name (DB2 Catalog Node Host Name)');
insert into session.CTD_AttrTyp values ('CTD_APPL_NAME', 'DB2 Application Name');

-- insert the DB2 attribute types into the generic schema 
-- if not exist already

insert into TWG.AttrTyp 
select 
 m.AttrTyp_Cd,
 m.AttrTyp_Nm
from 
 session.CTD_AttrTyp m
where not exists
( select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd=m.AttrTyp_Cd )
  ;
------------------------------------------
-- Insert measurement group type codes
------------------------------------------

delete from twg.mgrpmbr where Mgrp_cd='CTDAAC';
delete from TWG.Mgrp where MGrp_Cd='CTDAAC';
delete from twg.mgrpmbr where Mgrp_cd='CTDABP';
delete from TWG.Mgrp where MGrp_Cd='CTDABP';
delete from twg.mgrpmbr where Mgrp_cd='CTDADI';
delete from TWG.Mgrp where MGrp_Cd='CTDADI';
delete from twg.mgrpmbr where Mgrp_cd='CTDALC';
delete from TWG.Mgrp where MGrp_Cd='CTDALC';
delete from twg.mgrpmbr where Mgrp_cd='CTDALK';
delete from TWG.Mgrp where MGrp_Cd='CTDALK';
delete from twg.mgrpmbr where Mgrp_cd='CTDAPA';
delete from TWG.Mgrp where MGrp_Cd='CTDAPA';
delete from twg.mgrpmbr where Mgrp_cd='CTDAPL';
delete from TWG.Mgrp where MGrp_Cd='CTDAPL';
delete from twg.mgrpmbr where Mgrp_cd='CTDASQ';
delete from TWG.Mgrp where MGrp_Cd='CTDASQ';
delete from twg.mgrpmbr where Mgrp_cd='CTDAST';
delete from TWG.Mgrp where MGrp_Cd='CTDAST';
delete from twg.mgrpmbr where Mgrp_cd='CTDIST';
delete from TWG.Mgrp where MGrp_Cd='CTDIST';
delete from twg.mgrpmbr where Mgrp_cd='CTDTAC';
delete from TWG.Mgrp where MGrp_Cd='CTDTAC';
delete from twg.mgrpmbr where Mgrp_cd='CTDTAR';
delete from TWG.Mgrp where MGrp_Cd='CTDTAR';
delete from twg.mgrpmbr where Mgrp_cd='CTDTBP';
delete from TWG.Mgrp where MGrp_Cd='CTDTBP';
delete from twg.mgrpmbr where Mgrp_cd='CTDTDI';
delete from TWG.Mgrp where MGrp_Cd='CTDTDI';
delete from twg.mgrpmbr where Mgrp_cd='CTDOBJ';
delete from TWG.Mgrp where MGrp_Cd='CTDOBJ';

delete from twg.mgrpmbr where Mgrp_cd='CTDTBS';
delete from TWG.Mgrp where MGrp_Cd='CTDTBS';
delete from twg.mgrpmbr where Mgrp_cd='CTDTB';
delete from TWG.Mgrp where MGrp_Cd='CTDTB';
delete from twg.mgrpmbr where Mgrp_cd='CTDINS';
delete from TWG.Mgrp where MGrp_Cd='CTDINS';
delete from twg.mgrpmbr where Mgrp_cd='CTDNDE';
delete from TWG.Mgrp where MGrp_Cd='CTDNDE';
delete from twg.mgrpmbr where Mgrp_cd='CTDAPY';
delete from TWG.Mgrp where MGrp_Cd='CTDAPY';
delete from twg.mgrpmbr where Mgrp_cd='CTDISA';
delete from TWG.Mgrp where MGrp_Cd='CTDISA';
delete from twg.mgrpmbr where Mgrp_cd='CTDAPR';
delete from TWG.Mgrp where MGrp_Cd='CTDAPR';
delete from twg.mgrpmbr where Mgrp_cd='CTDDBP';
delete from TWG.Mgrp where MGrp_Cd='CTDDBP';
delete from twg.mgrpmbr where Mgrp_cd='CTDCC';
delete from TWG.Mgrp where MGrp_Cd='CTDCC';
delete from twg.mgrpmbr where Mgrp_cd='CTDTSS';
delete from TWG.Mgrp where MGrp_Cd='CTDTSS';
delete from twg.mgrpmbr where Mgrp_cd='CTDDDI';
delete from TWG.Mgrp where MGrp_Cd='CTDDDI';
delete from twg.mgrpmbr where Mgrp_cd='CTDFCM';
delete from TWG.Mgrp where MGrp_Cd='CTDFCM';
delete from twg.mgrpmbr where Mgrp_cd='CTDHGW';
delete from TWG.Mgrp where MGrp_Cd='CTDHGW';
delete from twg.mgrpmbr where Mgrp_cd='CTDLMC';
delete from TWG.Mgrp where MGrp_Cd='CTDLMC';
delete from twg.mgrpmbr where Mgrp_cd='CTDHGW';
delete from TWG.Mgrp where MGrp_Cd='CTDHGW';
delete from twg.mgrpmbr where Mgrp_cd='CTDDLD';
delete from TWG.Mgrp where MGrp_Cd='CTDDLD';
delete from twg.mgrpmbr where Mgrp_cd='CTDBLK';
delete from TWG.Mgrp where MGrp_Cd='CTDBLK';
delete from twg.mgrpmbr where Mgrp_cd='CTDLOG';
delete from TWG.Mgrp where MGrp_Cd='CTDLOG';
delete from twg.mgrpmbr where Mgrp_cd='CTDPKC';
delete from TWG.Mgrp where MGrp_Cd='CTDPKC';
delete from twg.mgrpmbr where Mgrp_cd='CTDDST';
delete from TWG.Mgrp where MGrp_Cd='CTDDST';
delete from twg.mgrpmbr where Mgrp_cd='CTDDSQ';
delete from TWG.Mgrp where MGrp_Cd='CTDDSQ';




-- create a temporary table for measurement group 
declare global temporary table CTD_MGrp (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MGrp_Parent_Cd       CHAR(6),
       MGrp_Nm              VARCHAR(120) NOT NULL
) 
with replace on commit preserve rows not logged
; 

insert into session.CTD_MGrp values ('PERF', 'CATEG', null, 'Performance');
insert into session.CTD_MGrp values ('UTIL', 'CATEG', null, 'Utilization');
insert into session.CTD_MGrp values ('AVL', 'CATEG', null, 'Availability');
insert into session.CTD_MGrp values ('STATE', 'CATEG', null, 'The percentage State measurements');
insert into session.CTD_MGrp values ('STORAG', 'CATEG', null, 'Storage');
insert into session.CTD_MGrp values ('AVG_E ', 'GROUP', null, 'Average Value Exists');
insert into session.CTD_MGrp values ('MIN_E', 'GROUP', null, 'Minimum Value Exists');
insert into session.CTD_MGrp values ('MAX_E', 'GROUP', null, 'Maximum Value Exists');
insert into session.CTD_MGrp values ('TOT_E', 'GROUP', null, 'Total Value Exists');
insert into session.CTD_MGrp values ('CTDSTS', 'STATE', null, 'State Measurements for DB2 Resources');
insert into session.CTD_MGrp values ('MEMORY', 'CATEG', null, 'Memory');
insert into session.CTD_MGrp values ('NETWK', 'CATEG', null, 'Network');
insert into session.CTD_MGrp values ('CTDAGT', 'CATEG', 'UTIL', 'DB2 Agents');
insert into session.CTD_MGrp values ('CTDREP', 'CATEG', 'UTIL', 'DB2 Replication');
insert into session.CTD_MGrp values ('CTDBP', 'CATEG', 'UTIL', 'DB2 Buffer Pool Activity');
insert into session.CTD_MGrp values ('CTDCC', 'CATEG', 'UTIL', 'DB2 Catalog Cache');
insert into session.CTD_MGrp values ('CTDSTO', 'CATEG', 'UTIL', 'DB2 Storage');
insert into session.CTD_MGrp values ('CTDDIO', 'CATEG', 'UTIL', 'DB2 Direct IO');
insert into session.CTD_MGrp values ('CTDFCM', 'CATEG', 'UTIL', 'DB2 Fast Communication Manager');
insert into session.CTD_MGrp values ('CTDHGW', 'CATEG', 'UTIL', 'DB2 Host Gateway');
insert into session.CTD_MGrp values ('CTDCNX', 'CATEG', 'UTIL', 'DB2 Connections');
insert into session.CTD_MGrp values ('CTDDLK', 'CATEG', 'UTIL', 'DB2 Locks/Deadlocks');
insert into session.CTD_MGrp values ('CTDLKW', 'CATEG', 'UTIL', 'DB2 Lock Waits');
insert into session.CTD_MGrp values ('CTDLOG', 'CATEG', 'UTIL', 'DB2 Logging');
insert into session.CTD_MGrp values ('CTDPKC', 'CATEG', 'UTIL', 'DB2 Package Cache');
insert into session.CTD_MGrp values ('CTDCAP', 'CATEG', 'UTIL', 'DB2 Replication');
insert into session.CTD_MGrp values ('CTDSRT', 'CATEG', 'UTIL', 'DB2 Sorts');
insert into session.CTD_MGrp values ('CTDSQL', 'CATEG', 'UTIL', 'DB2 SQL Activity');
insert into session.CTD_MGrp values ('CTDHSH', 'CATEG', 'UTIL', 'DB2 Hash Joins');
insert into session.CTD_MGrp values ('CTDHTP', 'CATEG', 'UTIL', 'DB2 Host Throughput');
insert into session.CTD_MGrp values ('CTDAPP', 'CATEG', 'UTIL', 'DB2 Application Activity');
insert into session.CTD_MGrp values ('CTDLD', 'CATEG', 'UTIL', 'DB2 Load');
insert into session.CTD_MGrp values ('CTDPTH', 'CATEG', 'UTIL', 'DB2 Pass Through');
insert into session.CTD_MGrp values ('CTDBPE', 'CATEG', 'UTIL', 'DB2 BufferPool - External Storage');
insert into session.CTD_MGrp values ('CTDCFG', 'CATEG', 'UTIL', 'DB2 Configuration');
insert into session.CTD_MGrp values ('CTDTBL', 'CATEG', 'UTIL', 'DB2 Table Activity');

-- insert the measurement group into the generic schema 
-- if not exist already

insert into TWG.MGrp
select 
 m.MGrp_Cd,
 m.MGrpTyp_Cd,
 m.MGrp_Parent_Cd,
 m.MGrp_Nm 
from 
 session.CTD_MGrp m
where not exists
( select 1 from
  TWG.MGrp t
  where
  t.MGrpTyp_Cd=m.MGrpTyp_Cd and
  t.MGrp_Cd=m.MGrp_Cd
 ) 
  ;


-- create a temporary table for measurement group member

declare global temporary table CTD_MGrpMbr (
MGrp_Cd              CHAR(6) NOT NULL,
MGrpTyp_Cd           CHAR(6) NOT NULL,
MsmtTyp_ID           INTEGER NOT NULL
)
with replace on commit preserve rows not logged
;


-------------------------------
-- CONTEXT: Application Activity
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDAPP', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'AppsCurConnected',
----# 'AppsReqInProcess',
----# 'MaxCurrentConnections',
'PctConnectionsUsed'
----# ,
----# 'TotalConnections'
);

-------------------------------
-- CONTEXT: BufferPool - External Storage
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDBPE', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'IndexCopiedFromExtStorage',
----# 'IndexCopiedToExtStorage',
----# 'PagesCopiedFromExtStorage',
----# 'PagesCopiedToExtStorage',
'PctExtStorageReadWrite'
);

-------------------------------
-- CONTEXT: Bufferpool Activity
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDBP', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'AsyncDataReads',
----# 'AsyncDataWrites',
----# 'AsyncIndexReads',
----# 'AsyncIndexWrites',
----# 'AsyncReadTime',
----# 'AsyncWriteTime',
'AvgAsyncReadsPerPoolRead',
'AvgAsyncWritesPerPoolWrite',
----# 'AvgPagesPerCleaner',
'AvgPoolIOTime',
'AvgPoolReadTime',
'AvgPoolWritesPerPoolRead',
'AvgPoolWriteTime',
'AvgSyncIOTime',
'AvgSyncReadTime',
'AvgSyncWriteTime',
----# 'FilesClosed',
'InputOutputRate',
----# 'LogicalDataReads',
----# 'LogicalIndexReads',
----# 'LogSpaceCleanersInvoked',
----# 'PageCleanersDueToDirtyThreshold',
----# 'PagesPerPrefetch',
----# 'PctAsyncReadReqSatisfied',
'PctBufferPoolHits',
'PctIndexHits'
----# ,
----# 'PhysicalDataReads',
----# 'PhysicalDataWrites',
----# 'PhysicalIndexReads',
----# 'PhysicalIndexWrites',
----# 'PreFetchWaitTime',
----# 'SyncDataReads',
----# 'SyncDataWrites',
----# 'SyncIndexReads',
----# 'SyncIndexWrites',
----# 'SyncReadTime',
----# 'SyncWriteTime',
----# 'TotPhysicalIOTime',
----# 'TotPhysicalReadTime',
----# 'TotPhysicalWriteTime',
----# 'TotPoolReads',
----# 'TotPoolWrites',
----# 'TotSyncInputOutput',
----# 'VictimPageCleanersInvoked'
);

-------------------------------
-- CONTEXT: Catalog Cache
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDCC', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'CatCacheHeapFull',
----# 'CatCacheInsertAttempts',
----# 'CatCacheOverflows',
----# 'CatCacheTableLookups',
'PctCatCacheHits'
----# ,
);

-------------------------------
-- CONTEXT: Configuration
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDCFG', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'ClientIOBlockSize',
----# 'CurAgentsPriority',
----# 'CurMaxAgents',
----# 'MaxConcurrentAgents',
----# 'MaxPoolAgents',
----# 'MaxQueryHeapSize',
----# 'MonHeapSize',
----# 'NumFcmAnchors',
----# 'NumFcmBuffers',
----# 'NumFcmConnections',
----# 'NumFcmReqBlocks',
'PctPrivateMemUsed',
----# 'SortHeapThreshold',
----# 'SqlStatementSize',
'ApplControlHeapSize',
'ApplHeapAvailSize',
'BufferPoolDefaultSize',
----# 'CatalogCacheSize',
'ChangedPagesThreshold',
'InputOutputCleaners',
'InputOutputServers',
'LogBufferSize',
----# 'MaxActiveApplications',
'MaxLocklistStorage',
'MaxPctLocklist',
'MinCommits',
----# 'NumDMSTablespaces',
----# 'NumEventMonitors',
----# 'NumInvalidPkgsALL',
----# 'NumInvalidPkgsSYSTEM',
----# 'NumInvalidPkgsUSER',
----# 'NumInvalidTriggers',
'NumPrimaryLogs',
----# 'NumSMSTablespaces',
----# 'NumTables',
----# 'NumTablespaces',
----# 'NumTablespacesWithLONG',
----# 'NumTriggers',
----# 'NumUserIndexes',
----# 'NumViews',
'PackageCacheSize'
----# ,
);

-------------------------------
-- CONTEXT: Connections
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDCNX', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'AttemptedConnections',
'ConnectionErrors',
----# 'ConnWaitingForClientCurrent',
'ConnWaitingForHostCurrent',
'CurrentConnections',
----# 'MostRecentConnectElapsedTime',
'MostRecentConnectResponseTime',
----# 'NumConnectionsToLocalDBases',
----# 'NumLocalConnections',
----# 'NumLocalConnectionsExecuting',
----# 'NumRemoteConnections',
----# 'NumRemoteConnectionsExecuting',
'PctConnectionsExecuting'
----# ,
----# 'StatementElapsedTime'
);

-------------------------------
-- CONTEXT: CPU Utilization
-------------------------------
insert into session.CTD_MGrpMbr
select 'UTIL', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'TotSystemCpuTime',
'TotUserCpuTime'
);

-------------------------------
-- CONTEXT: DB2 Agents
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDAGT', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'AgentCreationRatio',
----# 'CurAgentsWaiting',
----# 'MaxAgentsRegistered',
----# 'MaxAgentsWaiting',
----# 'MaxAssociatedAgents',
----# 'MaxCoordAgents',
----# 'NumAgentsRegistered',
----# 'NumIdleAgents',
----# 'NumStolenAgents',
----# 'NumUnassignedAgents',
'PctAgentsWaiting',
'WorkLoad'
);

-------------------------------
-- CONTEXT: Direct IO
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDDIO', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'AvgDirectReadTime',
'AvgDirectWriteTime',
'DirectReadAvgSectorsPer'
----# ,
----# 'DirectReadRequests',
----# 'DirectReads',
----# 'DirectReadTime',
----# 'DirectWriteAvgSectorsPer',
----# 'DirectWriteRequests',
----# 'DirectWrites',
----# 'DirectWriteTime',
----# 'TotDirectIOTime'
);

-------------------------------
-- CONTEXT: FCM Activity
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDFCM', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'FreeFcmBuffers',
----# 'FreeFcmConnections',
----# 'FreeFcmRequestBlocks',
----# 'MinFreeFcmBuffers',
----# 'MinFreeFcmConnections',
----# 'MinFreeFcmMsgAnchors',
----# 'MinFreeFcmReqBlocks',
----# 'NumFcmNodes',
'PctFcmBuffsInUse',
'PctFcmConnInUse',
----# 'PctFcmReqBlocksUsed',
'PctMaxFcmConnUsed',
'PctMaxFcmMsgAnchorUsed'
----# ,
----# 'TotFcmBuffsReceived',
----# 'TotFcmBuffsSent'
);


-------------------------------
-- CONTEXT: Host Throughput
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDHTP', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'HostThroughput',
'HostTimePerStatement',
'NetworkTimePerStatement',
----# 'OutboundBytesReceived',
----# 'OutboundBytesSent',
'TimePerStatement'
);

-------------------------------
-- CONTEXT: Load
-------------------------------

----# insert into session.CTD_MGrpMbr
----# select 'CTDLD', 'CATEG',
----# mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'HostTimePerStatement',
----# 'MostRecentConnectElapsedTime',
----# 'NetworkTimePerStatement',
----# );

-------------------------------
-- CONTEXT: Lock Waits
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDLKW', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'ApplsInLockWait',
'PctApplsInLockWait'
----# ,
----# 'TotLockWaits',
----# 'TotLockWaitTime',
----# 'UOWLockWaitTime'
);

-------------------------------
-- CONTEXT: Locks / DeadLocks
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDDLK', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'AvgLockEscalationConn',
'AvgLocksHeld',
----# 'LocklistMemInUse',
----# 'LockTimeouts',
'PctDeadlockRollbacks',
'PctIntDeadlockedRollbacks',
'PctLockListUsed'
----# ,
----# 'TotCurLocksHeld',
----# 'TotDeadlockIntRollbacks',
----# 'TotDeadLocks'
);

-------------------------------
-- CONTEXT: Logging
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDLOG', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'LogPageReads',
'LogPageWrites',
----# 'MaxPrimaryLogSpaceUsed',
----# 'MaxSecondaryLogUsed',
----# 'MaxTotalLogSpaceUsed',
'PctLogSpaceUsedByPrimary',
'PctLogSpaceUsedBySecondary',
----# 'PrimaryLogSpaceAllocated',
'TotLogInputOutput',
'TotSecondaryLogsInUse'
);

-------------------------------
-- CONTEXT: Memory
-------------------------------
----# insert into session.CTD_MGrpMbr
----# select 'MEMORY', 'CATEG',
----# mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'MaxHeapAllocated',
----# );

-------------------------------
-- CONTEXT: Package Cache
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDPKC', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'PackageCacheInserts',
'PackageCacheLookups',
'PctPackageCacheHits'
----# ,
);

-------------------------------
-- CONTEXT: Pass Through
-------------------------------

----# insert into session.CTD_MGrpMbr
----# select 'CTDPTH', 'CATEG',
----# mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# );

-------------------------------
-- CONTEXT: Replication
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDCAP', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'ApplyRequiresRefresh',
'ApplySubscriptionLagTime',
'CaptureLag',
----# 'CapturePruning',
'FailedSubscriptions',
'LaggingSubscriptions'
);

-------------------------------
-- CONTEXT: Sorts
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDSRT', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'AvgSortTime',
----# 'NumActiveSorts',
----# 'NumPipedSortsAccepted',
----# 'NumPipedSortsRequested',
'PctPipedSortHits',
'PctPipedSortReqRejected',
----# 'PctSortHeapUsed',
'PctSortOverflowed',
'PipedSortReqRejected'
----# ,
----# 'SortHeapAllocated',
----# 'StatementSorts',
----# 'TotSorts',
----# 'TotSortTime'
);

-------------------------------
-- CONTEXT: SQL Statement Activity
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDSQL', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'BindPrecompileAttempts',
'CommitRate',
----# 'Commits',
'DDLSqlStatements',
----# 'DynamicSqlStatements',
'FailedSqlStatements',
----# 'InternalRowDeletes',
----# 'InternalRowInserts',
----# 'InternalRowUpdates',
'OpenBlockingCursors',
'OpenCursors',
----# 'PctDDLSqlStatements',
'PctFailedSqlStatements',
'PctSelectSqlStatements',
----# 'PctUidSqlStatements',
'RollbackRate',
----# 'Rollbacks',
----# 'RollbackSqlStatements',
----# 'RowDeleteAttempts',
----# 'RowInsertAttempts',
----# 'RowsDeleted',
----# 'RowsInserted',
----# 'RowsSelected',
----# 'RowsUpdated',
----# 'RowUpdateAttempts',
----# 'SectionInserts',
----# 'SectionLookups',
----# 'SqlReqSinceLastCommit',
'SqlSelectsExecuted',
'SqlStatementsRate',
----# 'StaticSqlAttempts',
----# 'TotAutoRebindAttempts',
----# 'TotInternalCommits',
----# 'TotInternalRollbacks',
----# 'TotSqlCommitAttempts',
----# 'TotSqlRollbackAttempts',
'UIDSqlExecuted'
);

-------------------------------
-- CONTEXT: Status
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDSTS', 'STATE',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'DB2Down',
'DB2Up',
'NumInactiveNodes',
----# 'TableDataReorgNeeded',
----# 'TableDataReorgNotNeeded',
----# 'TableIndexReorgNeeded',
----# 'TableIndexReorgNotNeeded',
'TbspBackupPending',
'TbspBackupProgress',
'TbspDeletePending',
'TbspDisablePending',
'TbspDMSRebalance',
'TbspDropPending',
'TbspLoadPending',
'TbspNormal',
'TbspOffline',
'TbspQuiescedEx',
'TbspQuiescedSh',
'TbspQuiescedUp',
'TbspReorgProgress',
'TbspRestorePending',
'TbspRestoreProgress',
'TbspRFpending',
'TbspRFprogress',
'TbspStorageUndefined',
'TbspStorDef',
'TbspStorDefChanged',
'TbspStorDefFinal',
'TbspTBScreate',
'TbspTBSdelete'
);

-------------------------------
-- CONTEXT: Storage
-------------------------------
insert into session.CTD_MGrpMbr
select 'STORAG', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'PctSpaceUsedDMS',
'SpaceUsedSMS'
);

-------------------------------
-- CONTEXT: Table Activity
-------------------------------
insert into session.CTD_MGrpMbr
select 'CTDTBL', 'CATEG',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----# 'NumRows',
----# 'OverflowAccesses',
'RowsReadRate',
'RowsWrittenRate'
);

-------------------------------
--CONTEXT: MAX EXISTS
-------------------------------
insert into session.CTD_MGrpMbr
select 'MAX_E','GROUP',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'AgentCreationRatio',
'ApplControlHeapSize',
'ApplHeapAvailSize',
----# 'ApplsInLockWait',
'ApplyRequiresRefresh',
'ApplySubscriptionLagTime',
----# 'AppsCurConnected',
----# 'AppsReqInProcess',
----# 'AsyncDataReads',
----# 'AsyncDataWrites',
----# 'AsyncIndexReads',
----# 'AsyncIndexWrites',
----# 'AsyncReadTime',
----# 'AsyncWriteTime',
----# 'AttemptedConnections',
'AvgAsyncReadsPerPoolRead',
'AvgAsyncWritesPerPoolWrite',
'AvgDirectReadTime',
'AvgDirectWriteTime',
'AvgLockEscalationConn',
'AvgLocksHeld',
----# 'AvgPagesPerCleaner',
'AvgPoolIOTime',
'AvgPoolReadTime',
'AvgPoolWritesPerPoolRead',
'AvgPoolWriteTime',
----# 'AvgSortTime',
'AvgSyncIOTime',
'AvgSyncReadTime',
'AvgSyncWriteTime',
----# 'BindPrecompileAttempts',
'BufferPoolDefaultSize',
'CaptureLag',
----# 'CapturePruning',
----# 'CatalogCacheSize',
----# 'CatCacheHeapFull',
----# 'CatCacheInsertAttempts',
----# 'CatCacheOverflows',
----# 'CatCacheTableLookups',
'ChangedPagesThreshold',
----# 'ClientIOBlockSize',
'CommitRate',
----# 'Commits',
'ConnectionErrors',
----# 'ConnWaitingForClientCurrent',
'ConnWaitingForHostCurrent',
----# 'CurAgentsPriority',
----# 'CurAgentsWaiting',
----# 'CurMaxAgents',
'CurrentConnections',
'DB2Down',
'DB2Up',
'DDLSqlStatements',
'DirectReadAvgSectorsPer',
----# 'DirectReadRequests',
----# 'DirectReads',
----# 'DirectReadTime',
----# 'DirectWriteAvgSectorsPer',
----# 'DirectWriteRequests',
----# 'DirectWrites',
----# 'DirectWriteTime',
----# 'DynamicSqlStatements',
'FailedSqlStatements',
'FailedSubscriptions',
----# 'FilesClosed',
----# 'FreeFcmBuffers',
----# 'FreeFcmConnections',
----# 'FreeFcmRequestBlocks',
'HostThroughput',
'HostTimePerStatement',
----# 'IndexCopiedFromExtStorage',
----# 'IndexCopiedToExtStorage',
'InputOutputCleaners',
'InputOutputRate',
'InputOutputServers',
----# 'InternalRowDeletes',
----# 'InternalRowInserts',
----# 'InternalRowUpdates',
'LaggingSubscriptions',
----# 'LocklistMemInUse',
----# 'LockTimeouts',
'LogBufferSize',
----# 'LogicalDataReads',
----# 'LogicalIndexReads',
'LogPageReads',
'LogPageWrites',
----# 'LogSpaceCleanersInvoked',
----# 'MaxActiveApplications',
----# 'MaxAgentsRegistered',
----# 'MaxAgentsWaiting',
----# 'MaxAssociatedAgents',
----# 'MaxConcurrentAgents',
----# 'MaxCoordAgents',
----# 'MaxCurrentConnections',
----# 'MaxHeapAllocated',
'MaxLocklistStorage',
'MaxPctLocklist',
----# 'MaxPoolAgents',
----# 'MaxPrimaryLogSpaceUsed',
----# 'MaxQueryHeapSize',
----# 'MaxSecondaryLogUsed',
----# 'MaxTotalLogSpaceUsed',
'MinCommits',
----# 'MinFreeFcmBuffers',
----# 'MinFreeFcmConnections',
----# 'MinFreeFcmMsgAnchors',
----# 'MinFreeFcmReqBlocks',
----# 'MonHeapSize',
----# 'MostRecentConnectElapsedTime',
'MostRecentConnectResponseTime',
'NetworkTimePerStatement',
----# 'NumActiveSorts',
----# 'NumAgentsRegistered',
----# 'NumConnectionsToLocalDBases',
----# 'NumDMSTablespaces',
----# 'NumEventMonitors',
----# 'NumFcmAnchors',
----# 'NumFcmBuffers',
----# 'NumFcmConnections',
----# 'NumFcmNodes',
----# 'NumFcmReqBlocks',
----# 'NumIdleAgents',
'NumInactiveNodes',
----# 'NumInvalidPkgsALL',
----# 'NumInvalidPkgsSYSTEM',
----# 'NumInvalidPkgsUSER',
----# 'NumInvalidTriggers',
----# 'NumLocalConnections',
----# 'NumLocalConnectionsExecuting',
----# 'NumPipedSortsAccepted',
----# 'NumPipedSortsRequested',
'NumPrimaryLogs',
----# 'NumRemoteConnections',
----# 'NumRemoteConnectionsExecuting',
----# 'NumRows',
----# 'NumSMSTablespaces',
----# 'NumStolenAgents',
----# 'NumTables',
----# 'NumTablespaces',
----# 'NumTablespacesWithLONG',
----# 'NumTriggers',
----# 'NumUnassignedAgents',
----# 'NumUserIndexes',
----# 'NumViews',
'OpenBlockingCursors',
'OpenCursors',
----# 'OutboundBytesReceived',
----# 'OutboundBytesSent',
----# 'OverflowAccesses',
'PackageCacheInserts',
'PackageCacheLookups',
'PackageCacheSize',
----# 'PageCleanersDueToDirtyThreshold',
----# 'PagesCopiedFromExtStorage',
----# 'PagesCopiedToExtStorage',
----# 'PagesPerPrefetch',
'PctAgentsWaiting',
'PctApplsInLockWait',
----# 'PctAsyncReadReqSatisfied',
'PctBufferPoolHits',
'PctCatCacheHits',
'PctConnectionsExecuting',
'PctConnectionsUsed',
----# 'PctDDLSqlStatements',
'PctDeadlockRollbacks',
'PctExtStorageReadWrite',
'PctFailedSqlStatements',
'PctFcmBuffsInUse',
'PctFcmConnInUse',
----# 'PctFcmReqBlocksUsed',
'PctIndexHits',
'PctIntDeadlockedRollbacks',
'PctLockListUsed',
'PctLogSpaceUsedByPrimary',
'PctLogSpaceUsedBySecondary',
'PctMaxFcmConnUsed',
'PctMaxFcmMsgAnchorUsed',
'PctPackageCacheHits',
'PctPipedSortHits',
'PctPipedSortReqRejected',
'PctPrivateMemUsed',
'PctSelectSqlStatements',
----# 'PctSortHeapUsed',
'PctSortOverflowed',
'PctSpaceUsedDMS',
----# 'PctUidSqlStatements',
----# 'PhysicalDataReads',
----# 'PhysicalDataWrites',
----# 'PhysicalIndexReads',
----# 'PhysicalIndexWrites',
'PipedSortReqRejected',
----# 'PreFetchWaitTime',
----# 'PrimaryLogSpaceAllocated',
'RollbackRate',
----# 'Rollbacks',
----# 'RollbackSqlStatements',
----# 'RowDeleteAttempts',
----# 'RowInsertAttempts',
----# 'RowsDeleted',
----# 'RowsInserted',
'RowsReadRate',
----# 'RowsSelected',
----# 'RowsUpdated',
'RowsWrittenRate',
----# 'RowUpdateAttempts',
----# 'SectionInserts',
----# 'SectionLookups',
----# 'SortHeapAllocated',
----# 'SortHeapThreshold',
'SpaceUsedSMS',
----# 'SqlReqSinceLastCommit',
'SqlSelectsExecuted',
'SqlStatementsRate',
----# 'SqlStatementSize',
----# 'StatementElapsedTime',
----# 'StatementSorts',
----# 'StaticSqlAttempts',
----# 'SyncDataReads',
----# 'SyncDataWrites',
----# 'SyncIndexReads',
----# 'SyncIndexWrites',
----# 'SyncReadTime',
----# 'SyncWriteTime',
----# 'TableDataReorgNeeded',
----# 'TableDataReorgNotNeeded',
----# 'TableIndexReorgNeeded',
----# 'TableIndexReorgNotNeeded',
'TbspBackupPending',
'TbspBackupProgress',
'TbspDeletePending',
'TbspDisablePending',
'TbspDMSRebalance',
'TbspDropPending',
'TbspLoadPending',
'TbspNormal',
'TbspOffline',
'TbspQuiescedEx',
'TbspQuiescedSh',
'TbspQuiescedUp',
'TbspReorgProgress',
'TbspRestorePending',
'TbspRestoreProgress',
'TbspRFpending',
'TbspRFprogress',
'TbspStorageUndefined',
'TbspStorDef',
'TbspStorDefChanged',
'TbspStorDefFinal',
'TbspTBScreate',
'TbspTBSdelete',
'TimePerStatement',
----# 'TotalConnections',
----# 'TotAutoRebindAttempts',
----# 'TotCurLocksHeld',
----# 'TotDeadlockIntRollbacks',
----# 'TotDeadLocks',
----# 'TotDirectIOTime',
----# 'TotFcmBuffsReceived',
----# 'TotFcmBuffsSent',
----# 'TotInternalCommits',
----# 'TotInternalRollbacks',
----# 'TotLockWaits',
----# 'TotLockWaitTime',
'TotLogInputOutput',
----# 'TotPhysicalIOTime',
----# 'TotPhysicalReadTime',
----# 'TotPhysicalWriteTime',
----# 'TotPoolReads',
----# 'TotPoolWrites',
'TotSecondaryLogsInUse',
----# 'TotSorts',
----# 'TotSortTime',
----# 'TotSqlCommitAttempts',
----# 'TotSqlRollbackAttempts',
----# 'TotSyncInputOutput',
'TotSystemCpuTime',
'TotUserCpuTime',
'UIDSqlExecuted',
----# 'UOWLockWaitTime',
----# 'VictimPageCleanersInvoked',
'WorkLoad'
);

-------------------------------
--CONTEXT: MIN EXISTS
-------------------------------
insert into session.CTD_MGrpMbr
select 'MIN_E','GROUP',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'AgentCreationRatio',
'ApplControlHeapSize',
'ApplHeapAvailSize',
----# 'ApplsInLockWait',
'ApplyRequiresRefresh',
'ApplySubscriptionLagTime',
----# 'AppsCurConnected',
----# 'AppsReqInProcess',
----# 'AsyncDataReads',
----# 'AsyncDataWrites',
----# 'AsyncIndexReads',
----# 'AsyncIndexWrites',
----# 'AsyncReadTime',
----# 'AsyncWriteTime',
----# 'AttemptedConnections',
'AvgAsyncReadsPerPoolRead',
'AvgAsyncWritesPerPoolWrite',
'AvgDirectReadTime',
'AvgDirectWriteTime',
'AvgLockEscalationConn',
'AvgLocksHeld',
----# 'AvgPagesPerCleaner',
'AvgPoolIOTime',
'AvgPoolReadTime',
'AvgPoolWritesPerPoolRead',
'AvgPoolWriteTime',
----# 'AvgSortTime',
'AvgSyncIOTime',
'AvgSyncReadTime',
'AvgSyncWriteTime',
----# 'BindPrecompileAttempts',
'BufferPoolDefaultSize',
'CaptureLag',
----# 'CapturePruning',
----# 'CatalogCacheSize',
----# 'CatCacheHeapFull',
----# 'CatCacheInsertAttempts',
----# 'CatCacheOverflows',
----# 'CatCacheTableLookups',
'ChangedPagesThreshold',
----# 'ClientIOBlockSize',
'CommitRate',
----# 'Commits',
'ConnectionErrors',
----# 'ConnWaitingForClientCurrent',
'ConnWaitingForHostCurrent',
----# 'CurAgentsPriority',
----# 'CurAgentsWaiting',
----# 'CurMaxAgents',
'CurrentConnections',
'DB2Down',
'DB2Up',
'DDLSqlStatements',
'DirectReadAvgSectorsPer',
----# 'DirectReadRequests',
----# 'DirectReads',
----# 'DirectReadTime',
----# 'DirectWriteAvgSectorsPer',
----# 'DirectWriteRequests',
----# 'DirectWrites',
----# 'DirectWriteTime',
----# 'DynamicSqlStatements',
'FailedSqlStatements',
'FailedSubscriptions',
----# 'FilesClosed',
----# 'FreeFcmBuffers',
----# 'FreeFcmConnections',
----# 'FreeFcmRequestBlocks',
'HostThroughput',
'HostTimePerStatement',
----# 'IndexCopiedFromExtStorage',
----# 'IndexCopiedToExtStorage',
'InputOutputCleaners',
'InputOutputRate',
'InputOutputServers',
----# 'InternalRowDeletes',
----# 'InternalRowInserts',
----# 'InternalRowUpdates',
'LaggingSubscriptions',
----# 'LocklistMemInUse',
----# 'LockTimeouts',
'LogBufferSize',
----# 'LogicalDataReads',
----# 'LogicalIndexReads',
'LogPageReads',
'LogPageWrites',
----# 'LogSpaceCleanersInvoked',
----# 'MaxActiveApplications',
----# 'MaxAgentsRegistered',
----# 'MaxAgentsWaiting',
----# 'MaxAssociatedAgents',
----# 'MaxConcurrentAgents',
----# 'MaxCoordAgents',
----# 'MaxCurrentConnections',
----# 'MaxHeapAllocated',
'MaxLocklistStorage',
'MaxPctLocklist',
----# 'MaxPoolAgents',
----# 'MaxPrimaryLogSpaceUsed',
----# 'MaxQueryHeapSize',
----# 'MaxSecondaryLogUsed',
----# 'MaxTotalLogSpaceUsed',
'MinCommits',
----# 'MinFreeFcmBuffers',
----# 'MinFreeFcmConnections',
----# 'MinFreeFcmMsgAnchors',
----# 'MinFreeFcmReqBlocks',
----# 'MonHeapSize',
----# 'MostRecentConnectElapsedTime',
'MostRecentConnectResponseTime',
'NetworkTimePerStatement',
----# 'NumActiveSorts',
----# 'NumAgentsRegistered',
----# 'NumConnectionsToLocalDBases',
----# 'NumDMSTablespaces',
----# 'NumEventMonitors',
----# 'NumFcmAnchors',
----# 'NumFcmBuffers',
----# 'NumFcmConnections',
----# 'NumFcmNodes',
----# 'NumFcmReqBlocks',
----# 'NumIdleAgents',
'NumInactiveNodes',
----# 'NumInvalidPkgsALL',
----# 'NumInvalidPkgsSYSTEM',
----# 'NumInvalidPkgsUSER',
----# 'NumInvalidTriggers',
----# 'NumLocalConnections',
----# 'NumLocalConnectionsExecuting',
----# 'NumPipedSortsAccepted',
----# 'NumPipedSortsRequested',
'NumPrimaryLogs',
----# 'NumRemoteConnections',
----# 'NumRemoteConnectionsExecuting',
----# 'NumRows',
----# 'NumSMSTablespaces',
----# 'NumStolenAgents',
----# 'NumTables',
----# 'NumTablespaces',
----# 'NumTablespacesWithLONG',
----# 'NumTriggers',
----# 'NumUnassignedAgents',
----# 'NumUserIndexes',
----# 'NumViews',
'OpenBlockingCursors',
'OpenCursors',
----# 'OutboundBytesReceived',
----# 'OutboundBytesSent',
----# 'OverflowAccesses',
'PackageCacheInserts',
'PackageCacheLookups',
'PackageCacheSize',
----# 'PageCleanersDueToDirtyThreshold',
----# 'PagesCopiedFromExtStorage',
----# 'PagesCopiedToExtStorage',
----# 'PagesPerPrefetch',
'PctAgentsWaiting',
'PctApplsInLockWait',
----# 'PctAsyncReadReqSatisfied',
'PctBufferPoolHits',
'PctCatCacheHits',
'PctConnectionsExecuting',
'PctConnectionsUsed',
----# 'PctDDLSqlStatements',
'PctDeadlockRollbacks',
'PctExtStorageReadWrite',
'PctFailedSqlStatements',
'PctFcmBuffsInUse',
'PctFcmConnInUse',
----# 'PctFcmReqBlocksUsed',
'PctIndexHits',
'PctIntDeadlockedRollbacks',
'PctLockListUsed',
'PctLogSpaceUsedByPrimary',
'PctLogSpaceUsedBySecondary',
'PctMaxFcmConnUsed',
'PctMaxFcmMsgAnchorUsed',
'PctPackageCacheHits',
'PctPipedSortHits',
'PctPipedSortReqRejected',
'PctPrivateMemUsed',
'PctSelectSqlStatements',
----# 'PctSortHeapUsed',
'PctSortOverflowed',
'PctSpaceUsedDMS',
----# 'PctUidSqlStatements',
----# 'PhysicalDataReads',
----# 'PhysicalDataWrites',
----# 'PhysicalIndexReads',
----# 'PhysicalIndexWrites',
'PipedSortReqRejected',
----# 'PreFetchWaitTime',
----# 'PrimaryLogSpaceAllocated',
'RollbackRate',
----# 'Rollbacks',
----# 'RollbackSqlStatements',
----# 'RowDeleteAttempts',
----# 'RowInsertAttempts',
----# 'RowsDeleted',
----# 'RowsInserted',
'RowsReadRate',
----# 'RowsSelected',
----# 'RowsUpdated',
'RowsWrittenRate',
----# 'RowUpdateAttempts',
----# 'SectionInserts',
----# 'SectionLookups',
----# 'SortHeapAllocated',
----# 'SortHeapThreshold',
'SpaceUsedSMS',
----# 'SqlReqSinceLastCommit',
'SqlSelectsExecuted',
'SqlStatementsRate',
----# 'SqlStatementSize',
----# 'StatementElapsedTime',
----# 'StatementSorts',
----# 'StaticSqlAttempts',
----# 'SyncDataReads',
----# 'SyncDataWrites',
----# 'SyncIndexReads',
----# 'SyncIndexWrites',
----# 'SyncReadTime',
----# 'SyncWriteTime',
----# 'TableDataReorgNeeded',
----# 'TableDataReorgNotNeeded',
----# 'TableIndexReorgNeeded',
----# 'TableIndexReorgNotNeeded',
'TbspBackupPending',
'TbspBackupProgress',
'TbspDeletePending',
'TbspDisablePending',
'TbspDMSRebalance',
'TbspDropPending',
'TbspLoadPending',
'TbspNormal',
'TbspOffline',
'TbspQuiescedEx',
'TbspQuiescedSh',
'TbspQuiescedUp',
'TbspReorgProgress',
'TbspRestorePending',
'TbspRestoreProgress',
'TbspRFpending',
'TbspRFprogress',
'TbspStorageUndefined',
'TbspStorDef',
'TbspStorDefChanged',
'TbspStorDefFinal',
'TbspTBScreate',
'TbspTBSdelete',
'TimePerStatement',
----# 'TotalConnections',
----# 'TotAutoRebindAttempts',
----# 'TotCurLocksHeld',
----# 'TotDeadlockIntRollbacks',
----# 'TotDeadLocks',
----# 'TotDirectIOTime',
----# 'TotFcmBuffsReceived',
----# 'TotFcmBuffsSent',
----# 'TotInternalCommits',
----# 'TotInternalRollbacks',
----# 'TotLockWaits',
----# 'TotLockWaitTime',
'TotLogInputOutput',
----# 'TotPhysicalIOTime',
----# 'TotPhysicalReadTime',
----# 'TotPhysicalWriteTime',
----# 'TotPoolReads',
----# 'TotPoolWrites',
'TotSecondaryLogsInUse',
----# 'TotSorts',
----# 'TotSortTime',
----# 'TotSqlCommitAttempts',
----# 'TotSqlRollbackAttempts',
----# 'TotSyncInputOutput',
'TotSystemCpuTime',
'TotUserCpuTime',
'UIDSqlExecuted',
----# 'UOWLockWaitTime',
----# 'VictimPageCleanersInvoked',
'WorkLoad'
);

-------------------------------
--CONTEXT: AVG EXISTS
-------------------------------
insert into session.CTD_MGrpMbr
select 'AVG_E','GROUP',
mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
'AgentCreationRatio',
'ApplControlHeapSize',
'ApplHeapAvailSize',
----# 'ApplsInLockWait',
'ApplyRequiresRefresh',
'ApplySubscriptionLagTime',
----# 'AppsCurConnected',
----# 'AppsReqInProcess',
----# 'AsyncDataReads',
----# 'AsyncDataWrites',
----# 'AsyncIndexReads',
----# 'AsyncIndexWrites',
----# 'AsyncReadTime',
----# 'AsyncWriteTime',
----# 'AttemptedConnections',
'AvgAsyncReadsPerPoolRead',
'AvgAsyncWritesPerPoolWrite',
'AvgDirectReadTime',
'AvgDirectWriteTime',
'AvgLockEscalationConn',
'AvgLocksHeld',
----# 'AvgPagesPerCleaner',
'AvgPoolIOTime',
'AvgPoolReadTime',
'AvgPoolWritesPerPoolRead',
'AvgPoolWriteTime',
----# 'AvgSortTime',
'AvgSyncIOTime',
'AvgSyncReadTime',
'AvgSyncWriteTime',
----# 'BindPrecompileAttempts',
'BufferPoolDefaultSize',
'CaptureLag',
----# 'CapturePruning',
----# 'CatalogCacheSize',
----# 'CatCacheHeapFull',
----# 'CatCacheInsertAttempts',
----# 'CatCacheOverflows',
----# 'CatCacheTableLookups',
'ChangedPagesThreshold',
----# 'ClientIOBlockSize',
'CommitRate',
----# 'Commits',
'ConnectionErrors',
----# 'ConnWaitingForClientCurrent',
'ConnWaitingForHostCurrent',
----# 'CurAgentsPriority',
----# 'CurAgentsWaiting',
----# 'CurMaxAgents',
'CurrentConnections',
'DB2Down',
'DB2Up',
'DDLSqlStatements',
'DirectReadAvgSectorsPer',
----# 'DirectReadRequests',
----# 'DirectReads',
----# 'DirectReadTime',
----# 'DirectWriteAvgSectorsPer',
----# 'DirectWriteRequests',
----# 'DirectWrites',
----# 'DirectWriteTime',
----# 'DynamicSqlStatements',
'FailedSqlStatements',
'FailedSubscriptions',
----# 'FilesClosed',
----# 'FreeFcmBuffers',
----# 'FreeFcmConnections',
----# 'FreeFcmRequestBlocks',
'HostThroughput',
'HostTimePerStatement',
----# 'IndexCopiedFromExtStorage',
----# 'IndexCopiedToExtStorage',
'InputOutputCleaners',
'InputOutputRate',
'InputOutputServers',
----# 'InternalRowDeletes',
----# 'InternalRowInserts',
----# 'InternalRowUpdates',
'LaggingSubscriptions',
----# 'LocklistMemInUse',
----# 'LockTimeouts',
'LogBufferSize',
----# 'LogicalDataReads',
----# 'LogicalIndexReads',
'LogPageReads',
'LogPageWrites',
----# 'LogSpaceCleanersInvoked',
----# 'MaxActiveApplications',
----# 'MaxAgentsRegistered',
----# 'MaxAgentsWaiting',
----# 'MaxAssociatedAgents',
----# 'MaxConcurrentAgents',
----# 'MaxCoordAgents',
----# 'MaxCurrentConnections',
----# 'MaxHeapAllocated',
'MaxLocklistStorage',
'MaxPctLocklist',
----# 'MaxPoolAgents',
----# 'MaxPrimaryLogSpaceUsed',
----# 'MaxQueryHeapSize',
----# 'MaxSecondaryLogUsed',
----# 'MaxTotalLogSpaceUsed',
'MinCommits',
----# 'MinFreeFcmBuffers',
----# 'MinFreeFcmConnections',
----# 'MinFreeFcmMsgAnchors',
----# 'MinFreeFcmReqBlocks',
----# 'MonHeapSize',
----# 'MostRecentConnectElapsedTime',
'MostRecentConnectResponseTime',
'NetworkTimePerStatement',
----# 'NumActiveSorts',
----# 'NumAgentsRegistered',
----# 'NumConnectionsToLocalDBases',
----# 'NumDMSTablespaces',
----# 'NumEventMonitors',
----# 'NumFcmAnchors',
----# 'NumFcmBuffers',
----# 'NumFcmConnections',
----# 'NumFcmNodes',
----# 'NumFcmReqBlocks',
----# 'NumIdleAgents',
'NumInactiveNodes',
----# 'NumInvalidPkgsALL',
----# 'NumInvalidPkgsSYSTEM',
----# 'NumInvalidPkgsUSER',
----# 'NumInvalidTriggers',
----# 'NumLocalConnections',
----# 'NumLocalConnectionsExecuting',
----# 'NumPipedSortsAccepted',
----# 'NumPipedSortsRequested',
'NumPrimaryLogs',
----# 'NumRemoteConnections',
----# 'NumRemoteConnectionsExecuting',
----# 'NumRows',
----# 'NumSMSTablespaces',
----# 'NumStolenAgents',
----# 'NumTables',
----# 'NumTablespaces',
----# 'NumTablespacesWithLONG',
----# 'NumTriggers',
----# 'NumUnassignedAgents',
----# 'NumUserIndexes',
----# 'NumViews',
'OpenBlockingCursors',
'OpenCursors',
----# 'OutboundBytesReceived',
----# 'OutboundBytesSent',
----# 'OverflowAccesses',
'PackageCacheInserts',
'PackageCacheLookups',
'PackageCacheSize',
----# 'PageCleanersDueToDirtyThreshold',
----# 'PagesCopiedFromExtStorage',
----# 'PagesCopiedToExtStorage',
----# 'PagesPerPrefetch',
'PctAgentsWaiting',
'PctApplsInLockWait',
----# 'PctAsyncReadReqSatisfied',
'PctBufferPoolHits',
'PctCatCacheHits',
'PctConnectionsExecuting',
'PctConnectionsUsed',
----# 'PctDDLSqlStatements',
'PctDeadlockRollbacks',
'PctExtStorageReadWrite',
'PctFailedSqlStatements',
'PctFcmBuffsInUse',
'PctFcmConnInUse',
----# 'PctFcmReqBlocksUsed',
'PctIndexHits',
'PctIntDeadlockedRollbacks',
'PctLockListUsed',
'PctLogSpaceUsedByPrimary',
'PctLogSpaceUsedBySecondary',
'PctMaxFcmConnUsed',
'PctMaxFcmMsgAnchorUsed',
'PctPackageCacheHits',
'PctPipedSortHits',
'PctPipedSortReqRejected',
'PctPrivateMemUsed',
'PctSelectSqlStatements',
----# 'PctSortHeapUsed',
'PctSortOverflowed',
'PctSpaceUsedDMS',
----# 'PctUidSqlStatements',
----# 'PhysicalDataReads',
----# 'PhysicalDataWrites',
----# 'PhysicalIndexReads',
----# 'PhysicalIndexWrites',
'PipedSortReqRejected',
----# 'PreFetchWaitTime',
----# 'PrimaryLogSpaceAllocated',
'RollbackRate',
----# 'Rollbacks',
----# 'RollbackSqlStatements',
----# 'RowDeleteAttempts',
----# 'RowInsertAttempts',
----# 'RowsDeleted',
----# 'RowsInserted',
'RowsReadRate',
----# 'RowsSelected',
----# 'RowsUpdated',
'RowsWrittenRate',
----# 'RowUpdateAttempts',
----# 'SectionInserts',
----# 'SectionLookups',
----# 'SortHeapAllocated',
----# 'SortHeapThreshold',
'SpaceUsedSMS',
----# 'SqlReqSinceLastCommit',
'SqlSelectsExecuted',
'SqlStatementsRate',
----# 'SqlStatementSize',
----# 'StatementElapsedTime',
----# 'StatementSorts',
----# 'StaticSqlAttempts',
----# 'SyncDataReads',
----# 'SyncDataWrites',
----# 'SyncIndexReads',
----# 'SyncIndexWrites',
----# 'SyncReadTime',
----# 'SyncWriteTime',
----# 'TableDataReorgNeeded',
----# 'TableDataReorgNotNeeded',
----# 'TableIndexReorgNeeded',
----# 'TableIndexReorgNotNeeded',
'TbspBackupPending',
'TbspBackupProgress',
'TbspDeletePending',
'TbspDisablePending',
'TbspDMSRebalance',
'TbspDropPending',
'TbspLoadPending',
'TbspNormal',
'TbspOffline',
'TbspQuiescedEx',
'TbspQuiescedSh',
'TbspQuiescedUp',
'TbspReorgProgress',
'TbspRestorePending',
'TbspRestoreProgress',
'TbspRFpending',
'TbspRFprogress',
'TbspStorageUndefined',
'TbspStorDef',
'TbspStorDefChanged',
'TbspStorDefFinal',
'TbspTBScreate',
'TbspTBSdelete',
'TimePerStatement',
----# 'TotalConnections',
----# 'TotAutoRebindAttempts',
----# 'TotCurLocksHeld',
----# 'TotDeadlockIntRollbacks',
----# 'TotDeadLocks',
----# 'TotDirectIOTime',
----# 'TotFcmBuffsReceived',
----# 'TotFcmBuffsSent',
----# 'TotInternalCommits',
----# 'TotInternalRollbacks',
----# 'TotLockWaits',
----# 'TotLockWaitTime',
'TotLogInputOutput',
----# 'TotPhysicalIOTime',
----# 'TotPhysicalReadTime',
----# 'TotPhysicalWriteTime',
----# 'TotPoolReads',
----# 'TotPoolWrites',
'TotSecondaryLogsInUse',
----# 'TotSorts',
----# 'TotSortTime',
----# 'TotSqlCommitAttempts',
----# 'TotSqlRollbackAttempts',
----# 'TotSyncInputOutput',
'TotSystemCpuTime',
'TotUserCpuTime',
'UIDSqlExecuted',
----# 'UOWLockWaitTime',
----# 'VictimPageCleanersInvoked',
'WorkLoad'
);

-------------------------------
--CONTEXT: TOT EXISTS
-------------------------------
----# insert into session.CTD_MGrpMbr
----# select 'TOT_E','GROUP',
----# mt.MsmtTyp_ID from TWG.MsmtTyp mt where MsmtTyp_Nm in(
----#);

insert into TWG.MGrpMbr (
  MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID )
select * from session.CTD_MGrpMbr s
where not exists (
  select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd = s.MGrpTyp_Cd and
  t.MGrp_Cd = s.MGrp_Cd and
  t.MsmtTyp_ID = s.MsmtTyp_ID )
;
--------------------------------------------------
-- Temporary for TWG.RelnRul
----------------------------------------
delete from TWG.Relnrul where comptyp_source_cd='CTD_HOST' and comptyp_target_cd='IP_INTERFACE';

declare global temporary table CTD_RelnRul (
       CompTyp_Source_Cd    CHAR(17) NOT NULL,
       CompTyp_Target_Cd    CHAR(17) NOT NULL,
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
       RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

;
insert into session.CTD_RelnRul values ('CTD_HOST', 'CTD_INSTANCE', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('IP_HOST', 'CTD_INSTANCE', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('IP_INTERFACE', 'CTD_INSTANCE', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('CTD_INSTANCE', 'CTD_DATABASE', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('CTD_DATABASE', 'CTD_NODE', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('CTD_DATABASE', 'CTD_TABLE', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('CTD_DATABASE', 'CTD_APPL', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('CTD_NODE', 'CTD_TBSP', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('CTD_DATABASE', 'CTD_APPLY_ID', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('CTD_INSTANCE', 'CTD_GATEWAY', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into session.CTD_RelnRul values ('CTD_APPLY_ID', 'CTD_TABLE_APPLY', 'PCHILD', current timestamp - current timezone, '9999-01-01-00.00.00.000000');


insert into TWG.RelnRul 
select
 m.CompTyp_Source_Cd as CompTyp_Source_Cd, 
 m.CompTyp_Target_Cd as CompTyp_Target_Cd,
 m.RelnTyp_Cd as RelnTyp_Cd, 
 m.RelnRul_Strt_DtTm as RelnRul_Strt_DtTm,
 m.RelnRul_End_DtTm as RelnRul_End_DtTm
from
 session.CTD_RelnRul m
where
 not exists
( select 1 from
  CTD.Cur_Relnrul t
  where
  t.CompTyp_Source_Cd = m.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = m.CompTyp_Target_Cd and
  t.RelnTyp_Cd = m.RelnTyp_Cd 
  )
;
-----------------
-- Attribute Rule
-----------------

update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_BACKUP_TMSTMP' and comptyp_cd='CTD_DATABASE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_RSTPND_STATUS' and comptyp_cd='CTD_DATABASE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_CONN_STATUS' and comptyp_cd='CTD_DATABASE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_RESTORE_PEND' and comptyp_cd='CTD_DATABASE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_RESET_TMSTMP' and comptyp_cd='CTD_INSTANCE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_CNTRSST_TM' and comptyp_cd='CTD_INSTANCE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_ISMPP' and comptyp_cd='CTD_NODE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_LAST_DB_BCKUP' and comptyp_cd='CTD_NODE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_RSTPND_STATUS' and comptyp_cd='CTD_NODE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_RESTORE_PEND' and comptyp_cd='CTD_NODE';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_ISMPP' and comptyp_cd='CTD_APPL';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_APPLY_STATUS' and comptyp_cd='CTD_APPLY_ID';
update TWG.Attrrul set AttrRul_End_Dttm=(current timestamp - current timezone) where attrtyp_cd='CTD_ASUB_STATUS' and comptyp_cd='CTD_APPLY_ID';

update TWG.Attrrul set AttrRul_Dom_Ind='N' where attrtyp_cd='NAME' and comptyp_cd='CTD_TABLE';
update TWG.Attrrul set AttrRul_Dom_Ind='N' where attrtyp_cd='OWNER' and comptyp_cd='CTD_TABLE';
update TWG.Attrrul set AttrRul_Dom_Ind='N' where attrtyp_cd='NAME' and comptyp_cd='CTD_TABLE_APPLY';
update TWG.Attrrul set AttrRul_Dom_Ind='N' where attrtyp_cd='OWNER' and comptyp_cd='CTD_TABLE_APPLY';


--------------------------------------
-- temporary table for AttrRul 
---------------------------------------

declare global temporary table CTD_AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;   

insert into session.CTD_AttrRul values ('CTD_INSTANCE', 'CTD_ISMPP', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_INSTANCE', 'CTD_HOST', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_INSTANCE', 'LAST_IP_ADDRESS', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_INSTANCE', 'VERSION', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_NODE', 'CTD_LOGPATH', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_NODE', 'CTD_NODE_PORT_NUM', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_NODE', 'CTD_NODE_NUM', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_NODE', 'CTD_NODE_HOST_NM', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_TABLE', 'OWNER', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_TABLE', 'NAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_TABLE_APPLY', 'OWNER', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_TABLE_APPLY', 'NAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_HOST', 'AMX_EID', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.CTD_AttrRul values ('CTD_HOST', 'AMX_GMT_OFFSET', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');


insert into TWG.AttrRul
select 
 t.CompTyp_Cd  as CompTyp_Cd,
 t.AttrTyp_Cd as AttrTyp_Cd,
 t.AttrRul_Strt_DtTm as AttrRul_Strt_DtTm,
 t.AttrRul_End_DtTm as AttrRul_End_DtTm,
 t.AttrRul_Dom_Ind as AttrRul_Dom_Ind
from 
 session.CTD_AttrRul t
where not exists
( select 1 from
  CTD.Cur_AttrRul m
  where
  t.CompTyp_Cd = m.CompTyp_Cd and
  t.AttrTyp_Cd = m.AttrTyp_Cd
  )
;


----------------------------------------------
-- Translation tables
----------------------------------------------
--------------------------------------------------
-- Need to link the ITM Resource to the compTyp_cd 
----------------------------------------------

declare global temporary table AMX_Resource_Transl (
resource		varchar(50) not null,
CompTyp_cd		varchar(17) not null
)
with replace on commit preserve rows not logged
;

insert into session.AMX_Resource_Transl values ('DB2Instance', 'CTD_INSTANCE');
insert into session.AMX_Resource_Transl values ('DB2Database', 'CTD_DATABASE');
insert into session.AMX_Resource_Transl values ('DB2TableSpace', 'CTD_TBSP');
insert into session.AMX_Resource_Transl values ('DB2Table', 'CTD_TABLE');
insert into session.AMX_Resource_Transl values ('DB2Partition', 'CTD_NODE');
insert into session.AMX_Resource_Transl values ('DB2Gateway', 'CTD_GATEWAY');
insert into session.AMX_Resource_Transl values ('DB2Application', 'CTD_APPL');
insert into session.AMX_Resource_Transl values ('DB2Apply ', 'CTD_APPLY_ID');
insert into session.AMX_Resource_Transl values ('DB2TableApply', 'CTD_TABLE_APPLY');



insert into AMX.Resource_Transl
select 
t.resource as resource,
t.Comptyp_cd as comptyp_cd
from 
 session.AMX_resource_Transl t
where not exists
( select 1 from
  AMX.Resource_Transl m
  where
  t.comptyp_Cd = m.comptyp_Cd 
  )
; 

--------------------------------------------------
-- Need to link the ITM Category to the AVA code 
----------------------------------------------

declare global temporary table AMX_Category_Transl (
category		varchar(120) not null,
MSrc_cd			char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.AMX_Category_Transl values ('DB2Monitoring','CTD');


insert into AMX.Category_Transl
select 
t.category as category,
t.Msrc_Cd as Msrc_Cd
from 
 session.AMX_Category_Transl t
where not exists
( select 1 from
  AMX.Category_Transl m
  where
  t.Msrc_Cd = m.Msrc_Cd 
  )
; 

--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters 
-- Need to know which properties are key properties
-- Need to know which properties will be used for the Comp_Nm
--------------------------------------------------

declare global temporary table AMX_CompTyp_Transl (
Msrc_Cd			char(3) not null,
ITM_key_property	varchar(600) not null,
Comptyp_cd		varchar(17) not null,
Comp_format_nm		varchar(120) not null
)
with replace on commit preserve rows not logged
;


insert into session.AMX_CompTyp_Transl values ('CTD','DB2Instance.db2Instance','CTD_INSTANCE','DB2Instance.db2Instance');
insert into session.AMX_CompTyp_Transl values ('CTD','DB2Database.db2Database','CTD_DATABASE','DB2Database.db2Database');
insert into session.AMX_CompTyp_Transl values ('CTD','DB2Application.db2AppID','CTD_APPL','DB2Application.db2AppID');
insert into session.AMX_CompTyp_Transl values ('CTD','DB2TableSpace.db2TbspName','CTD_TBSP','DB2TableSpace.db2TbspName');
insert into session.AMX_CompTyp_Transl values ('CTD','DB2Table.db2Schema;DB2Table.db2TableName','CTD_TABLE','DB2Table.db2Schema;DB2Table.db2TableName');
insert into session.AMX_CompTyp_Transl values ('CTD','DB2Gateway.db2Database','CTD_GATEWAY','DB2Gateway.db2Database');
insert into session.AMX_CompTyp_Transl values ('CTD','DB2Apply.db2ApplyID','CTD_APPLY_ID','DB2Apply.db2ApplyID');
insert into session.AMX_CompTyp_Transl values ('CTD','DB2TableApply.db2Schema;DB2TableApply.db2TableName','CTD_TABLE_APPLY','DB2TableApply.db2Schema;DB2TableApply.db2TableName');
insert into session.AMX_CompTyp_Transl values ('CTD','DB2Partition.db2Node','CTD_NODE','DB2Partition.db2Node');




insert into AMX.Comptyp_Transl
select 
t.Msrc_Cd as Msrc_Cd,
t.ITM_key_property as ITM_key_property,
t.Comptyp_cd as Comptyp_cd,
t.Comp_format_nm as Comp_format_nm
from 
 session.AMX_Comptyp_Transl t
where not exists
( select 1 from
  AMX.Comptyp_Transl m
  where
  t.Msrc_Cd = m.Msrc_Cd and
  t.Comptyp_cd  = m.Comptyp_cd 
  )
; 

---------------------------------------------------
-- Update the AMX.ATTRTYP_TRANSL Table

delete from amx.attrtyp_transl where attrtyp_cd='CTD_APPLY_STATUS';
delete from amx.attrtyp_transl where attrtyp_cd='CTD_ASUB_STATUS';
delete from amx.attrtyp_transl where attrtyp_cd='CTD_CNTRSST_TM';
delete from amx.attrtyp_transl where attrtyp_cd='CTD_START_TMSTMP';
delete from amx.attrtyp_transl where attrtyp_cd='CTD_RDIST_STATUS';
delete from amx.attrtyp_transl where attrtyp_cd='CTD_LAST_DB_BCKUP';
delete from amx.attrtyp_transl where attrtyp_cd='CTD_RESTORE_PEND';

--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters
----------------------------------------------
declare global temporary table AMX_AttrTyp_Transl (
Msrc_Cd			char(3) not null,
ITM_attr_property	varchar(120) not null,
AttrTyp_cd		varchar(17) not null
)
with replace on commit preserve rows not logged
;


insert into session.AMX_AttrTyp_Transl values ('CTD','DB2Table.db2TableName','NAME');
insert into session.AMX_AttrTyp_Transl values ('CTD','DB2Table.db2Schema','OWNER');
insert into session.AMX_AttrTyp_Transl values ('CTD','DB2TableApply.db2TableName','NAME');
insert into session.AMX_AttrTyp_Transl values ('CTD','DB2TableApply.db2Schema','OWNER');
insert into session.AMX_AttrTyp_Transl values ('CTD','DB2Instance.isMPP','CTD_ISMPP');
insert into session.AMX_AttrTyp_Transl values ('CTD','DB2Application.db2AppName','CTD_APPL_NAME');

insert into AMX.Attrtyp_Transl
select 
t.Msrc_Cd as Msrc_Cd,
t.ITM_attr_property as ITM_attr_property,
t.AttrTyp_Cd as AttrTyp_Cd
from 
 session.AMX_Attrtyp_Transl t
where not exists
( select 1 from
  AMX.Attrtyp_Transl m
  where
  t.Msrc_Cd = m.Msrc_Cd and
  t.AttrTyp_cd  = m.AttrTyp_cd 
  )
; 

--Insert data into control table for pruning data from Msmt table.
--A date duration is decimal(8,0) and has the format yyyymmdd.

declare global temporary table prune_msmt_control(
       MSrc_Cd              CHAR(6) NOT NULL,
       TmSum_Cd             CHAR NOT NULL,
       PMsmtC_Age_In_Days   DECIMAL(8,0) NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.Prune_Msmt_Control values ('CTD', 'H', 00000300);
insert into session.Prune_Msmt_Control values ('CTD', 'D', 00000300);
insert into session.Prune_Msmt_Control values ('CTD', 'W', 00010000);
insert into session.Prune_Msmt_Control values ('CTD', 'M', 00010000);

insert into TWG.Prune_Msmt_Control
select * from 
 session.Prune_Msmt_Control s
where not exists
( select 1 from
  TWG.Prune_Msmt_Control t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.TmSum_Cd = s.TmSum_Cd)
;



--------------------------------------
-- temporary tables indicating which measurement
-- is in the group MIN_E, MAX_E, AVG_E, TOT_E
-- for the CTD DataMart
------------------------------------------



declare global temporary table temp_min_exists (
 msmttyp_id   integer,
 min_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 twg.mgrpmbr mb 
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E'
;

-- select * from session.temp_min_exists;


declare global temporary table temp_max_exists (
 msmttyp_id   integer,
 max_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 twg.mgrpmbr mb 
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E'
;

declare global temporary table temp_avg_exists (
 msmttyp_id   integer,
 avg_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 twg.mgrpmbr mb 
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'
;

-- select * from session.temp_avg_exists;


declare global temporary table temp_tot_exists (
 msmttyp_id   integer,
 tot_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 twg.mgrpmbr mb 
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'
;

---------------------------------------
-- temporary table for Extract Control
---------------------------------------
 declare global temporary table Extract_Control (
        ExtCtl_Source     varchar(120) not null,
  ExtCtl_Target       varchar(120) not null,
  ExtCtl_From_RawSeq      char(10) for bit data,
  ExtCtl_To_RawSeq        char(10) for bit data,
  ExtCtl_From_IntSeq      bigint,
  ExtCtl_To_IntSeq        bigint,
  ExtCtl_From_DtTm        timestamp not null,
  ExtCtl_To_DtTm          timestamp not null
  )
with replace on commit preserve rows not logged
;
-----------------------------------------------
-- From Staging to the T tables
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_HOST' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  INST 
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_INST' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_INST_MET' ,
    'CTD.STG_T_INST_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_INST_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  DB 
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_DB' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_DB_MET' ,
    'CTD.STG_T_DB_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_DB_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  GTWY 
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_GTWY' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_GTWY_MET' ,
    'CTD.STG_T_GTWY_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_GTWY_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  NODE 
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_NODE' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_NODE_MET' ,
    'CTD.STG_T_NODE_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_NODE_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  APPLY 
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_APPLY' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_APPLY_MET' ,
    'CTD.STG_T_APPLY_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_APPLY_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  TABLE 
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_TABLE' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_TABLE_MET' ,
    'CTD.STG_T_TABLE_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_TABLE_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  APPL 
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_APPL' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_APPL_MET' ,
    'CTD.STG_T_APPL_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_APPL_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  TBSP 
-----------------------------------------------


insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_TBSP_ND' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_TBSP_ND_MET' ,
    'CTD.STG_T_TBSP_ND_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_TBSP_ND_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);
-----------------------------------------------
-- Component  TAPPLY 
-----------------------------------------------

insert into session.extract_control values (
    'TWG.COMP' ,
    'CTD.STG_T_TAPPLY' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'CTD.STG_TAPPLY_MET' ,
    'CTD.STG_T_TAPPLY_MET' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'CTD.STG_TAPPLY_HR' ,
    x'',
    x'',
    -1,
    -1, 
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-- insert the static data for the extract table 
-- if not exist already

insert into TWG.Extract_control
select 
 m.ExtCtl_Source as ExtCtl_Source,
 m.ExtCtl_Target as ExtCtl_Target,
 m.ExtCtl_From_RawSeq as ExtCtl_From_RawSeq,
 m.ExtCtl_To_RawSeq as ExtCtl_To_RawSeq,
 m.ExtCtl_From_IntSeq as ExtCtl_From_IntSeq,
 m.ExtCtl_To_IntSeq as ExtCtl_To_IntSeq,
 m.ExtCtl_From_DtTm as ExtCtl_From_DtTm,
 m.ExtCtl_To_DtTm as ExtCtl_To_DtTm  
from 
 session.Extract_Control m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
  )
; 
   


--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_INSTANCE
------------------------------------------

insert into CTD.STG_INST_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_INSTANCE' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_INST_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;



--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_DATABASE
------------------------------------------

insert into CTD.STG_DB_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_DATABASE' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_DB_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;



--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_GATEWAY
------------------------------------------

insert into CTD.STG_GTWY_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_GATEWAY' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_GTWY_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;




--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_NODE
------------------------------------------

insert into CTD.STG_NODE_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_NODE' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_NODE_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;



--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_APPLY_ID
------------------------------------------

insert into CTD.STG_APPLY_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_APPLY_ID' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_APPLY_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;



--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_TABLE
------------------------------------------

insert into CTD.STG_TABLE_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_TABLE' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_TABLE_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;



--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_APPL
------------------------------------------

insert into CTD.STG_APPL_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_APPL' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_APPL_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;





--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_TBSP
------------------------------------------

insert into CTD.STG_TBSP_ND_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_TBSP' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_TBSP_ND_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;




--------------------------------------
-- insert the  measurement types in 
-- the metrics dimensions for 
-- the component CTD_TABLE_APPLY
------------------------------------------

insert into CTD.STG_TAPPLY_MET
(
insert_dttm,
metric_id,
met_category,
met_name,
met_desc,
met_units,
min_exists,
max_exists,
avg_exists,
total_exists,
msrc_nm)
select
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 'Not used' AS met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 s.msrc_nm as msrc_nm
from
 twg.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 twg.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 twg.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 twg.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 twg.msmtrul mr,
 twg.msrc s
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mt.msrc_cd='CTD' and  
 s.msrc_cd=mt.msrc_cd and
 mr.comptyp_cd = 'CTD_TABLE_APPLY' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 not exists (select 1 from CTD.STG_TAPPLY_MET m
  where
  m.metric_id = mt.msmttyp_id and
  m.msrc_nm = s.msrc_nm)
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd,  
 min_exists, avg_exists, tot_exists, max_exists, s.msrc_nm
;




--#iftag fixpack_1
